(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3043459,      88965]*)
(*NotebookOutlinePosition[   3112526,      91294]*)
(*  CellTagsIndexPosition[   3112482,      91290]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Identities for JacobiCD", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", "m"}], "-", 
            SuperscriptBox[
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], 
                "2"]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              SuperscriptBox[
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "-", "m"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        "m"]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], "m"]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        "m"]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], "m"]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        "m"]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], "m"]}],
       TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "-", "m", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "-", 
            "m", "+", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", "1"}], "-", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], 
                "2"]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "-", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", "1"}],
             ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", "1"}],
             ")"}], " ", 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        SuperscriptBox[
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]}]}]], "StandardFormEquation",\

  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", "1"}],
             ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", "1"}],
             ")"}], " ", 
          SuperscriptBox[
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
          " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", "1"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], "-", 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{"m", " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", "1"}],
             ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", "1"}],
             ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSN", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sn", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSN", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sn", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
          " ", 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"JacobiDN", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"dn", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"], " ", 
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        "m"]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], "m"]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          "-", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{"m", " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"m", " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]}]}],
       TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiCN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSD", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
                RowBox[{
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNS", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSD", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"ns", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSD", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"JacobiNS", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "3"], " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSD", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  SuperscriptBox[
                    RowBox[{"ns", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "3"]}], "-", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
                
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"JacobiND", "[", 
                        RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                    RowBox[{"JacobiNS", "[", 
                      RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                  RowBox[{
                    RowBox[{"JacobiND", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], " ", 
                    RowBox[{"JacobiSD", "[", 
                      RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                  RowBox[{"JacobiSN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      RowBox[{"ns", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                    " ", 
                    SuperscriptBox[
                      RowBox[{"nd", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", 
                  RowBox[{
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
                
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "/", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities for JacobiCN", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "-", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", "-", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "m"]}]], "StandardFormEquation",\

  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "m"]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "m"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "-", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", "-", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{"m", " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{"1", "+", 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", "1"}],
             ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", "1"}],
             ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        "m"]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "m"]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        "m"]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], "m"]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          "m"]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "m"]}]}],
       TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "m"]}]], "StandardFormEquation",\

  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "m"]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "-", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "-", 
            
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "-", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          SuperscriptBox[
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              "1"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              "1"}], ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", "m", "+", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "m", "-", "1"}], ")"}], " ", 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", "1"}],
             ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", "1"}],
             ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], "-", 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", "1"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSN", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sn", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", "1"}], ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        "m"]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], "m"]}],
       TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"m", " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", "m"}], " ", 
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNS", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "3"], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"ns", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "3"]}], "-", 
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"m", " ", 
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], "-", 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]}],
           
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                  "2"]}]}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSD", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    SuperscriptBox[
                      RowBox[{"sd", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], "-", 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]}]}],
       TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
          " ", 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"m", " ", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"-", "m"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          "+", 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          "-", 
          RowBox[{
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{"m", " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], "-", 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          "-", 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          "-", 
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities for JacobiCS", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          SuperscriptBox[
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"JacobiDS", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"ds", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"], " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"ns", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"JacobiDS", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"ds", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"], " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], 
                "2"]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                  "2"]}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",\

  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"ns", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                  "2"]}]}], 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"ns", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{
                    RowBox[{"ns", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                  "2"]}]}], 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], 
                "2"]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiCS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "-", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"cs", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities for JacobiDC", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", "m", "+", 
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "m", "-", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "-", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          SuperscriptBox[
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            SuperscriptBox[
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", "1"}],
             ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", "1"}],
             ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", "1"}],
             ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", "1"}],
             ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{"m", " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], "+", 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "-", 
        RowBox[{"m", " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
          " ", 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"JacobiCN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"JacobiCN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
          " ", 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        SuperscriptBox[
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        SuperscriptBox[
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          SuperscriptBox[
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        SuperscriptBox[
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          SuperscriptBox[
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        SuperscriptBox[
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          SuperscriptBox[
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"-", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
          " ", 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiCN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"cn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities for JacobiDN", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "-", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", "-", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "-", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", "-", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "m"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", "m"}], " ", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", "m"}], " ", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", "m"}], " ", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", "m"}], " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", "1"}],
             ")"}], " ", 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "m"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", "1"}],
             ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", "1"}],
             ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiCN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"ns", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", "m"}], " ", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", "m"}], " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"ns", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", "m"}], " ", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", "m"}], " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], "/", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
                
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{"m", " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], "/", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
                
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"-", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], "/", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], "/", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"dn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities for JacobiDS", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}], ")"}], " ", 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                "2"]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          SuperscriptBox[
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], "/", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"-", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        SuperscriptBox[
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          SuperscriptBox[
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"-", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], "/", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"-", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiDS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ds", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities for JacobiNC", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", "1"}], ")"}], " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", "m"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}]}], 
          RowBox[{"m", "-", "1"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", "m", "+", 
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "m", "-", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", "m", "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "m", "-", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "-", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "-", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{"1", "-", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", "m"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"m", "-", "1"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  SuperscriptBox[
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  SuperscriptBox[
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}]}], 
          SuperscriptBox[
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}]}], 
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  SuperscriptBox[
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
          " ", 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], "+", 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", "m"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"m", "-", "1"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], "+", 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], "+", 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          "+", 
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiDS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"ds", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
          " ", 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "3"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "3"]}], 
            "-", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"m", " ", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        SuperscriptBox[
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          SuperscriptBox[
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], "+", 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
                
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities for JacobiND", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", "1"}], "+", "m", "-", 
            SuperscriptBox[
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", "m", "-", "1"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"-", "m"}], "-", 
            SuperscriptBox[
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], 
                "2"]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              SuperscriptBox[
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "-", "m"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"-", "m"}], "+", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "-", 
            "m"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"-", "1"}], "-", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], 
                "2"]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "-", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSN", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sn", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          SuperscriptBox[
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiND", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"nd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities for JacobiNS", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}], ")"}], " ", 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiCS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"cs", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", "m", "+", 
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "m", "-", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], " ", 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  SuperscriptBox[
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", "m", "-", "1"}], ")"}]}], " ", 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", "1"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiDN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"dn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{"JacobiSN", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          "+", 
          RowBox[{"sn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          SuperscriptBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiNS", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ns", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities for JacobiSC", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"-", "1"}], "+", "m", "+", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "m", "-", "1"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          SuperscriptBox[
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], " ", 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], " ", 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"m", " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "+", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiCN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"JacobiDC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"dc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"], " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiND", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    SuperscriptBox[
                      RowBox[{"nd", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}]}], ")"}]}], 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                  "2"]}]}], 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
              SuperscriptBox[
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"m", " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                  "2"]}]}], 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                  "2"]}]}], 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    RowBox[{"ns", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiSD", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], 
                "2"]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"m", " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"m", " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
              SuperscriptBox[
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], "/", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSC", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sc", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities for JacobiSD", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", "m"}], "+", 
          SuperscriptBox[
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "-", 
            "m"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        SuperscriptBox[
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          SuperscriptBox[
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", "1"}], "+", "m", "-", 
            SuperscriptBox[
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", "m", "-", "1"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          "m"]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "m"]}]}],
       TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", "1"}],
             ")"}], " ", 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "m"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"m", " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "-", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", "1"}], "-", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], 
                "2"]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "-", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"cs", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"m", "-", 
              SuperscriptBox[
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", 
                SuperscriptBox[
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "1"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSN", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
              ")"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sn", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", "1"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCD", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                  "2"]}]}], 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "m"]}]], "StandardFormEquation",\

  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "m"]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"-", "m"}], " ", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"-", "m"}], " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                RowBox[{"cn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"JacobiSN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSD", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sd", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identities for JacobiSN", "Section",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Involving two other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"m", " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          "m"]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "m"]}]}],
       TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving three other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"-", "1"}], "+", "m", "+", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "m", "-", "1"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", "1"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          "m"]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "m"]}]}],
       TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiCS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "-", "m", "+", "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cs", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          SuperscriptBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], " ", 
        RowBox[{"(", 
          RowBox[{"1", "+", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              "1"}], ")"}], " ", 
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "+", 
                SuperscriptBox[
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "-", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", "-", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "m"]}]], "StandardFormEquation",\

  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "m"]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m", "+", 
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"ds", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "m", "-", "1"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "m"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "-", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", "-", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", " ", 
          SuperscriptBox[
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              SuperscriptBox[
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "+", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                "1"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                "1"}], ")"}], " ", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "-", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", "-", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m", "-", 
                SuperscriptBox[
                  RowBox[{"JacobiCS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      RowBox[{"cs", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "+", "m", "-", "1"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{"m", "-", 
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", "-", 
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "m"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiNC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          SuperscriptBox[
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"nc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            SuperscriptBox[
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"1", "+", 
            SuperscriptBox[
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              SuperscriptBox[
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              "+", "1"}]]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
              RowBox[{"m", " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{"1", "+", 
          RowBox[{"m", " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"sd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                "+", "1"}], ")"}]}], 
          RowBox[{
            RowBox[{"m", " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          SuperscriptBox[
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          SuperscriptBox[
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "2"]}], 
        RowBox[{"1", "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            SuperscriptBox[
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            SuperscriptBox[
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving four other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiDN", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    SuperscriptBox[
                      RowBox[{"dn", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiCN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}]}],
           
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"JacobiDS", "[", 
          RowBox[{"z", ",", "m"}], "]"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"ds", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"m", " ", 
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"JacobiCD", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                  RowBox[{"JacobiDN", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"cd", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"], " ", 
                    RowBox[{"dn", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  RowBox[{"cd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], 
                "]"}]}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  "1"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"JacobiDC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"dc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          SuperscriptBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  SuperscriptBox[
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                    "2"]}], "-", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{"JacobiNS", "[", 
          RowBox[{"z", ",", "m"}], "]"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"ns", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], " ", 
            
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        SuperscriptBox[
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "2"]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          SuperscriptBox[
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiND", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"nd", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "-", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"JacobiDC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "m"]}]], "StandardFormEquation",\

  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"dc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                  RowBox[{"dn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"m", " ", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "m"]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "m"]}]], "StandardFormEquation",\

  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "m"]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiNC", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"nc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"1", "+", 
          SuperscriptBox[
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "1"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"m", "-", "1"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        FractionBox["1", "m"], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"JacobiDN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], " ", 
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"JacobiDS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], "m"]}],
       TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiSC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"sc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", "1"}], "-", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], "+", 
                RowBox[{"m", " ", 
                  SuperscriptBox[
                    RowBox[{"JacobiSC", "[", 
                      RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], ")"}]}], 
          RowBox[{
            RowBox[{"JacobiCS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "+", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"m", " ", 
                    SuperscriptBox[
                      RowBox[{"sc", "(", 
                        RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
                      "2"]}], "-", 
                  SuperscriptBox[
                    RowBox[{"sc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"],
                   "-", "1"}], ")"}]}], 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"m", " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], ")"}]}], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"m", "-", "1"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", "m"}], " ", 
                  RowBox[{"JacobiCD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "-", 
                RowBox[{
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], " ", 
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", "m"}], " ", 
                    RowBox[{"cd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "+", 
                  RowBox[{"m", " ", 
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
                  "-", 
                  RowBox[{
                    RowBox[{"nc", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                    
                    RowBox[{"nd", "(", 
                      RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
                ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
                RowBox[{"m", " ", 
                  RowBox[{"sc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
                
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], ")"}], 
            " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{"JacobiCN", "[", 
          RowBox[{"z", ",", "m"}], "]"}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{"cn", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiDS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], ")"}]}], 
        RowBox[{"m", "+", 
          SuperscriptBox[
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], 
            "2"]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"ds", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
                RowBox[{"m", " ", 
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
                
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
              ")"}]}], 
          RowBox[{
            SuperscriptBox[
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], "+", 
            "m"}]]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiNS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"ns", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiNS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ns", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSC", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiCN", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiDC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "-", 
          RowBox[{
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{"m", " ", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{"dc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"sc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{
                RowBox[{"JacobiCN", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "-", 
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"cn", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
                
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{"m", " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"JacobiNC", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], 
        RowBox[{
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], 
              "2"]}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "+", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiNS", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "3"], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiSD", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                SuperscriptBox[
                  RowBox[{"ns", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "3"]}],
               "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
                " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Involving five other Jacobi elliptic functions", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiDC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"dc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], " ", 
          RowBox[{"JacobiCS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiDN", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], "+", 
        RowBox[{
          RowBox[{"JacobiDS", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiND", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{
            RowBox[{"ds", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"nd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
          RowBox[{
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"cs", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"dn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], " ", 
            RowBox[{"JacobiDN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "+", 
          RowBox[{
            RowBox[{"JacobiDC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiDS", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiND", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]}], 
        RowBox[{"JacobiDC", "[", 
          RowBox[{"z", ",", "m"}], "]"}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"dc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"ds", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"nd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"cs", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"dn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
          RowBox[{"dc", "(", 
            RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiDN", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiCS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "-", 
            RowBox[{
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}], "+", 
            RowBox[{"m", " ", 
              RowBox[{"JacobiND", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              RowBox[{"JacobiSC", "[", 
                RowBox[{"z", ",", "m"}], "]"}]}]}], 
          ")"}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{
          RowBox[{"-", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"dn", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"cs", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            ")"}]}]}], TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"JacobiNC", "[", 
                    RowBox[{"z", ",", "m"}], "]"}]}], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                SuperscriptBox[
                  RowBox[{"JacobiND", "[", 
                    RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
                RowBox[{"JacobiNS", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiNC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{"m", " ", 
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"nc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        RowBox[{
          FractionBox["1", 
            RowBox[{"JacobiSC", "[", 
              RowBox[{"z", ",", "m"}], "]"}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"JacobiCN", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "-", 
              RowBox[{
                RowBox[{"JacobiCD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "-", 
              RowBox[{
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSC", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], " ", 
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}]}]}], 
            ")"}]}]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "-", 
              RowBox[{
                RowBox[{"cd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "+", 
              RowBox[{"m", " ", 
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], "-", 
              RowBox[{
                RowBox[{"nd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]}], 
            RowBox[{"sc", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      RowBox[{"-", 
        FractionBox[
          RowBox[{
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}], "-", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiND", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
            RowBox[{
              RowBox[{"JacobiNC", "[", 
                RowBox[{"z", ",", "m"}], "]"}], " ", 
              SuperscriptBox[
                RowBox[{"JacobiSD", "[", 
                  RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
          RowBox[{"m", " ", 
            RowBox[{"JacobiCD", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            RowBox[{"JacobiSD", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}]]}]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        RowBox[{"-", 
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"nc", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], " ", 
                
                SuperscriptBox[
                  RowBox[{"nd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{
                RowBox[{"nc", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
                SuperscriptBox[
                  RowBox[{"sd", "(", 
                    RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}],
               "+", 
              RowBox[{"cn", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
            RowBox[{"m", " ", 
              RowBox[{"cd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              RowBox[{"sd", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"JacobiSN", "[", 
        RowBox[{"z", ",", "m"}], "]"}], "\[Equal]", 
      FractionBox[
        RowBox[{
          RowBox[{"-", 
            RowBox[{"JacobiCN", "[", 
              RowBox[{"z", ",", "m"}], "]"}]}], "-", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}], "+", 
          RowBox[{
            RowBox[{"JacobiNC", "[", 
              RowBox[{"z", ",", "m"}], "]"}], " ", 
            SuperscriptBox[
              RowBox[{"JacobiNS", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"], " ", 
            SuperscriptBox[
              RowBox[{"JacobiSD", "[", 
                RowBox[{"z", ",", "m"}], "]"}], "2"]}]}], 
        RowBox[{"m", " ", 
          RowBox[{"JacobiCD", "[", 
            RowBox[{"z", ",", "m"}], "]"}], " ", 
          RowBox[{"JacobiSD", "[", 
            RowBox[{"z", ",", "m"}], "]"}]}]]}]], "StandardFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"sn", "(", 
          RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "\[LongEqual]", 
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"ns", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{
              RowBox[{"nc", "(", 
                RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
              SuperscriptBox[
                RowBox[{"sd", "(", 
                  RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], "2"]}], 
            "-", 
            RowBox[{"cn", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}], 
          RowBox[{"m", " ", 
            RowBox[{"cd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}], " ", 
            RowBox[{"sd", "(", 
              RowBox[{"z", "\[VerticalSeparator]", "m"}], ")"}]}]]}], 
      TraditionalForm]], "TraditionalFormEquation",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
Evaluator->"V6 on byblis2",
WindowSize->{692, 755},
WindowMargins->{{Automatic, 213}, {Automatic, 108}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "WebSite"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{36, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ Page]}], PageNumber], None, Cell[ 
            TextData[ {
              ValueBox[ FileName]}], Header]}, {Cell[ 
            TextData[ {"http://functions.wolfram.com"}], Header], None, Cell[ 
          
            TextData[ {
              CounterBox[ Page]}], PageNumber]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FirstPageFooter"->False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24],
  
  Cell[StyleData["Title", "WebSite"]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18],
  
  Cell[StyleData["Subtitle", "WebSite"],
    CellMargins->{{36, Inherited}, {8, 35}},
    FontSize->36]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "WebSite"]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, Inherited}, {8, 30}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{Inherited, Inherited}, {2, Inherited}},
    CellFrameColor->RGBColor[0, 0.6, 0.8],
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Plain"],
  
  Cell[StyleData["Section", "Printout"],
    CellFrame->False,
    CellMargins->{{2, 0}, {7, 24}},
    FontSize->16],
  
  Cell[StyleData["Section", "WebSite"],
    CellFrame->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{36, Inherited}, {8, 30}},
    CellFrameColor->GrayLevel[0.6],
    FontSize->18]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 0}, {7, 22}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "WebSite"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, Inherited}, {8, 20}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{12, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontWeight->"Plain"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {7, 14}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "WebSite"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{60, Inherited}, {8, 10}},
    FontColor->GrayLevel[0.300008]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Text", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["HyperlinkText"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["HyperlinkText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["HyperlinkText", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextHeader"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextHeader", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["TextHeader", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CommentText"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->"OutputGrouping",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"CommentText"],
  
  Cell[StyleData["CommentText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["CommentText", "WebSite"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrivateCommentText"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->"OutputGrouping",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"PrivateCommentText"],
  
  Cell[StyleData["PrivateCommentText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["PrivateCommentText", "WebSite"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationText"],
    CellMargins->{{12, 10}, {7, 7}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["EquationText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["EquationText", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection3"],
    CellMargins->{{12, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0.6, 0.100008, 0.2]],
  
  Cell[StyleData["Subsection3", "Printout"],
    CellMargins->{{2, 0}, {7, 14}},
    FontSize->11],
  
  Cell[StyleData["Subsection3", "WebSite"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{60, Inherited}, {8, 10}},
    FontColor->GrayLevel[0.300008]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection4"],
    CellMargins->{{12, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 70},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection4",
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0.100008, 0.100008, 0.600015]],
  
  Cell[StyleData["Subsection4", "Printout"],
    CellMargins->{{2, 0}, {7, 14}},
    FontSize->11],
  
  Cell[StyleData["Subsection4", "WebSite"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{60, Inherited}, {8, 10}},
    FontColor->GrayLevel[0.300008]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection5"],
    CellMargins->{{12, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 80},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection5",
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0.600015, 0.400015]],
  
  Cell[StyleData["Subsection5", "Printout"],
    CellMargins->{{2, 0}, {7, 14}},
    FontSize->11],
  
  Cell[StyleData["Subsection5", "WebSite"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{60, Inherited}, {8, 10}},
    FontColor->GrayLevel[0.300008]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["Input", "WebSite"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["StandardFormEquation"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->{"SectionGrouping", 90},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Above,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Plain"],
  
  Cell[StyleData["StandardFormEquation", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["StandardFormEquation", "WebSite"],
    CellMargins->{{56, 10}, {5, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TraditionalFormEquation"],
    CellMargins->{{85, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->{"OutputGrouping", 50},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Above,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Plain"],
  
  Cell[StyleData["TraditionalFormEquation", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["TraditionalFormEquation", "WebSite"],
    CellMargins->{{56, 10}, {5, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["StandardFormEquationHeader"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Plain"],
  
  Cell[StyleData["StandardFormEquationHeader", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["StandardFormEquationHeader", "WebSite"],
    CellMargins->{{56, 10}, {5, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TraditionalFormEquationHeader"],
    CellMargins->{{85, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Plain"],
  
  Cell[StyleData["TraditionalFormEquationHeader", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["TraditionalFormEquationHeader", "WebSite"],
    CellMargins->{{56, 10}, {5, 7}}]
  }, Open  ]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "WebSite"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputFormVersion"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Plain"],
  
  Cell[StyleData["InputFormVersion", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["InputFormVersion", "WebSite"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReplacementRuleVersion"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameLabels->{{
      Cell[ "\[RuleDelayed]", "Text", FontColor -> RGBColor[ 
            0, 0.299992, 0.299992]], Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Plain"],
  
  Cell[StyleData["ReplacementRuleVersion", "Printout"]],
  
  Cell[StyleData["ReplacementRuleVersion", "WebSite"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "WebSite"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8],
  
  Cell[StyleData["Print", "WebSite"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8],
  
  Cell[StyleData["Graphics", "WebSite"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "WebSite"],
    FontFamily->"Courier",
    FontSize->8,
    FontColor->RGBColor[0.6, 0.2, 0]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Misc Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Keywords"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->"OutputGrouping",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Keywords", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Keywords", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CitationInfo"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->"OutputGrouping",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["CitationInfo", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["CitationInfo", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contributors"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->"OutputGrouping",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Contributors", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Contributors", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Derivation"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Derivation", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["Derivation", "WebSite"],
    CellMargins->{{56, 10}, {5, 7}}]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "WebSite"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10],
  
  Cell[StyleData["InlineFormula", "WebSite"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "WebSite"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["Program", "WebSite"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "WebSite"],
    FontColor->RGBColor[0.6, 0.2, 0]]
  }, Open  ]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "WebSite"],
    FontColor->RGBColor[0.6, 0.2, 0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "WebSite"],
    FontColor->RGBColor[0.6, 0.2, 0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "WebSite"],
    FontColor->RGBColor[0.6, 0.2, 0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "WebSite"],
    FontColor->RGBColor[0.6, 0.2, 0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "WebSite"],
    FontColor->RGBColor[0.6, 0.2, 0]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Printout"]],
  
  Cell[StyleData["Placeholder", "WebSite"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]],
  
  Cell[StyleData["PrimaryPlaceholder", "WebSite"]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Misc Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7],
  
  Cell[StyleData["SmallText", "WebSite"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TitleCell1"],
    ShowCellBracket->False,
    CellMargins->{{-2, 0}, {-5, 0}},
    CellLabelMargins->{{0, 0}, {0, 0}},
    CellFrameMargins->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    Background->RGBColor[0.796078, 0.4, 0],
    ButtonBoxOptions->{ButtonFrame->"None"}],
  
  Cell[StyleData["TitleCell1", "Printout"],
    CellMargins->{{0, 0}, {0, 0}}],
  
  Cell[StyleData["TitleCell1", "WebSite"],
    CellMargins->{{-2, 0}, {-5, -2}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TitleCell2"],
    ShowCellBracket->False,
    CellMargins->{{-6, 0}, {0, 0}},
    CellFrameMargins->2,
    StyleMenuListing->None,
    FontSize->14,
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666667],
    Background->GrayLevel[0],
    ButtonBoxOptions->{ButtonFrame->"None"}],
  
  Cell[StyleData["TitleCell2", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7],
  
  Cell[StyleData["TitleCell2", "WebSite"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["HyperlinkHeaderGraphic"],
    CellMargins->{{36, 10}, {0, 3}},
    LineSpacing->{1, 3},
    StyleMenuListing->None],
  
  Cell[StyleData["HyperlinkHeaderGraphic", "Printout"],
    CellMargins->{{12, 2}, {0, 0}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IdentityCount"],
    CellMargins->{{12, 10}, {12, 3}},
    CellGroupingRules->{"SectionGrouping", 30},
    Hyphenation->True],
  
  Cell[StyleData["IdentityCount", "Printout"],
    CellMargins->{{2, 2}, {9, 3}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["IdentityCount", "WebSite"],
    CellMargins->{{36, 10}, {12, 3}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notations_TF_Section"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontWeight->"Bold"],
  
  Cell[StyleData["Notations_TF_Section", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notations_TF_SectionText"],
    CellMargins->{{12, 10}, {7, 7}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Notations_TF_SectionText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notations_TF_Subsection"],
    CellMargins->{{45, 10}, {5, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontWeight->"Bold"],
  
  Cell[StyleData["Notations_TF_Subsection", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notations_TF_SubsectionText"],
    CellMargins->{{45, 10}, {5, 7}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Notations_TF_SubsectionText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notations_SF_Section"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontWeight->"Plain"],
  
  Cell[StyleData["Notations_SF_Section", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notations_SF_SectionText"],
    CellMargins->{{12, 10}, {7, 7}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Notations_SF_SectionText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notations_Program_Section"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->{"SectionGrouping", 60},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontWeight->"Bold"],
  
  Cell[StyleData["Notations_Program_Section", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notations_Program_Subsection"],
    CellMargins->{{20, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->{"SectionGrouping", 70},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Notations_Program_Subsection", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notations_Program_Code"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontWeight->"Bold"],
  
  Cell[StyleData["Notations_Program_Code", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureDescription"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["PictureDescription", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["PictureDescription", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureNumber"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["PictureNumber", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["PictureNumber", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Reference Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 95},
    CellFrameLabels->{{
      Cell[ "R ", "Text", FontColor -> RGBColor[ 0, 0.4, 0]], Inherited}, {
        Inherited, Inherited}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Reference", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceLink"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 95},
    CellFrameLabels->{{
      Cell[ "RL", "Text", FontColor -> RGBColor[ 0, 0.4, 0]], Inherited}, {
        Inherited, Inherited}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ReferenceLink", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["ReferenceLink", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ArXiveNumber"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ArXiveNumber", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["ArXiveNumber", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Authors"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Authors", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Authors", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BookTitle"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["BookTitle", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["BookTitle", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Comments"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Comments", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Comments", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Edition"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Edition", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Edition", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Editors"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Editors", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Editors", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Journal"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Journal", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Journal", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}},
    GeneratedCell->True,
    CellAutoOverwrite->True]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Volume"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Volume", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Volume", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IssueNumber"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IssueNumber", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["IssueNumber", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Language"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Language", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Language", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Pages"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Pages", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Pages", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}},
    GeneratedCell->True,
    CellAutoOverwrite->True]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PublisherLocation"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["PublisherLocation", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["PublisherLocation", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PublisherName"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["PublisherName", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["PublisherName", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Remarks"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Remarks", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Remarks", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTitle"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ReferenceTitle", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["ReferenceTitle", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["URL"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["URL", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["URL", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Year"],
    CellMargins->{{40, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 96},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Year", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Year", "WebSite"],
    CellMargins->{{60, 10}, {7, 7}}]
  }, Open  ]]
  }, Open  ]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 92, 2, 74, "Section"],

Cell[CellGroupData[{
Cell[1893, 59, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2038, 65, 793, 22, 48, "StandardFormEquation"],
Cell[2834, 89, 917, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3788, 117, 694, 19, 46, "StandardFormEquation"],
Cell[4485, 138, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[5374, 165, 790, 21, 49, "StandardFormEquation"],
Cell[6167, 188, 976, 25, 48, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7192, 219, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[7339, 225, 988, 27, 50, "StandardFormEquation"],
Cell[8330, 254, 1173, 30, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[9540, 289, 1132, 30, 61, "StandardFormEquation"],
Cell[10675, 321, 1379, 34, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[12091, 360, 901, 24, 50, "StandardFormEquation"],
Cell[12995, 386, 1103, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[14135, 419, 779, 22, 48, "StandardFormEquation"],
Cell[14917, 443, 929, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[15883, 473, 888, 25, 48, "StandardFormEquation"],
Cell[16774, 500, 1057, 28, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[17868, 533, 901, 24, 50, "StandardFormEquation"],
Cell[18772, 559, 1103, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[19912, 592, 674, 19, 50, "StandardFormEquation"],
Cell[20589, 613, 822, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[21448, 639, 710, 20, 50, "StandardFormEquation"],
Cell[22161, 661, 860, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[23058, 688, 674, 19, 50, "StandardFormEquation"],
Cell[23735, 709, 809, 20, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[24581, 734, 885, 24, 67, "StandardFormEquation"],
Cell[25469, 760, 1067, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[26573, 793, 696, 19, 44, "StandardFormEquation"],
Cell[27272, 814, 854, 21, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[28163, 840, 1018, 27, 66, "StandardFormEquation"],
Cell[29184, 869, 1206, 30, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[30427, 904, 1129, 30, 66, "StandardFormEquation"],
Cell[31559, 936, 1349, 34, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[32945, 975, 733, 20, 44, "StandardFormEquation"],
Cell[33681, 997, 881, 21, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[34599, 1023, 899, 24, 50, "StandardFormEquation"],
Cell[35501, 1049, 1100, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[36638, 1082, 691, 19, 48, "StandardFormEquation"],
Cell[37332, 1103, 852, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[38221, 1130, 648, 18, 48, "StandardFormEquation"],
Cell[38872, 1150, 781, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[39690, 1174, 741, 20, 49, "StandardFormEquation"],
Cell[40434, 1196, 872, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[41343, 1223, 638, 18, 48, "StandardFormEquation"],
Cell[41984, 1243, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[42792, 1267, 849, 23, 65, "StandardFormEquation"],
Cell[43644, 1292, 1016, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[44697, 1323, 764, 21, 48, "StandardFormEquation"],
Cell[45464, 1346, 914, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[46415, 1375, 1109, 30, 81, "StandardFormEquation"],
Cell[47527, 1407, 1305, 34, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[48869, 1446, 850, 23, 66, "StandardFormEquation"],
Cell[49722, 1471, 1017, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[50776, 1502, 886, 24, 68, "StandardFormEquation"],
Cell[51665, 1528, 1068, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[52770, 1561, 839, 23, 47, "StandardFormEquation"],
Cell[53612, 1586, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[54655, 1617, 770, 22, 50, "StandardFormEquation"],
Cell[55428, 1641, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[56355, 1669, 770, 22, 50, "StandardFormEquation"],
Cell[57128, 1693, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[58055, 1721, 721, 20, 48, "StandardFormEquation"],
Cell[58779, 1743, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[59668, 1770, 935, 25, 49, "StandardFormEquation"],
Cell[60606, 1797, 1123, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[61766, 1831, 1079, 28, 66, "StandardFormEquation"],
Cell[62848, 1861, 1329, 33, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[64214, 1899, 984, 26, 65, "StandardFormEquation"],
Cell[65201, 1927, 1170, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[66408, 1961, 730, 20, 47, "StandardFormEquation"],
Cell[67141, 1983, 878, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[68056, 2011, 816, 22, 65, "StandardFormEquation"],
Cell[68875, 2035, 981, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[69893, 2065, 1311, 35, 99, "StandardFormEquation"],
Cell[71207, 2102, 1408, 36, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[72652, 2143, 552, 16, 48, "StandardFormEquation"],
Cell[73207, 2161, 668, 17, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[73912, 2183, 588, 17, 50, "StandardFormEquation"],
Cell[74503, 2202, 706, 18, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[75246, 2225, 674, 19, 50, "StandardFormEquation"],
Cell[75923, 2246, 822, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[76782, 2272, 638, 18, 48, "StandardFormEquation"],
Cell[77423, 2292, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[78231, 2316, 793, 22, 48, "StandardFormEquation"],
Cell[79027, 2340, 917, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[79981, 2368, 1089, 29, 50, "StandardFormEquation"],
Cell[81073, 2399, 1276, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[82386, 2436, 1089, 29, 50, "StandardFormEquation"],
Cell[83478, 2467, 1276, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[84791, 2504, 1179, 31, 50, "StandardFormEquation"],
Cell[85973, 2537, 1383, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[87393, 2576, 721, 20, 48, "StandardFormEquation"],
Cell[88117, 2598, 852, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[89006, 2625, 816, 22, 47, "StandardFormEquation"],
Cell[89825, 2649, 981, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[90843, 2679, 950, 26, 49, "StandardFormEquation"],
Cell[91796, 2707, 1123, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[92956, 2741, 1072, 29, 49, "StandardFormEquation"],
Cell[94031, 2772, 1221, 31, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[95289, 2808, 1139, 31, 49, "StandardFormEquation"],
Cell[96431, 2841, 1358, 35, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[97826, 2881, 691, 19, 27, "StandardFormEquation"],
Cell[98520, 2902, 831, 22, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[99388, 2929, 988, 27, 49, "StandardFormEquation"],
Cell[100379, 2958, 1163, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[101579, 2993, 802, 23, 49, "StandardFormEquation"],
Cell[102384, 3018, 941, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[103362, 3048, 727, 21, 45, "StandardFormEquation"],
Cell[104092, 3071, 867, 23, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[104996, 3099, 752, 21, 43, "StandardFormEquation"],
Cell[105751, 3122, 917, 23, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[106705, 3150, 868, 23, 65, "StandardFormEquation"],
Cell[107576, 3175, 1074, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[108687, 3207, 868, 23, 65, "StandardFormEquation"],
Cell[109558, 3232, 1074, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[110669, 3264, 1097, 29, 100, "StandardFormEquation"],
Cell[111769, 3295, 1318, 33, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[113124, 3333, 673, 18, 43, "StandardFormEquation"],
Cell[113800, 3353, 828, 20, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[114665, 3378, 691, 19, 48, "StandardFormEquation"],
Cell[115359, 3399, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[116248, 3426, 1162, 31, 67, "StandardFormEquation"],
Cell[117413, 3459, 1328, 33, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[118778, 3497, 852, 24, 47, "StandardFormEquation"],
Cell[119633, 3523, 1006, 26, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[120676, 3554, 899, 24, 50, "StandardFormEquation"],
Cell[121578, 3580, 1100, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[122715, 3613, 1179, 31, 68, "StandardFormEquation"],
Cell[123897, 3646, 1383, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[125317, 3685, 956, 25, 48, "StandardFormEquation"],
Cell[126276, 3712, 1133, 28, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[127446, 3745, 730, 21, 43, "StandardFormEquation"],
Cell[128179, 3768, 854, 22, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[129070, 3795, 988, 27, 48, "StandardFormEquation"],
Cell[130061, 3824, 1173, 30, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[131271, 3859, 950, 26, 48, "StandardFormEquation"],
Cell[132224, 3887, 1118, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[133379, 3920, 921, 25, 66, "StandardFormEquation"],
Cell[134303, 3947, 1079, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[135419, 3979, 959, 26, 68, "StandardFormEquation"],
Cell[136381, 4007, 1134, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[137552, 4041, 897, 24, 47, "StandardFormEquation"],
Cell[138452, 4067, 1068, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[139557, 4099, 716, 20, 48, "StandardFormEquation"],
Cell[140276, 4121, 821, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[141134, 4147, 831, 23, 48, "StandardFormEquation"],
Cell[141968, 4172, 955, 24, 45, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[142972, 4202, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[143118, 4208, 840, 23, 48, "StandardFormEquation"],
Cell[143961, 4233, 1013, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[145011, 4263, 958, 26, 50, "StandardFormEquation"],
Cell[145972, 4291, 1152, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[147161, 4324, 863, 23, 50, "StandardFormEquation"],
Cell[148027, 4349, 1043, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[149107, 4381, 777, 21, 50, "StandardFormEquation"],
Cell[149887, 4404, 921, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[150845, 4432, 792, 21, 47, "StandardFormEquation"],
Cell[151640, 4455, 983, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[152660, 4485, 821, 22, 48, "StandardFormEquation"],
Cell[153484, 4509, 980, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[154501, 4539, 739, 20, 48, "StandardFormEquation"],
Cell[155243, 4561, 866, 21, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[156146, 4587, 585, 16, 47, "StandardFormEquation"],
Cell[156734, 4605, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[157494, 4628, 753, 20, 47, "StandardFormEquation"],
Cell[158250, 4650, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[159231, 4679, 707, 19, 47, "StandardFormEquation"],
Cell[159941, 4700, 868, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[160846, 4727, 802, 22, 47, "StandardFormEquation"],
Cell[161651, 4751, 958, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[162646, 4779, 665, 18, 47, "StandardFormEquation"],
Cell[163314, 4799, 820, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[164171, 4824, 701, 19, 49, "StandardFormEquation"],
Cell[164875, 4845, 858, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[165770, 4871, 615, 17, 49, "StandardFormEquation"],
Cell[166388, 4890, 755, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[167180, 4914, 579, 16, 47, "StandardFormEquation"],
Cell[167762, 4932, 717, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[168516, 4955, 729, 20, 47, "StandardFormEquation"],
Cell[169248, 4977, 888, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[170173, 5004, 993, 27, 49, "StandardFormEquation"],
Cell[171169, 5033, 1206, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[172412, 5068, 700, 19, 47, "StandardFormEquation"],
Cell[173115, 5089, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[174009, 5115, 1037, 28, 47, "StandardFormEquation"],
Cell[175049, 5145, 1263, 31, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[176349, 5181, 1037, 28, 47, "StandardFormEquation"],
Cell[177389, 5211, 1263, 31, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[178689, 5247, 899, 24, 47, "StandardFormEquation"],
Cell[179591, 5273, 1043, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[180671, 5303, 1135, 30, 48, "StandardFormEquation"],
Cell[181809, 5335, 1335, 33, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[183181, 5373, 683, 19, 29, "StandardFormEquation"],
Cell[183867, 5394, 835, 21, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[184739, 5420, 753, 20, 47, "StandardFormEquation"],
Cell[185495, 5442, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[186476, 5471, 643, 18, 27, "StandardFormEquation"],
Cell[187122, 5491, 778, 19, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[187937, 5515, 632, 17, 27, "StandardFormEquation"],
Cell[188572, 5534, 783, 20, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[189392, 5559, 713, 19, 47, "StandardFormEquation"],
Cell[190108, 5580, 870, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[191015, 5606, 1016, 26, 65, "StandardFormEquation"],
Cell[192034, 5634, 1249, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[193320, 5669, 751, 20, 49, "StandardFormEquation"],
Cell[194074, 5691, 910, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[195021, 5718, 729, 20, 47, "StandardFormEquation"],
Cell[195753, 5740, 888, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[196678, 5767, 826, 23, 43, "StandardFormEquation"],
Cell[197507, 5792, 948, 23, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[198492, 5820, 934, 25, 50, "StandardFormEquation"],
Cell[199429, 5847, 1109, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[200575, 5880, 921, 24, 78, "StandardFormEquation"],
Cell[201499, 5906, 1115, 26, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[202651, 5937, 581, 16, 27, "StandardFormEquation"],
Cell[203235, 5955, 719, 18, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[203991, 5978, 617, 17, 29, "StandardFormEquation"],
Cell[204611, 5997, 768, 20, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[205416, 6022, 782, 21, 43, "StandardFormEquation"],
Cell[206201, 6045, 956, 23, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[207194, 6073, 755, 20, 47, "StandardFormEquation"],
Cell[207952, 6095, 880, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[208869, 6121, 755, 20, 47, "StandardFormEquation"],
Cell[209627, 6143, 880, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[210544, 6169, 844, 23, 50, "StandardFormEquation"],
Cell[211391, 6194, 977, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[212405, 6223, 1329, 34, 83, "StandardFormEquation"],
Cell[213737, 6259, 1474, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[215248, 6298, 1329, 34, 83, "StandardFormEquation"],
Cell[216580, 6334, 1474, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[218091, 6373, 630, 18, 29, "StandardFormEquation"],
Cell[218724, 6393, 757, 19, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[219518, 6417, 795, 21, 49, "StandardFormEquation"],
Cell[220316, 6440, 937, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[221290, 6468, 1381, 35, 101, "StandardFormEquation"],
Cell[222674, 6505, 1527, 37, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[224238, 6547, 694, 19, 47, "StandardFormEquation"],
Cell[224935, 6568, 851, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[225823, 6594, 753, 20, 47, "StandardFormEquation"],
Cell[226579, 6616, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[227560, 6645, 851, 22, 47, "StandardFormEquation"],
Cell[228414, 6669, 1059, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[229510, 6700, 753, 20, 47, "StandardFormEquation"],
Cell[230266, 6722, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[231247, 6751, 753, 20, 47, "StandardFormEquation"],
Cell[232003, 6773, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[232984, 6802, 579, 16, 47, "StandardFormEquation"],
Cell[233566, 6820, 717, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[234320, 6843, 626, 17, 47, "StandardFormEquation"],
Cell[234949, 6862, 781, 20, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[235767, 6887, 626, 17, 47, "StandardFormEquation"],
Cell[236396, 6906, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[237214, 6931, 712, 19, 47, "StandardFormEquation"],
Cell[237929, 6952, 884, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[238850, 6979, 1215, 32, 47, "StandardFormEquation"],
Cell[240068, 7013, 1447, 36, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[241552, 7054, 993, 27, 49, "StandardFormEquation"],
Cell[242548, 7083, 1206, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[243791, 7118, 1135, 30, 48, "StandardFormEquation"],
Cell[244929, 7150, 1335, 33, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[246301, 7188, 1053, 27, 65, "StandardFormEquation"],
Cell[247357, 7217, 1263, 31, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[248657, 7253, 1377, 35, 99, "StandardFormEquation"],
Cell[250037, 7290, 1538, 38, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[251612, 7333, 678, 19, 47, "StandardFormEquation"],
Cell[252293, 7354, 815, 20, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[253145, 7379, 845, 23, 48, "StandardFormEquation"],
Cell[253993, 7404, 1036, 26, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[255066, 7435, 858, 24, 48, "StandardFormEquation"],
Cell[255927, 7461, 1023, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[256987, 7491, 829, 23, 48, "StandardFormEquation"],
Cell[257819, 7516, 953, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[258809, 7544, 1092, 29, 48, "StandardFormEquation"],
Cell[259904, 7575, 1273, 31, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[261214, 7611, 776, 21, 47, "StandardFormEquation"],
Cell[261993, 7634, 903, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[262933, 7661, 841, 22, 47, "StandardFormEquation"],
Cell[263777, 7685, 1023, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[264837, 7716, 905, 24, 47, "StandardFormEquation"],
Cell[265745, 7742, 1098, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[266880, 7773, 841, 22, 47, "StandardFormEquation"],
Cell[267724, 7797, 1023, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[268784, 7828, 595, 16, 47, "StandardFormEquation"],
Cell[269382, 7846, 733, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[270152, 7869, 911, 24, 65, "StandardFormEquation"],
Cell[271066, 7895, 1104, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[272207, 7926, 943, 24, 47, "StandardFormEquation"],
Cell[273153, 7952, 1163, 29, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[274365, 7987, 121, 2, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[274511, 7993, 1342, 34, 101, "StandardFormEquation"],
Cell[275856, 8029, 1525, 36, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[277418, 8070, 1383, 35, 81, "StandardFormEquation"],
Cell[278804, 8107, 1528, 34, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[280369, 8146, 784, 21, 47, "StandardFormEquation"],
Cell[281156, 8169, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[282151, 8197, 694, 19, 47, "StandardFormEquation"],
Cell[282848, 8218, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[283736, 8244, 1329, 33, 101, "StandardFormEquation"],
Cell[285068, 8279, 1572, 38, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[286677, 8322, 1045, 27, 49, "StandardFormEquation"],
Cell[287725, 8351, 1327, 33, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[289089, 8389, 1139, 30, 63, "StandardFormEquation"],
Cell[290231, 8421, 1366, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[291634, 8460, 1270, 32, 75, "StandardFormEquation"],
Cell[292907, 8494, 1413, 32, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[294357, 8531, 1289, 33, 99, "StandardFormEquation"],
Cell[295649, 8566, 1421, 32, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[297131, 8605, 92, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[297248, 8611, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[297393, 8617, 655, 18, 49, "StandardFormEquation"],
Cell[298051, 8637, 769, 20, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[298857, 8662, 757, 22, 50, "StandardFormEquation"],
Cell[299617, 8686, 836, 22, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[300490, 8713, 588, 17, 50, "StandardFormEquation"],
Cell[301081, 8732, 719, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[301837, 8756, 570, 17, 48, "StandardFormEquation"],
Cell[302410, 8775, 637, 17, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[303084, 8797, 552, 16, 46, "StandardFormEquation"],
Cell[303639, 8815, 645, 17, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[304321, 8837, 704, 20, 50, "StandardFormEquation"],
Cell[305028, 8859, 813, 21, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[305878, 8885, 656, 19, 48, "StandardFormEquation"],
Cell[306537, 8906, 740, 19, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[307314, 8930, 839, 23, 50, "StandardFormEquation"],
Cell[308156, 8955, 1014, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[309207, 8986, 552, 16, 48, "StandardFormEquation"],
Cell[309762, 9004, 668, 17, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[310467, 9026, 764, 21, 48, "StandardFormEquation"],
Cell[311234, 9049, 914, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[312185, 9078, 730, 20, 47, "StandardFormEquation"],
Cell[312918, 9100, 878, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[313833, 9128, 443, 13, 48, "StandardFormEquation"],
Cell[314279, 9143, 540, 14, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[314856, 9162, 552, 16, 48, "StandardFormEquation"],
Cell[315411, 9180, 668, 17, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[316116, 9202, 878, 24, 50, "StandardFormEquation"],
Cell[316997, 9228, 1059, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[318093, 9260, 648, 19, 27, "StandardFormEquation"],
Cell[318744, 9281, 755, 20, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[319536, 9306, 782, 21, 47, "StandardFormEquation"],
Cell[320321, 9329, 934, 24, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[321304, 9359, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[321451, 9365, 727, 20, 50, "StandardFormEquation"],
Cell[322181, 9387, 903, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[323121, 9416, 691, 19, 48, "StandardFormEquation"],
Cell[323815, 9437, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[324704, 9464, 742, 20, 50, "StandardFormEquation"],
Cell[325449, 9486, 873, 22, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[326359, 9513, 975, 26, 48, "StandardFormEquation"],
Cell[327337, 9541, 1178, 29, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[328552, 9575, 867, 24, 50, "StandardFormEquation"],
Cell[329422, 9601, 1064, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[330523, 9634, 643, 18, 44, "StandardFormEquation"],
Cell[331169, 9654, 774, 19, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[331980, 9678, 846, 23, 50, "StandardFormEquation"],
Cell[332829, 9703, 1018, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[333884, 9733, 674, 19, 50, "StandardFormEquation"],
Cell[334561, 9754, 822, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[335420, 9780, 638, 18, 48, "StandardFormEquation"],
Cell[336061, 9800, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[336869, 9824, 786, 22, 50, "StandardFormEquation"],
Cell[337658, 9848, 960, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[338655, 9878, 696, 19, 44, "StandardFormEquation"],
Cell[339354, 9899, 854, 21, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[340245, 9925, 1178, 32, 66, "StandardFormEquation"],
Cell[341426, 9959, 1387, 35, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[342850, 9999, 1129, 30, 66, "StandardFormEquation"],
Cell[343982, 10031, 1349, 34, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[345368, 10070, 807, 22, 44, "StandardFormEquation"],
Cell[346178, 10094, 948, 24, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[347163, 10123, 750, 21, 48, "StandardFormEquation"],
Cell[347916, 10146, 909, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[348862, 10174, 888, 25, 48, "StandardFormEquation"],
Cell[349753, 10201, 1044, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[350834, 10233, 850, 23, 48, "StandardFormEquation"],
Cell[351687, 10258, 1017, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[352741, 10289, 839, 23, 47, "StandardFormEquation"],
Cell[353583, 10314, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[354626, 10345, 732, 20, 50, "StandardFormEquation"],
Cell[355361, 10367, 863, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[356261, 10394, 585, 16, 47, "StandardFormEquation"],
Cell[356849, 10412, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[357609, 10435, 741, 20, 49, "StandardFormEquation"],
Cell[358353, 10457, 872, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[359262, 10484, 708, 19, 49, "StandardFormEquation"],
Cell[359973, 10505, 837, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[360847, 10531, 1093, 29, 65, "StandardFormEquation"],
Cell[361943, 10562, 1298, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[363278, 10599, 638, 18, 46, "StandardFormEquation"],
Cell[363919, 10619, 748, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[364704, 10643, 579, 16, 47, "StandardFormEquation"],
Cell[365286, 10661, 717, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[366040, 10684, 470, 13, 47, "StandardFormEquation"],
Cell[366513, 10699, 589, 15, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[367139, 10719, 595, 17, 48, "StandardFormEquation"],
Cell[367737, 10738, 724, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[368498, 10762, 552, 16, 48, "StandardFormEquation"],
Cell[369053, 10780, 668, 17, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[369758, 10802, 704, 20, 48, "StandardFormEquation"],
Cell[370465, 10824, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[371354, 10851, 638, 18, 48, "StandardFormEquation"],
Cell[371995, 10871, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[372803, 10895, 1019, 27, 68, "StandardFormEquation"],
Cell[373825, 10924, 1191, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[375053, 10958, 691, 19, 48, "StandardFormEquation"],
Cell[375747, 10979, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[376636, 11006, 846, 23, 50, "StandardFormEquation"],
Cell[377485, 11031, 1019, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[378541, 11061, 816, 22, 47, "StandardFormEquation"],
Cell[379360, 11085, 981, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[380378, 11115, 698, 19, 49, "StandardFormEquation"],
Cell[381079, 11136, 827, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[381943, 11162, 1162, 31, 49, "StandardFormEquation"],
Cell[383108, 11195, 1328, 33, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[384473, 11233, 890, 25, 48, "StandardFormEquation"],
Cell[385366, 11260, 1003, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[386406, 11290, 1179, 31, 50, "StandardFormEquation"],
Cell[387588, 11323, 1383, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[389008, 11362, 902, 24, 48, "StandardFormEquation"],
Cell[389913, 11388, 1110, 28, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[391060, 11421, 868, 23, 47, "StandardFormEquation"],
Cell[391931, 11446, 1074, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[393042, 11478, 977, 26, 47, "StandardFormEquation"],
Cell[394022, 11506, 1202, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[395261, 11541, 890, 25, 43, "StandardFormEquation"],
Cell[396154, 11568, 1039, 26, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[397230, 11599, 700, 20, 50, "StandardFormEquation"],
Cell[397933, 11621, 857, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[398827, 11649, 729, 20, 29, "StandardFormEquation"],
Cell[399559, 11671, 892, 23, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[400488, 11699, 843, 22, 49, "StandardFormEquation"],
Cell[401334, 11723, 1044, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[402415, 11754, 795, 22, 48, "StandardFormEquation"],
Cell[403213, 11778, 962, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[404212, 11807, 522, 15, 27, "StandardFormEquation"],
Cell[404737, 11824, 638, 16, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[405412, 11845, 708, 19, 49, "StandardFormEquation"],
Cell[406123, 11866, 837, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[406997, 11892, 992, 28, 49, "StandardFormEquation"],
Cell[407992, 11922, 1135, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[409164, 11957, 932, 26, 47, "StandardFormEquation"],
Cell[410099, 11985, 1043, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[411179, 12017, 1072, 29, 49, "StandardFormEquation"],
Cell[412254, 12048, 1221, 31, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[413512, 12084, 589, 16, 29, "StandardFormEquation"],
Cell[414104, 12102, 699, 18, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[414840, 12125, 1139, 31, 49, "StandardFormEquation"],
Cell[415982, 12158, 1358, 35, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[417377, 12198, 956, 27, 47, "StandardFormEquation"],
Cell[418336, 12227, 1084, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[419457, 12260, 1022, 28, 47, "StandardFormEquation"],
Cell[420482, 12290, 1150, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[421669, 12324, 877, 23, 50, "StandardFormEquation"],
Cell[422549, 12349, 1080, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[423666, 12381, 843, 22, 49, "StandardFormEquation"],
Cell[424512, 12405, 1044, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[425593, 12436, 782, 21, 47, "StandardFormEquation"],
Cell[426378, 12459, 934, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[427349, 12488, 730, 21, 27, "StandardFormEquation"],
Cell[428082, 12511, 854, 22, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[428973, 12538, 872, 23, 47, "StandardFormEquation"],
Cell[429848, 12563, 1041, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[430926, 12594, 472, 13, 27, "StandardFormEquation"],
Cell[431401, 12609, 591, 15, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[432029, 12629, 657, 19, 29, "StandardFormEquation"],
Cell[432689, 12650, 760, 20, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[433486, 12675, 791, 21, 49, "StandardFormEquation"],
Cell[434280, 12698, 928, 23, 48, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[435257, 12727, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[435403, 12733, 869, 24, 50, "StandardFormEquation"],
Cell[436275, 12759, 1058, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[437370, 12791, 804, 22, 50, "StandardFormEquation"],
Cell[438177, 12815, 948, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[439162, 12844, 730, 20, 49, "StandardFormEquation"],
Cell[439895, 12866, 902, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[440834, 12894, 863, 23, 50, "StandardFormEquation"],
Cell[441700, 12919, 1043, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[442780, 12951, 888, 24, 50, "StandardFormEquation"],
Cell[443671, 12977, 1064, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[444772, 13009, 694, 19, 47, "StandardFormEquation"],
Cell[445469, 13030, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[446357, 13056, 821, 22, 48, "StandardFormEquation"],
Cell[447181, 13080, 980, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[448198, 13110, 896, 24, 47, "StandardFormEquation"],
Cell[449097, 13136, 1072, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[450206, 13168, 814, 22, 47, "StandardFormEquation"],
Cell[451023, 13192, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[452018, 13220, 829, 22, 49, "StandardFormEquation"],
Cell[452850, 13244, 1005, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[453892, 13275, 787, 21, 47, "StandardFormEquation"],
Cell[454682, 13298, 942, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[455661, 13327, 748, 21, 47, "StandardFormEquation"],
Cell[456412, 13350, 902, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[457351, 13377, 639, 18, 47, "StandardFormEquation"],
Cell[457993, 13397, 774, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[458804, 13421, 665, 18, 47, "StandardFormEquation"],
Cell[459472, 13441, 820, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[460329, 13466, 579, 16, 47, "StandardFormEquation"],
Cell[460911, 13484, 717, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[461665, 13507, 780, 21, 47, "StandardFormEquation"],
Cell[462448, 13530, 954, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[463439, 13558, 954, 25, 65, "StandardFormEquation"],
Cell[464396, 13585, 1181, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[465614, 13619, 700, 19, 47, "StandardFormEquation"],
Cell[466317, 13640, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[467211, 13666, 763, 21, 62, "StandardFormEquation"],
Cell[467977, 13689, 881, 21, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[468895, 13715, 795, 21, 49, "StandardFormEquation"],
Cell[469693, 13738, 992, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[470722, 13768, 753, 20, 47, "StandardFormEquation"],
Cell[471478, 13790, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[472459, 13819, 862, 23, 47, "StandardFormEquation"],
Cell[473324, 13844, 1072, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[474433, 13876, 753, 20, 47, "StandardFormEquation"],
Cell[475189, 13898, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[476170, 13927, 873, 23, 49, "StandardFormEquation"],
Cell[477046, 13952, 1023, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[478106, 13982, 1141, 31, 65, "StandardFormEquation"],
Cell[479250, 14015, 1365, 35, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[480652, 14055, 873, 23, 49, "StandardFormEquation"],
Cell[481528, 14080, 1067, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[482632, 14111, 792, 21, 47, "StandardFormEquation"],
Cell[483427, 14134, 985, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[484449, 14164, 731, 20, 27, "StandardFormEquation"],
Cell[485183, 14186, 883, 21, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[486103, 14212, 700, 19, 47, "StandardFormEquation"],
Cell[486806, 14233, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[487700, 14259, 780, 21, 47, "StandardFormEquation"],
Cell[488483, 14282, 954, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[489474, 14310, 585, 16, 47, "StandardFormEquation"],
Cell[490062, 14328, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[490822, 14351, 643, 18, 27, "StandardFormEquation"],
Cell[491468, 14371, 778, 19, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[492283, 14395, 785, 22, 27, "StandardFormEquation"],
Cell[493071, 14419, 907, 22, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[494015, 14446, 1399, 35, 99, "StandardFormEquation"],
Cell[495417, 14483, 1537, 36, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[496991, 14524, 700, 19, 47, "StandardFormEquation"],
Cell[497694, 14545, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[498588, 14571, 738, 20, 49, "StandardFormEquation"],
Cell[499329, 14593, 910, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[500276, 14621, 694, 19, 47, "StandardFormEquation"],
Cell[500973, 14642, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[501861, 14668, 585, 16, 47, "StandardFormEquation"],
Cell[502449, 14686, 723, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[503209, 14709, 1170, 30, 100, "StandardFormEquation"],
Cell[504382, 14741, 1463, 36, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[505882, 14782, 864, 23, 59, "StandardFormEquation"],
Cell[506749, 14807, 1035, 24, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[507821, 14836, 558, 15, 27, "StandardFormEquation"],
Cell[508382, 14853, 694, 17, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[509113, 14875, 738, 20, 49, "StandardFormEquation"],
Cell[509854, 14897, 908, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[510799, 14925, 747, 21, 48, "StandardFormEquation"],
Cell[511549, 14948, 904, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[512490, 14976, 683, 19, 29, "StandardFormEquation"],
Cell[513176, 14997, 833, 21, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[514046, 15023, 885, 23, 49, "StandardFormEquation"],
Cell[514934, 15048, 1073, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[516044, 15080, 607, 17, 29, "StandardFormEquation"],
Cell[516654, 15099, 732, 18, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[517423, 15122, 643, 18, 27, "StandardFormEquation"],
Cell[518069, 15142, 778, 19, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[518884, 15166, 626, 17, 47, "StandardFormEquation"],
Cell[519513, 15185, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[520331, 15210, 604, 17, 27, "StandardFormEquation"],
Cell[520938, 15229, 737, 18, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[521712, 15252, 769, 21, 47, "StandardFormEquation"],
Cell[522484, 15275, 898, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[523419, 15302, 1016, 26, 65, "StandardFormEquation"],
Cell[524438, 15330, 1249, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[525724, 15365, 683, 19, 47, "StandardFormEquation"],
Cell[526410, 15386, 795, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[527242, 15411, 720, 19, 43, "StandardFormEquation"],
Cell[527965, 15432, 888, 22, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[528890, 15459, 984, 25, 81, "StandardFormEquation"],
Cell[529877, 15486, 1211, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[531125, 15520, 1316, 35, 75, "StandardFormEquation"],
Cell[532444, 15557, 1542, 39, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[534023, 15601, 641, 18, 27, "StandardFormEquation"],
Cell[534667, 15621, 776, 19, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[535480, 15645, 886, 23, 65, "StandardFormEquation"],
Cell[536369, 15670, 1113, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[537519, 15703, 770, 21, 43, "StandardFormEquation"],
Cell[538292, 15726, 924, 22, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[539253, 15753, 581, 16, 27, "StandardFormEquation"],
Cell[539837, 15771, 719, 18, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[540593, 15794, 1217, 32, 63, "StandardFormEquation"],
Cell[541813, 15828, 1515, 37, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[543365, 15870, 782, 21, 43, "StandardFormEquation"],
Cell[544150, 15893, 956, 23, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[545143, 15921, 643, 18, 27, "StandardFormEquation"],
Cell[545789, 15941, 778, 19, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[546604, 15965, 841, 22, 47, "StandardFormEquation"],
Cell[547448, 15989, 1023, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[548508, 16020, 774, 21, 27, "StandardFormEquation"],
Cell[549285, 16043, 928, 22, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[550250, 16070, 653, 18, 27, "StandardFormEquation"],
Cell[550906, 16090, 788, 19, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[551731, 16114, 558, 15, 27, "StandardFormEquation"],
Cell[552292, 16131, 694, 17, 28, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[553035, 16154, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[553181, 16160, 764, 21, 27, "StandardFormEquation"],
Cell[553948, 16183, 918, 22, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[554903, 16210, 1239, 32, 83, "StandardFormEquation"],
Cell[556145, 16244, 1371, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[557553, 16281, 667, 18, 27, "StandardFormEquation"],
Cell[558223, 16301, 822, 20, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[559082, 16326, 1231, 32, 43, "StandardFormEquation"],
Cell[560316, 16360, 1492, 34, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[561845, 16399, 1153, 30, 77, "StandardFormEquation"],
Cell[563001, 16431, 1343, 31, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[564381, 16467, 1145, 30, 43, "StandardFormEquation"],
Cell[565529, 16499, 1389, 32, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[566955, 16536, 940, 25, 45, "StandardFormEquation"],
Cell[567898, 16563, 1157, 29, 29, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[569116, 16599, 92, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[569233, 16605, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[569378, 16611, 860, 24, 49, "StandardFormEquation"],
Cell[570241, 16637, 1016, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[571294, 16669, 982, 27, 49, "StandardFormEquation"],
Cell[572279, 16698, 1114, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[573430, 16732, 766, 22, 47, "StandardFormEquation"],
Cell[574199, 16756, 903, 24, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[575139, 16785, 831, 23, 48, "StandardFormEquation"],
Cell[575973, 16810, 972, 25, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[576994, 16841, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[577141, 16847, 935, 25, 49, "StandardFormEquation"],
Cell[578079, 16874, 1123, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[579239, 16908, 1079, 28, 66, "StandardFormEquation"],
Cell[580321, 16938, 1329, 33, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[581687, 16976, 743, 21, 47, "StandardFormEquation"],
Cell[582433, 16999, 878, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[583348, 17027, 852, 24, 47, "StandardFormEquation"],
Cell[584203, 17053, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[585246, 17084, 817, 22, 47, "StandardFormEquation"],
Cell[586066, 17108, 971, 25, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[587074, 17138, 849, 23, 47, "StandardFormEquation"],
Cell[587926, 17163, 1016, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[588979, 17194, 741, 20, 49, "StandardFormEquation"],
Cell[589723, 17216, 872, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[590632, 17243, 940, 26, 49, "StandardFormEquation"],
Cell[591575, 17271, 1143, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[592755, 17305, 975, 26, 66, "StandardFormEquation"],
Cell[593733, 17333, 1178, 29, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[594948, 17367, 623, 17, 47, "StandardFormEquation"],
Cell[595574, 17386, 763, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[596374, 17410, 1004, 27, 49, "StandardFormEquation"],
Cell[597381, 17439, 1215, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[598633, 17474, 926, 24, 47, "StandardFormEquation"],
Cell[599562, 17500, 1142, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[600741, 17533, 661, 18, 47, "StandardFormEquation"],
Cell[601405, 17553, 769, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[602211, 17577, 956, 25, 48, "StandardFormEquation"],
Cell[603170, 17604, 1133, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[604340, 17637, 950, 26, 49, "StandardFormEquation"],
Cell[605293, 17665, 1123, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[606453, 17699, 1026, 28, 49, "StandardFormEquation"],
Cell[607482, 17729, 1246, 31, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[608765, 17765, 766, 22, 47, "StandardFormEquation"],
Cell[609534, 17789, 903, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[610474, 17818, 839, 23, 47, "StandardFormEquation"],
Cell[611316, 17843, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[612359, 17874, 862, 24, 47, "StandardFormEquation"],
Cell[613224, 17900, 1016, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[614277, 17931, 902, 24, 48, "StandardFormEquation"],
Cell[615182, 17957, 1110, 28, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[616329, 17990, 868, 23, 47, "StandardFormEquation"],
Cell[617200, 18015, 1074, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[618311, 18047, 626, 17, 47, "StandardFormEquation"],
Cell[618940, 18066, 781, 20, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[619758, 18091, 943, 26, 47, "StandardFormEquation"],
Cell[620704, 18119, 1084, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[621825, 18152, 990, 27, 47, "StandardFormEquation"],
Cell[622818, 18181, 1195, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[624050, 18215, 1178, 31, 47, "StandardFormEquation"],
Cell[625231, 18248, 1414, 35, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[626682, 18288, 1162, 31, 49, "StandardFormEquation"],
Cell[627847, 18321, 1328, 33, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[629212, 18359, 817, 22, 47, "StandardFormEquation"],
Cell[630032, 18383, 971, 25, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[631040, 18413, 1056, 28, 47, "StandardFormEquation"],
Cell[632099, 18443, 1267, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[633403, 18478, 1106, 30, 47, "StandardFormEquation"],
Cell[634512, 18510, 1298, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[635847, 18547, 950, 26, 48, "StandardFormEquation"],
Cell[636800, 18575, 1118, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[637955, 18608, 921, 25, 48, "StandardFormEquation"],
Cell[638879, 18635, 1079, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[639995, 18667, 897, 24, 47, "StandardFormEquation"],
Cell[640895, 18693, 1068, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[642000, 18725, 897, 24, 47, "StandardFormEquation"],
Cell[642900, 18751, 1068, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[644005, 18783, 661, 18, 47, "StandardFormEquation"],
Cell[644669, 18803, 769, 19, 45, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[645487, 18828, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[645633, 18834, 905, 24, 49, "StandardFormEquation"],
Cell[646541, 18860, 1102, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[647680, 18892, 964, 25, 49, "StandardFormEquation"],
Cell[648647, 18919, 1186, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[649870, 18953, 829, 22, 49, "StandardFormEquation"],
Cell[650702, 18977, 1007, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[651746, 19008, 743, 20, 49, "StandardFormEquation"],
Cell[652492, 19030, 885, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[653414, 19057, 792, 21, 47, "StandardFormEquation"],
Cell[654209, 19080, 983, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[655229, 19110, 865, 23, 47, "StandardFormEquation"],
Cell[656097, 19135, 1043, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[657177, 19165, 920, 24, 47, "StandardFormEquation"],
Cell[658100, 19191, 1138, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[659275, 19224, 883, 24, 47, "StandardFormEquation"],
Cell[660161, 19250, 1010, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[661208, 19279, 1299, 33, 65, "StandardFormEquation"],
Cell[662510, 19314, 1595, 38, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[664142, 19357, 761, 21, 47, "StandardFormEquation"],
Cell[664906, 19380, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[665846, 19407, 1299, 33, 65, "StandardFormEquation"],
Cell[667148, 19442, 1595, 38, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[668780, 19485, 761, 21, 47, "StandardFormEquation"],
Cell[669544, 19508, 903, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[670484, 19535, 801, 22, 48, "StandardFormEquation"],
Cell[671288, 19559, 962, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[672287, 19588, 849, 22, 49, "StandardFormEquation"],
Cell[673139, 19612, 1052, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[674228, 19643, 761, 21, 47, "StandardFormEquation"],
Cell[674992, 19666, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[675932, 19693, 801, 22, 48, "StandardFormEquation"],
Cell[676736, 19717, 959, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[677732, 19746, 805, 21, 47, "StandardFormEquation"],
Cell[678540, 19769, 1004, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[679581, 19799, 824, 22, 49, "StandardFormEquation"],
Cell[680408, 19823, 970, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[681415, 19852, 784, 21, 47, "StandardFormEquation"],
Cell[682202, 19875, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[683148, 19902, 911, 24, 65, "StandardFormEquation"],
Cell[684062, 19928, 1104, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[685203, 19959, 784, 21, 47, "StandardFormEquation"],
Cell[685990, 19982, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[686936, 20009, 784, 21, 47, "StandardFormEquation"],
Cell[687723, 20032, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[688669, 20059, 784, 21, 47, "StandardFormEquation"],
Cell[689456, 20082, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[690402, 20109, 870, 23, 47, "StandardFormEquation"],
Cell[691275, 20134, 1014, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[692326, 20163, 1614, 40, 101, "StandardFormEquation"],
Cell[693943, 20205, 1749, 40, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[695729, 20250, 683, 19, 29, "StandardFormEquation"],
Cell[696415, 20271, 835, 21, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[697287, 20297, 795, 21, 49, "StandardFormEquation"],
Cell[698085, 20320, 992, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[699114, 20350, 792, 21, 47, "StandardFormEquation"],
Cell[699909, 20373, 985, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[700931, 20403, 795, 21, 49, "StandardFormEquation"],
Cell[701729, 20426, 992, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[702758, 20456, 851, 23, 47, "StandardFormEquation"],
Cell[703612, 20481, 1010, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[704659, 20510, 848, 23, 48, "StandardFormEquation"],
Cell[705510, 20535, 1009, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[706556, 20565, 755, 20, 47, "StandardFormEquation"],
Cell[707314, 20587, 880, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[708231, 20613, 841, 22, 47, "StandardFormEquation"],
Cell[709075, 20637, 1023, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[710135, 20668, 1299, 33, 65, "StandardFormEquation"],
Cell[711437, 20703, 1595, 38, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[713069, 20746, 784, 21, 47, "StandardFormEquation"],
Cell[713856, 20769, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[714802, 20796, 824, 22, 49, "StandardFormEquation"],
Cell[715629, 20820, 970, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[716636, 20849, 911, 24, 65, "StandardFormEquation"],
Cell[717550, 20875, 1104, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[718691, 20906, 643, 18, 27, "StandardFormEquation"],
Cell[719337, 20926, 778, 19, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[720152, 20950, 753, 20, 47, "StandardFormEquation"],
Cell[720908, 20972, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[721889, 21001, 579, 16, 47, "StandardFormEquation"],
Cell[722471, 21019, 717, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[723225, 21042, 626, 17, 47, "StandardFormEquation"],
Cell[723854, 21061, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[724672, 21086, 626, 17, 47, "StandardFormEquation"],
Cell[725301, 21105, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[726119, 21130, 604, 17, 27, "StandardFormEquation"],
Cell[726726, 21149, 737, 18, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[727500, 21172, 862, 23, 47, "StandardFormEquation"],
Cell[728365, 21197, 1072, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[729474, 21229, 753, 20, 47, "StandardFormEquation"],
Cell[730230, 21251, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[731211, 21280, 735, 20, 47, "StandardFormEquation"],
Cell[731949, 21302, 909, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[732895, 21330, 712, 19, 47, "StandardFormEquation"],
Cell[733610, 21351, 884, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[734531, 21378, 833, 23, 48, "StandardFormEquation"],
Cell[735367, 21403, 960, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[736364, 21432, 629, 17, 47, "StandardFormEquation"],
Cell[736996, 21451, 769, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[737802, 21475, 724, 20, 47, "StandardFormEquation"],
Cell[738529, 21497, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[739417, 21523, 784, 21, 48, "StandardFormEquation"],
Cell[740204, 21546, 962, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[741203, 21575, 1215, 32, 47, "StandardFormEquation"],
Cell[742421, 21609, 1447, 36, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[743905, 21650, 762, 21, 48, "StandardFormEquation"],
Cell[744670, 21673, 906, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[745613, 21701, 724, 20, 47, "StandardFormEquation"],
Cell[746340, 21723, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[747228, 21749, 777, 22, 48, "StandardFormEquation"],
Cell[748008, 21773, 904, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[748949, 21801, 1244, 32, 65, "StandardFormEquation"],
Cell[750196, 21835, 1490, 36, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[751723, 21876, 829, 23, 48, "StandardFormEquation"],
Cell[752555, 21901, 953, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[753545, 21929, 890, 24, 48, "StandardFormEquation"],
Cell[754438, 21955, 1061, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[755536, 21987, 956, 25, 47, "StandardFormEquation"],
Cell[756495, 22014, 1157, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[757689, 22048, 784, 21, 47, "StandardFormEquation"],
Cell[758476, 22071, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[759422, 22098, 1614, 40, 103, "StandardFormEquation"],
Cell[761039, 22140, 1749, 40, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[762825, 22185, 870, 23, 47, "StandardFormEquation"],
Cell[763698, 22210, 1014, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[764749, 22239, 841, 22, 47, "StandardFormEquation"],
Cell[765593, 22263, 1023, 26, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[766665, 22295, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[766811, 22301, 694, 19, 47, "StandardFormEquation"],
Cell[767508, 22322, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[768396, 22348, 753, 20, 47, "StandardFormEquation"],
Cell[769152, 22370, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[770133, 22399, 767, 21, 47, "StandardFormEquation"],
Cell[770903, 22422, 909, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[771849, 22449, 1482, 37, 59, "StandardFormEquation"],
Cell[773334, 22488, 1577, 35, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[774972, 22530, 92, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[775089, 22536, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[775234, 22542, 598, 17, 48, "StandardFormEquation"],
Cell[775835, 22561, 688, 17, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[776560, 22583, 637, 18, 48, "StandardFormEquation"],
Cell[777200, 22603, 768, 20, 47, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[778017, 22629, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[778164, 22635, 702, 19, 50, "StandardFormEquation"],
Cell[778869, 22656, 863, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[779769, 22683, 921, 25, 48, "StandardFormEquation"],
Cell[780693, 22710, 1079, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[781809, 22742, 959, 26, 50, "StandardFormEquation"],
Cell[782771, 22770, 1119, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[783927, 22803, 1094, 29, 49, "StandardFormEquation"],
Cell[785024, 22834, 1322, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[786383, 22871, 1132, 30, 49, "StandardFormEquation"],
Cell[787518, 22903, 1362, 33, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[788917, 22941, 780, 22, 50, "StandardFormEquation"],
Cell[789700, 22965, 900, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[790637, 22993, 727, 20, 50, "StandardFormEquation"],
Cell[791367, 23015, 903, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[792307, 23044, 843, 23, 50, "StandardFormEquation"],
Cell[793153, 23069, 997, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[794187, 23100, 702, 20, 27, "StandardFormEquation"],
Cell[794892, 23122, 824, 21, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[795753, 23148, 736, 21, 45, "StandardFormEquation"],
Cell[796492, 23171, 860, 22, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[797389, 23198, 626, 17, 47, "StandardFormEquation"],
Cell[798018, 23217, 766, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[798821, 23241, 776, 22, 50, "StandardFormEquation"],
Cell[799600, 23265, 941, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[800578, 23295, 727, 20, 50, "StandardFormEquation"],
Cell[801308, 23317, 903, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[802248, 23346, 852, 23, 67, "StandardFormEquation"],
Cell[803103, 23371, 1032, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[804172, 23403, 624, 17, 47, "StandardFormEquation"],
Cell[804799, 23422, 764, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[805600, 23446, 1056, 29, 67, "StandardFormEquation"],
Cell[806659, 23477, 1233, 31, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[807929, 23513, 1142, 31, 67, "StandardFormEquation"],
Cell[809074, 23546, 1349, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[810460, 23585, 706, 19, 43, "StandardFormEquation"],
Cell[811169, 23606, 863, 21, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[812069, 23632, 691, 19, 49, "StandardFormEquation"],
Cell[812763, 23653, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[813652, 23680, 816, 22, 65, "StandardFormEquation"],
Cell[814471, 23704, 981, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[815489, 23734, 802, 23, 49, "StandardFormEquation"],
Cell[816294, 23759, 941, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[817272, 23789, 852, 24, 47, "StandardFormEquation"],
Cell[818127, 23815, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[819170, 23846, 888, 25, 49, "StandardFormEquation"],
Cell[820061, 23873, 1044, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[821142, 23905, 888, 25, 49, "StandardFormEquation"],
Cell[822033, 23932, 1044, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[823114, 23964, 924, 26, 50, "StandardFormEquation"],
Cell[824041, 23992, 1095, 29, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[825173, 24026, 888, 25, 49, "StandardFormEquation"],
Cell[826064, 24053, 1044, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[827145, 24085, 839, 23, 47, "StandardFormEquation"],
Cell[827987, 24110, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[829030, 24141, 562, 16, 29, "StandardFormEquation"],
Cell[829595, 24159, 689, 18, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[830321, 24182, 582, 16, 49, "StandardFormEquation"],
Cell[830906, 24200, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[831667, 24224, 616, 17, 50, "StandardFormEquation"],
Cell[832286, 24243, 760, 20, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[833083, 24268, 582, 16, 49, "StandardFormEquation"],
Cell[833668, 24286, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[834429, 24310, 691, 19, 49, "StandardFormEquation"],
Cell[835123, 24331, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[836012, 24358, 988, 27, 48, "StandardFormEquation"],
Cell[837003, 24387, 1173, 30, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[838213, 24422, 764, 21, 48, "StandardFormEquation"],
Cell[838980, 24445, 914, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[839931, 24474, 888, 25, 48, "StandardFormEquation"],
Cell[840822, 24501, 1044, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[841903, 24533, 779, 22, 48, "StandardFormEquation"],
Cell[842685, 24557, 916, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[843638, 24586, 935, 25, 48, "StandardFormEquation"],
Cell[844576, 24613, 1123, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[845736, 24647, 730, 20, 47, "StandardFormEquation"],
Cell[846469, 24669, 878, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[847384, 24697, 839, 23, 47, "StandardFormEquation"],
Cell[848226, 24722, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[849269, 24753, 839, 23, 47, "StandardFormEquation"],
Cell[850111, 24778, 1006, 26, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[851154, 24809, 740, 21, 50, "StandardFormEquation"],
Cell[851897, 24832, 890, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[852824, 24860, 776, 22, 47, "StandardFormEquation"],
Cell[853603, 24884, 913, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[854553, 24913, 727, 20, 50, "StandardFormEquation"],
Cell[855283, 24935, 903, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[856223, 24964, 795, 22, 47, "StandardFormEquation"],
Cell[857021, 24988, 964, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[858022, 25017, 904, 25, 47, "StandardFormEquation"],
Cell[858929, 25044, 1092, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[860058, 25076, 904, 25, 47, "StandardFormEquation"],
Cell[860965, 25103, 1092, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[862094, 25135, 1126, 30, 67, "StandardFormEquation"],
Cell[863223, 25167, 1347, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[864607, 25206, 673, 18, 43, "StandardFormEquation"],
Cell[865283, 25226, 828, 20, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[866148, 25251, 770, 21, 48, "StandardFormEquation"],
Cell[866921, 25274, 941, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[867899, 25303, 731, 20, 48, "StandardFormEquation"],
Cell[868633, 25325, 862, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[869532, 25352, 691, 19, 48, "StandardFormEquation"],
Cell[870226, 25373, 852, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[871115, 25400, 839, 23, 47, "StandardFormEquation"],
Cell[871957, 25425, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[873000, 25456, 866, 23, 48, "StandardFormEquation"],
Cell[873869, 25481, 1069, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[874975, 25513, 668, 18, 49, "StandardFormEquation"],
Cell[875646, 25533, 827, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[876510, 25559, 929, 25, 50, "StandardFormEquation"],
Cell[877442, 25586, 1100, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[878579, 25619, 691, 19, 49, "StandardFormEquation"],
Cell[879273, 25640, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[880162, 25667, 741, 20, 48, "StandardFormEquation"],
Cell[880906, 25689, 872, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[881815, 25716, 668, 18, 49, "StandardFormEquation"],
Cell[882486, 25736, 827, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[883350, 25762, 691, 19, 49, "StandardFormEquation"],
Cell[884044, 25783, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[884933, 25810, 822, 23, 47, "StandardFormEquation"],
Cell[885758, 25835, 961, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[886756, 25865, 797, 22, 47, "StandardFormEquation"],
Cell[887556, 25889, 934, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[888527, 25918, 797, 22, 47, "StandardFormEquation"],
Cell[889327, 25942, 934, 24, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[890298, 25971, 912, 25, 47, "StandardFormEquation"],
Cell[891213, 25998, 1068, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[892318, 26030, 912, 25, 47, "StandardFormEquation"],
Cell[893233, 26057, 1068, 27, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[894338, 26089, 950, 26, 49, "StandardFormEquation"],
Cell[895291, 26117, 1108, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[896436, 26150, 988, 27, 49, "StandardFormEquation"],
Cell[897427, 26179, 1163, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[898627, 26214, 988, 27, 50, "StandardFormEquation"],
Cell[899618, 26243, 1163, 30, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[900818, 26278, 950, 26, 49, "StandardFormEquation"],
Cell[901771, 26306, 1108, 28, 48, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[902928, 26340, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[903074, 26346, 800, 21, 49, "StandardFormEquation"],
Cell[903877, 26369, 993, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[904907, 26399, 710, 19, 49, "StandardFormEquation"],
Cell[905620, 26420, 886, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[906543, 26448, 843, 22, 49, "StandardFormEquation"],
Cell[907389, 26472, 1078, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[908504, 26505, 657, 18, 29, "StandardFormEquation"],
Cell[909164, 26525, 821, 22, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[910022, 26552, 938, 24, 65, "StandardFormEquation"],
Cell[910963, 26578, 1196, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[912196, 26613, 891, 24, 48, "StandardFormEquation"],
Cell[913090, 26639, 1069, 26, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[914196, 26670, 798, 22, 50, "StandardFormEquation"],
Cell[914997, 26694, 944, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[915978, 26723, 707, 20, 29, "StandardFormEquation"],
Cell[916688, 26745, 857, 22, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[917582, 26772, 769, 21, 43, "StandardFormEquation"],
Cell[918354, 26795, 889, 21, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[919280, 26821, 805, 21, 47, "StandardFormEquation"],
Cell[920088, 26844, 1023, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[921148, 26875, 621, 17, 27, "StandardFormEquation"],
Cell[921772, 26894, 772, 20, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[922581, 26919, 851, 23, 47, "StandardFormEquation"],
Cell[923435, 26944, 1010, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[924482, 26973, 760, 21, 49, "StandardFormEquation"],
Cell[925245, 26996, 889, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[926171, 27023, 792, 22, 27, "StandardFormEquation"],
Cell[926966, 27047, 948, 23, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[927951, 27075, 694, 19, 47, "StandardFormEquation"],
Cell[928648, 27096, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[929536, 27122, 712, 19, 47, "StandardFormEquation"],
Cell[930251, 27143, 884, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[931172, 27170, 735, 20, 47, "StandardFormEquation"],
Cell[931910, 27192, 909, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[932856, 27220, 784, 22, 48, "StandardFormEquation"],
Cell[933643, 27244, 947, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[934627, 27273, 735, 20, 47, "StandardFormEquation"],
Cell[935365, 27295, 909, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[936311, 27323, 626, 17, 47, "StandardFormEquation"],
Cell[936940, 27342, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[937758, 27367, 623, 17, 48, "StandardFormEquation"],
Cell[938384, 27386, 776, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[939197, 27411, 694, 19, 47, "StandardFormEquation"],
Cell[939894, 27432, 851, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[940782, 27458, 840, 23, 48, "StandardFormEquation"],
Cell[941625, 27483, 1015, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[942677, 27513, 676, 19, 48, "StandardFormEquation"],
Cell[943356, 27534, 813, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[944206, 27559, 797, 22, 48, "StandardFormEquation"],
Cell[945006, 27583, 953, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[945996, 27611, 721, 20, 48, "StandardFormEquation"],
Cell[946720, 27633, 869, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[947626, 27660, 678, 19, 48, "StandardFormEquation"],
Cell[948307, 27681, 807, 20, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[949151, 27706, 744, 20, 47, "StandardFormEquation"],
Cell[949898, 27728, 903, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[950838, 27755, 672, 18, 47, "StandardFormEquation"],
Cell[951513, 27775, 831, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[952381, 27801, 660, 18, 48, "StandardFormEquation"],
Cell[953044, 27821, 815, 21, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[953896, 27847, 1221, 31, 99, "StandardFormEquation"],
Cell[955120, 27880, 1287, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[956444, 27914, 916, 25, 47, "StandardFormEquation"],
Cell[957363, 27941, 1043, 25, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[958443, 27971, 793, 22, 47, "StandardFormEquation"],
Cell[959239, 27995, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[960179, 28022, 856, 23, 47, "StandardFormEquation"],
Cell[961038, 28047, 1016, 25, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[962091, 28077, 739, 20, 48, "StandardFormEquation"],
Cell[962833, 28099, 866, 21, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[963736, 28125, 677, 19, 29, "StandardFormEquation"],
Cell[964416, 28146, 814, 20, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[965267, 28171, 619, 17, 48, "StandardFormEquation"],
Cell[965889, 28190, 759, 19, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[966685, 28214, 734, 20, 48, "StandardFormEquation"],
Cell[967422, 28236, 893, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[968352, 28263, 1180, 30, 99, "StandardFormEquation"],
Cell[969535, 28295, 1282, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[970854, 28329, 638, 18, 48, "StandardFormEquation"],
Cell[971495, 28349, 773, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[972305, 28373, 694, 19, 47, "StandardFormEquation"],
Cell[973002, 28394, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[973890, 28420, 579, 16, 47, "StandardFormEquation"],
Cell[974472, 28438, 717, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[975226, 28461, 579, 16, 47, "StandardFormEquation"],
Cell[975808, 28479, 717, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[976562, 28502, 639, 18, 47, "StandardFormEquation"],
Cell[977204, 28522, 774, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[978015, 28546, 748, 21, 47, "StandardFormEquation"],
Cell[978766, 28569, 902, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[979705, 28596, 639, 18, 47, "StandardFormEquation"],
Cell[980347, 28616, 774, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[981158, 28640, 623, 17, 47, "StandardFormEquation"],
Cell[981784, 28659, 763, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[982584, 28683, 759, 20, 47, "StandardFormEquation"],
Cell[983346, 28705, 948, 24, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[984331, 28734, 792, 21, 47, "StandardFormEquation"],
Cell[985126, 28757, 983, 25, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[986146, 28787, 593, 16, 27, "StandardFormEquation"],
Cell[986742, 28805, 742, 19, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[987521, 28829, 626, 17, 47, "StandardFormEquation"],
Cell[988150, 28848, 779, 20, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[988966, 28873, 993, 27, 49, "StandardFormEquation"],
Cell[989962, 28902, 1206, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[991205, 28937, 780, 21, 47, "StandardFormEquation"],
Cell[991988, 28960, 954, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[992979, 28988, 665, 18, 47, "StandardFormEquation"],
Cell[993647, 29008, 820, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[994504, 29033, 748, 21, 47, "StandardFormEquation"],
Cell[995255, 29056, 902, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[996194, 29083, 851, 22, 65, "StandardFormEquation"],
Cell[997048, 29107, 1059, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[998144, 29138, 1036, 27, 65, "StandardFormEquation"],
Cell[999183, 29167, 1199, 28, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1000419, 29200, 729, 20, 47, "StandardFormEquation"],
Cell[1001151, 29222, 888, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1002076, 29249, 815, 22, 47, "StandardFormEquation"],
Cell[1002894, 29273, 991, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1003922, 29302, 845, 23, 48, "StandardFormEquation"],
Cell[1004770, 29327, 1036, 26, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1005843, 29358, 831, 23, 49, "StandardFormEquation"],
Cell[1006677, 29383, 943, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1007657, 29411, 943, 24, 65, "StandardFormEquation"],
Cell[1008603, 29437, 1163, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1009803, 29471, 858, 24, 48, "StandardFormEquation"],
Cell[1010664, 29497, 1023, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1011724, 29527, 585, 16, 47, "StandardFormEquation"],
Cell[1012312, 29545, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1013072, 29568, 984, 25, 81, "StandardFormEquation"],
Cell[1014059, 29595, 1211, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1015307, 29629, 796, 21, 65, "StandardFormEquation"],
Cell[1016106, 29652, 970, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1017113, 29680, 1082, 27, 99, "StandardFormEquation"],
Cell[1018198, 29709, 1378, 34, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1019613, 29748, 585, 16, 47, "StandardFormEquation"],
Cell[1020201, 29766, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1020961, 29789, 793, 22, 47, "StandardFormEquation"],
Cell[1021757, 29813, 903, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1022697, 29840, 911, 24, 81, "StandardFormEquation"],
Cell[1023611, 29866, 1104, 26, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1024764, 29898, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1024910, 29904, 675, 18, 47, "StandardFormEquation"],
Cell[1025588, 29924, 830, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1026455, 29949, 694, 19, 47, "StandardFormEquation"],
Cell[1027152, 29970, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1028040, 29996, 784, 21, 47, "StandardFormEquation"],
Cell[1028827, 30019, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1029846, 30049, 92, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[1029963, 30055, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1030108, 30061, 721, 21, 48, "StandardFormEquation"],
Cell[1030832, 30084, 785, 20, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1031654, 30109, 656, 19, 48, "StandardFormEquation"],
Cell[1032313, 30130, 740, 19, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1033090, 30154, 841, 22, 49, "StandardFormEquation"],
Cell[1033934, 30178, 999, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1034970, 30208, 756, 21, 50, "StandardFormEquation"],
Cell[1035729, 30231, 911, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1036677, 30259, 692, 20, 50, "StandardFormEquation"],
Cell[1037372, 30281, 791, 21, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1038200, 30307, 890, 24, 50, "StandardFormEquation"],
Cell[1039093, 30333, 1037, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1040167, 30364, 646, 18, 50, "StandardFormEquation"],
Cell[1040816, 30384, 760, 20, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1041613, 30409, 929, 25, 50, "StandardFormEquation"],
Cell[1042545, 30436, 1084, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1043666, 30468, 612, 17, 49, "StandardFormEquation"],
Cell[1044281, 30487, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1045054, 30512, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1045201, 30518, 740, 21, 50, "StandardFormEquation"],
Cell[1045944, 30541, 903, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1046884, 30570, 704, 20, 48, "StandardFormEquation"],
Cell[1047591, 30592, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1048480, 30619, 780, 22, 50, "StandardFormEquation"],
Cell[1049263, 30643, 900, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1050200, 30671, 846, 23, 50, "StandardFormEquation"],
Cell[1051049, 30696, 1018, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1052104, 30726, 674, 19, 50, "StandardFormEquation"],
Cell[1052781, 30747, 822, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1053640, 30773, 638, 18, 48, "StandardFormEquation"],
Cell[1054281, 30793, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1055089, 30817, 790, 22, 50, "StandardFormEquation"],
Cell[1055882, 30841, 916, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1056835, 30869, 831, 23, 50, "StandardFormEquation"],
Cell[1057669, 30894, 1013, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1058719, 30925, 816, 22, 47, "StandardFormEquation"],
Cell[1059538, 30949, 981, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1060556, 30979, 852, 23, 49, "StandardFormEquation"],
Cell[1061411, 31004, 1032, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1062480, 31036, 626, 17, 47, "StandardFormEquation"],
Cell[1063109, 31055, 766, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1063912, 31079, 710, 20, 50, "StandardFormEquation"],
Cell[1064625, 31101, 873, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1065535, 31129, 588, 17, 50, "StandardFormEquation"],
Cell[1066126, 31148, 719, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1066882, 31172, 822, 23, 50, "StandardFormEquation"],
Cell[1067707, 31197, 1011, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1068755, 31229, 886, 24, 68, "StandardFormEquation"],
Cell[1069644, 31255, 1068, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1070749, 31288, 917, 24, 65, "StandardFormEquation"],
Cell[1071669, 31314, 1097, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1072803, 31345, 917, 24, 65, "StandardFormEquation"],
Cell[1073723, 31371, 1097, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1074857, 31402, 701, 19, 49, "StandardFormEquation"],
Cell[1075561, 31423, 862, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1076460, 31450, 704, 20, 48, "StandardFormEquation"],
Cell[1077167, 31472, 852, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1078056, 31499, 912, 25, 50, "StandardFormEquation"],
Cell[1078971, 31526, 1100, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1080108, 31559, 638, 18, 48, "StandardFormEquation"],
Cell[1080749, 31579, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1081557, 31603, 725, 20, 43, "StandardFormEquation"],
Cell[1082285, 31625, 869, 23, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1083191, 31653, 552, 16, 48, "StandardFormEquation"],
Cell[1083746, 31671, 668, 17, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1084451, 31693, 786, 22, 50, "StandardFormEquation"],
Cell[1085240, 31717, 960, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1086237, 31747, 850, 23, 48, "StandardFormEquation"],
Cell[1087090, 31772, 1017, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1088144, 31803, 888, 25, 48, "StandardFormEquation"],
Cell[1089035, 31830, 1044, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1090116, 31862, 850, 23, 48, "StandardFormEquation"],
Cell[1090969, 31887, 1017, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1092023, 31918, 886, 24, 50, "StandardFormEquation"],
Cell[1092912, 31944, 1068, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1094017, 31977, 732, 20, 50, "StandardFormEquation"],
Cell[1094752, 31999, 863, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1095652, 32026, 731, 20, 48, "StandardFormEquation"],
Cell[1096386, 32048, 862, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1097285, 32075, 876, 24, 50, "StandardFormEquation"],
Cell[1098164, 32101, 1019, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1099220, 32131, 816, 22, 47, "StandardFormEquation"],
Cell[1100039, 32155, 981, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1101057, 32185, 698, 19, 49, "StandardFormEquation"],
Cell[1101758, 32206, 827, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1102622, 32232, 868, 23, 47, "StandardFormEquation"],
Cell[1103493, 32257, 1078, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1104608, 32289, 595, 17, 48, "StandardFormEquation"],
Cell[1105206, 32308, 724, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1105967, 32332, 552, 16, 48, "StandardFormEquation"],
Cell[1106522, 32350, 668, 17, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1107227, 32372, 588, 17, 50, "StandardFormEquation"],
Cell[1107818, 32391, 719, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1108574, 32415, 704, 20, 48, "StandardFormEquation"],
Cell[1109281, 32437, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1110170, 32464, 638, 18, 48, "StandardFormEquation"],
Cell[1110811, 32484, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1111619, 32508, 638, 18, 48, "StandardFormEquation"],
Cell[1112260, 32528, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1113068, 32552, 710, 20, 50, "StandardFormEquation"],
Cell[1113781, 32574, 860, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1114678, 32601, 674, 19, 50, "StandardFormEquation"],
Cell[1115355, 32622, 809, 20, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1116201, 32647, 841, 22, 49, "StandardFormEquation"],
Cell[1117045, 32671, 999, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1118081, 32701, 1019, 27, 50, "StandardFormEquation"],
Cell[1119103, 32730, 1191, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1120331, 32764, 1109, 29, 68, "StandardFormEquation"],
Cell[1121443, 32795, 1298, 31, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1122778, 32831, 691, 19, 48, "StandardFormEquation"],
Cell[1123472, 32852, 852, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1124361, 32879, 846, 23, 50, "StandardFormEquation"],
Cell[1125210, 32904, 1019, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1126266, 32934, 931, 24, 49, "StandardFormEquation"],
Cell[1127200, 32960, 1106, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1128343, 32992, 668, 18, 49, "StandardFormEquation"],
Cell[1129014, 33012, 826, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1129877, 33038, 846, 23, 50, "StandardFormEquation"],
Cell[1130726, 33063, 1018, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1131781, 33093, 980, 26, 50, "StandardFormEquation"],
Cell[1132764, 33121, 1144, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1133945, 33154, 852, 23, 49, "StandardFormEquation"],
Cell[1134800, 33179, 1032, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1135869, 33211, 956, 25, 49, "StandardFormEquation"],
Cell[1136828, 33238, 1133, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1137998, 33271, 1019, 27, 50, "StandardFormEquation"],
Cell[1139020, 33300, 1191, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1140248, 33334, 1179, 31, 50, "StandardFormEquation"],
Cell[1141430, 33367, 1383, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1142850, 33406, 620, 17, 47, "StandardFormEquation"],
Cell[1143473, 33425, 760, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1144270, 33449, 664, 19, 48, "StandardFormEquation"],
Cell[1144937, 33470, 806, 21, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1145780, 33496, 925, 26, 48, "StandardFormEquation"],
Cell[1146708, 33524, 1026, 26, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1147771, 33555, 770, 21, 48, "StandardFormEquation"],
Cell[1148544, 33578, 941, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1149522, 33607, 879, 24, 48, "StandardFormEquation"],
Cell[1150404, 33633, 1069, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1151510, 33665, 831, 23, 50, "StandardFormEquation"],
Cell[1152344, 33690, 1013, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1153394, 33721, 691, 19, 48, "StandardFormEquation"],
Cell[1154088, 33742, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1154977, 33769, 582, 16, 48, "StandardFormEquation"],
Cell[1155562, 33787, 724, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1156323, 33811, 875, 24, 48, "StandardFormEquation"],
Cell[1157201, 33837, 1057, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1158295, 33870, 691, 19, 48, "StandardFormEquation"],
Cell[1158989, 33891, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1159878, 33918, 727, 20, 50, "StandardFormEquation"],
Cell[1160608, 33940, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1161535, 33968, 943, 26, 47, "StandardFormEquation"],
Cell[1162481, 33996, 1084, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1163602, 34029, 782, 21, 47, "StandardFormEquation"],
Cell[1164387, 34052, 934, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1165358, 34081, 730, 21, 43, "StandardFormEquation"],
Cell[1166091, 34104, 854, 22, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1166982, 34131, 897, 24, 47, "StandardFormEquation"],
Cell[1167882, 34157, 1068, 27, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1168999, 34190, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1169145, 34196, 710, 19, 49, "StandardFormEquation"],
Cell[1169858, 34217, 886, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1170781, 34245, 783, 22, 50, "StandardFormEquation"],
Cell[1171567, 34269, 955, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1172559, 34299, 816, 22, 49, "StandardFormEquation"],
Cell[1173378, 34323, 1005, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1174420, 34353, 823, 22, 49, "StandardFormEquation"],
Cell[1175246, 34377, 995, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1176278, 34408, 823, 22, 49, "StandardFormEquation"],
Cell[1177104, 34432, 995, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1178136, 34463, 885, 23, 65, "StandardFormEquation"],
Cell[1179024, 34488, 1059, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1180120, 34519, 780, 21, 47, "StandardFormEquation"],
Cell[1180903, 34542, 954, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1181894, 34570, 762, 20, 47, "StandardFormEquation"],
Cell[1182659, 34592, 938, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1183634, 34620, 916, 24, 65, "StandardFormEquation"],
Cell[1184553, 34646, 1090, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1185680, 34678, 938, 24, 65, "StandardFormEquation"],
Cell[1186621, 34704, 1196, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1187854, 34739, 1011, 26, 99, "StandardFormEquation"],
Cell[1188868, 34767, 1208, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1190113, 34800, 753, 20, 47, "StandardFormEquation"],
Cell[1190869, 34822, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1191850, 34851, 672, 18, 47, "StandardFormEquation"],
Cell[1192525, 34871, 831, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1193393, 34897, 735, 20, 47, "StandardFormEquation"],
Cell[1194131, 34919, 894, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1195062, 34946, 748, 21, 47, "StandardFormEquation"],
Cell[1195813, 34969, 902, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1196752, 34996, 639, 18, 47, "StandardFormEquation"],
Cell[1197394, 35016, 774, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1198205, 35040, 665, 18, 47, "StandardFormEquation"],
Cell[1198873, 35060, 820, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1199730, 35085, 579, 16, 47, "StandardFormEquation"],
Cell[1200312, 35103, 717, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1201066, 35126, 701, 19, 49, "StandardFormEquation"],
Cell[1201770, 35147, 871, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1202678, 35174, 579, 16, 47, "StandardFormEquation"],
Cell[1203260, 35192, 717, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1204014, 35215, 701, 19, 49, "StandardFormEquation"],
Cell[1204718, 35236, 871, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1205626, 35263, 665, 18, 47, "StandardFormEquation"],
Cell[1206294, 35283, 820, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1207151, 35308, 694, 19, 47, "StandardFormEquation"],
Cell[1207848, 35329, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1208736, 35355, 792, 21, 47, "StandardFormEquation"],
Cell[1209531, 35378, 985, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1210553, 35408, 759, 20, 47, "StandardFormEquation"],
Cell[1211315, 35430, 950, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1212302, 35459, 927, 25, 66, "StandardFormEquation"],
Cell[1213232, 35486, 1132, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1214401, 35519, 954, 25, 65, "StandardFormEquation"],
Cell[1215358, 35546, 1181, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1216576, 35580, 710, 19, 47, "StandardFormEquation"],
Cell[1217289, 35601, 867, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1218193, 35627, 1208, 31, 65, "StandardFormEquation"],
Cell[1219404, 35660, 1473, 35, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1220914, 35700, 885, 23, 47, "StandardFormEquation"],
Cell[1221802, 35725, 1059, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1222898, 35756, 787, 21, 47, "StandardFormEquation"],
Cell[1223688, 35779, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1224669, 35808, 1046, 27, 49, "StandardFormEquation"],
Cell[1225718, 35837, 1240, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1226995, 35872, 789, 21, 49, "StandardFormEquation"],
Cell[1227787, 35895, 995, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1228819, 35926, 676, 19, 48, "StandardFormEquation"],
Cell[1229498, 35947, 813, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1230348, 35972, 773, 22, 48, "StandardFormEquation"],
Cell[1231124, 35996, 889, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1232050, 36023, 623, 17, 47, "StandardFormEquation"],
Cell[1232676, 36042, 763, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1233476, 36066, 724, 20, 47, "StandardFormEquation"],
Cell[1234203, 36088, 851, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1235091, 36114, 873, 23, 49, "StandardFormEquation"],
Cell[1235967, 36139, 1067, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1237071, 36170, 792, 21, 47, "StandardFormEquation"],
Cell[1237866, 36193, 985, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1238888, 36223, 759, 20, 47, "StandardFormEquation"],
Cell[1239650, 36245, 948, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1240635, 36274, 954, 25, 65, "StandardFormEquation"],
Cell[1241592, 36301, 1179, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1242808, 36335, 1066, 28, 82, "StandardFormEquation"],
Cell[1243877, 36365, 1290, 31, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1245204, 36401, 772, 21, 47, "StandardFormEquation"],
Cell[1245979, 36424, 943, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1246959, 36452, 858, 24, 48, "StandardFormEquation"],
Cell[1247820, 36478, 1023, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1248880, 36508, 1015, 26, 99, "StandardFormEquation"],
Cell[1249898, 36536, 1176, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1251111, 36568, 816, 22, 49, "StandardFormEquation"],
Cell[1251930, 36592, 1005, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1252972, 36622, 694, 19, 47, "StandardFormEquation"],
Cell[1253669, 36643, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1254557, 36669, 976, 25, 65, "StandardFormEquation"],
Cell[1255536, 36696, 1196, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1256769, 36731, 863, 24, 48, "StandardFormEquation"],
Cell[1257635, 36757, 996, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1258668, 36786, 1217, 31, 99, "StandardFormEquation"],
Cell[1259888, 36819, 1319, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1261244, 36854, 585, 16, 47, "StandardFormEquation"],
Cell[1261832, 36872, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1262592, 36895, 710, 19, 47, "StandardFormEquation"],
Cell[1263305, 36916, 867, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1264209, 36942, 796, 21, 65, "StandardFormEquation"],
Cell[1265008, 36965, 970, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1266015, 36993, 1208, 31, 75, "StandardFormEquation"],
Cell[1267226, 37026, 1473, 35, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1268736, 37066, 1170, 30, 100, "StandardFormEquation"],
Cell[1269909, 37098, 1463, 36, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1271409, 37139, 796, 21, 65, "StandardFormEquation"],
Cell[1272208, 37162, 970, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1273215, 37190, 1537, 38, 77, "StandardFormEquation"],
Cell[1274755, 37230, 1739, 40, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1276531, 37275, 638, 18, 48, "StandardFormEquation"],
Cell[1277172, 37295, 776, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1277985, 37320, 694, 19, 47, "StandardFormEquation"],
Cell[1278682, 37341, 851, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1279570, 37367, 753, 20, 47, "StandardFormEquation"],
Cell[1280326, 37389, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1281307, 37418, 820, 22, 48, "StandardFormEquation"],
Cell[1282130, 37442, 1009, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1283176, 37472, 851, 22, 65, "StandardFormEquation"],
Cell[1284030, 37496, 1059, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1285126, 37527, 730, 20, 48, "StandardFormEquation"],
Cell[1285859, 37549, 902, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1286798, 37577, 789, 21, 49, "StandardFormEquation"],
Cell[1287590, 37600, 995, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1288622, 37631, 579, 16, 47, "StandardFormEquation"],
Cell[1289204, 37649, 717, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1289958, 37672, 626, 17, 47, "StandardFormEquation"],
Cell[1290587, 37691, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1291405, 37716, 615, 17, 48, "StandardFormEquation"],
Cell[1292023, 37735, 768, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1292828, 37760, 662, 18, 49, "StandardFormEquation"],
Cell[1293493, 37780, 832, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1294362, 37807, 712, 19, 47, "StandardFormEquation"],
Cell[1295077, 37828, 884, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1295998, 37855, 626, 17, 47, "StandardFormEquation"],
Cell[1296627, 37874, 779, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1297443, 37899, 735, 20, 47, "StandardFormEquation"],
Cell[1298181, 37921, 907, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1299125, 37949, 1036, 27, 65, "StandardFormEquation"],
Cell[1300164, 37978, 1199, 28, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1301400, 38011, 1306, 34, 101, "StandardFormEquation"],
Cell[1302709, 38047, 1404, 33, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1304150, 38085, 1349, 34, 75, "StandardFormEquation"],
Cell[1305502, 38121, 1421, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1306960, 38158, 937, 25, 48, "StandardFormEquation"],
Cell[1307900, 38185, 1098, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1309035, 38217, 909, 24, 47, "StandardFormEquation"],
Cell[1309947, 38243, 1053, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1311037, 38273, 1120, 29, 59, "StandardFormEquation"],
Cell[1312160, 38304, 1353, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1313550, 38341, 796, 21, 65, "StandardFormEquation"],
Cell[1314349, 38364, 970, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1315356, 38392, 1208, 31, 75, "StandardFormEquation"],
Cell[1316567, 38425, 1473, 35, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1318077, 38465, 997, 26, 65, "StandardFormEquation"],
Cell[1319077, 38493, 1194, 28, 45, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1320320, 38527, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1320466, 38533, 744, 20, 47, "StandardFormEquation"],
Cell[1321213, 38555, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1322153, 38582, 814, 22, 47, "StandardFormEquation"],
Cell[1322970, 38606, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1323965, 38634, 1495, 37, 75, "StandardFormEquation"],
Cell[1325463, 38673, 1629, 36, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1327129, 38714, 784, 21, 47, "StandardFormEquation"],
Cell[1327916, 38737, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1328911, 38765, 694, 19, 47, "StandardFormEquation"],
Cell[1329608, 38786, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1330496, 38812, 753, 20, 47, "StandardFormEquation"],
Cell[1331252, 38834, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1332233, 38863, 1505, 38, 91, "StandardFormEquation"],
Cell[1333741, 38903, 1656, 37, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1335458, 38947, 92, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[1335575, 38953, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1335720, 38959, 832, 23, 47, "StandardFormEquation"],
Cell[1336555, 38984, 971, 25, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1337575, 39015, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1337722, 39021, 935, 25, 49, "StandardFormEquation"],
Cell[1338660, 39048, 1123, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1339820, 39082, 668, 18, 49, "StandardFormEquation"],
Cell[1340491, 39102, 827, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1341355, 39128, 691, 19, 49, "StandardFormEquation"],
Cell[1342049, 39149, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1342938, 39176, 743, 21, 47, "StandardFormEquation"],
Cell[1343684, 39199, 878, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1344599, 39227, 852, 24, 47, "StandardFormEquation"],
Cell[1345454, 39253, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1346497, 39284, 740, 21, 50, "StandardFormEquation"],
Cell[1347240, 39307, 890, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1348167, 39335, 691, 19, 49, "StandardFormEquation"],
Cell[1348861, 39356, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1349750, 39383, 782, 21, 47, "StandardFormEquation"],
Cell[1350535, 39406, 934, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1351506, 39435, 582, 16, 49, "StandardFormEquation"],
Cell[1352091, 39453, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1352852, 39477, 839, 23, 47, "StandardFormEquation"],
Cell[1353694, 39502, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1354737, 39533, 875, 24, 49, "StandardFormEquation"],
Cell[1355615, 39559, 1044, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1356696, 39591, 839, 23, 47, "StandardFormEquation"],
Cell[1357538, 39616, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1358581, 39647, 839, 23, 47, "StandardFormEquation"],
Cell[1359423, 39672, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1360466, 39703, 741, 20, 48, "StandardFormEquation"],
Cell[1361210, 39725, 872, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1362119, 39752, 950, 26, 49, "StandardFormEquation"],
Cell[1363072, 39780, 1123, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1364232, 39814, 730, 20, 47, "StandardFormEquation"],
Cell[1364965, 39836, 878, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1365880, 39864, 740, 21, 50, "StandardFormEquation"],
Cell[1366623, 39887, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1367550, 39915, 668, 18, 49, "StandardFormEquation"],
Cell[1368221, 39935, 827, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1369085, 39961, 691, 19, 49, "StandardFormEquation"],
Cell[1369779, 39982, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1370668, 40009, 727, 20, 50, "StandardFormEquation"],
Cell[1371398, 40031, 903, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1372338, 40060, 691, 19, 49, "StandardFormEquation"],
Cell[1373032, 40081, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1373921, 40108, 616, 17, 50, "StandardFormEquation"],
Cell[1374540, 40127, 760, 20, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1375337, 40152, 924, 26, 50, "StandardFormEquation"],
Cell[1376264, 40180, 1095, 29, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1377396, 40214, 1056, 29, 49, "StandardFormEquation"],
Cell[1378455, 40245, 1246, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1379738, 40282, 776, 22, 50, "StandardFormEquation"],
Cell[1380517, 40306, 941, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1381495, 40336, 551, 15, 29, "StandardFormEquation"],
Cell[1382049, 40353, 689, 18, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1382775, 40376, 1026, 28, 49, "StandardFormEquation"],
Cell[1383804, 40406, 1246, 31, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1385087, 40442, 1088, 29, 47, "StandardFormEquation"],
Cell[1386178, 40473, 1307, 33, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1387522, 40511, 852, 24, 47, "StandardFormEquation"],
Cell[1388377, 40537, 1006, 26, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1389420, 40568, 852, 24, 47, "StandardFormEquation"],
Cell[1390275, 40594, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1391318, 40625, 888, 25, 49, "StandardFormEquation"],
Cell[1392209, 40652, 1057, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1393303, 40685, 582, 16, 49, "StandardFormEquation"],
Cell[1393888, 40703, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1394649, 40727, 875, 24, 49, "StandardFormEquation"],
Cell[1395527, 40753, 1057, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1396621, 40786, 966, 26, 47, "StandardFormEquation"],
Cell[1397590, 40814, 1160, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1398787, 40847, 702, 19, 50, "StandardFormEquation"],
Cell[1399492, 40868, 863, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1400392, 40895, 740, 21, 50, "StandardFormEquation"],
Cell[1401135, 40918, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1402062, 40946, 950, 26, 48, "StandardFormEquation"],
Cell[1403015, 40974, 1118, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1404170, 41007, 950, 26, 48, "StandardFormEquation"],
Cell[1405123, 41035, 1118, 28, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1406290, 41069, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1406436, 41075, 744, 20, 47, "StandardFormEquation"],
Cell[1407183, 41097, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1408123, 41124, 672, 18, 47, "StandardFormEquation"],
Cell[1408798, 41144, 831, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1409666, 41170, 787, 21, 47, "StandardFormEquation"],
Cell[1410456, 41193, 965, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1411458, 41222, 841, 23, 47, "StandardFormEquation"],
Cell[1412302, 41247, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1413324, 41276, 585, 16, 47, "StandardFormEquation"],
Cell[1413912, 41294, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1414672, 41317, 735, 20, 47, "StandardFormEquation"],
Cell[1415410, 41339, 894, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1416341, 41366, 802, 22, 47, "StandardFormEquation"],
Cell[1417146, 41390, 958, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1418141, 41418, 623, 17, 47, "StandardFormEquation"],
Cell[1418767, 41437, 763, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1419567, 41461, 744, 20, 47, "StandardFormEquation"],
Cell[1420314, 41483, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1421254, 41510, 604, 17, 27, "StandardFormEquation"],
Cell[1421861, 41529, 737, 18, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1422635, 41552, 626, 17, 47, "StandardFormEquation"],
Cell[1423264, 41571, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1424082, 41596, 660, 18, 48, "StandardFormEquation"],
Cell[1424745, 41616, 817, 21, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1425599, 41642, 626, 17, 47, "StandardFormEquation"],
Cell[1426228, 41661, 781, 20, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1427046, 41686, 735, 20, 47, "StandardFormEquation"],
Cell[1427784, 41708, 909, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1428730, 41736, 724, 20, 47, "StandardFormEquation"],
Cell[1429457, 41758, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1430345, 41784, 771, 21, 48, "StandardFormEquation"],
Cell[1431119, 41807, 958, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1432114, 41837, 743, 21, 48, "StandardFormEquation"],
Cell[1432860, 41860, 889, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1433786, 41887, 858, 24, 48, "StandardFormEquation"],
Cell[1434647, 41913, 1023, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1435707, 41943, 789, 21, 49, "StandardFormEquation"],
Cell[1436499, 41966, 978, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1437514, 41996, 730, 20, 48, "StandardFormEquation"],
Cell[1438247, 42018, 902, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1439186, 42046, 845, 23, 48, "StandardFormEquation"],
Cell[1440034, 42071, 1036, 26, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1441107, 42102, 1308, 33, 59, "StandardFormEquation"],
Cell[1442418, 42137, 1416, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1443871, 42174, 626, 17, 47, "StandardFormEquation"],
Cell[1444500, 42193, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1445318, 42218, 615, 17, 48, "StandardFormEquation"],
Cell[1445936, 42237, 768, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1446741, 42262, 662, 18, 49, "StandardFormEquation"],
Cell[1447406, 42282, 832, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1448275, 42309, 626, 17, 47, "StandardFormEquation"],
Cell[1448904, 42328, 781, 20, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1449722, 42353, 735, 20, 47, "StandardFormEquation"],
Cell[1450460, 42375, 909, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1451406, 42403, 903, 25, 47, "StandardFormEquation"],
Cell[1452312, 42430, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1453334, 42459, 820, 22, 47, "StandardFormEquation"],
Cell[1454157, 42483, 1016, 25, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1455210, 42513, 754, 20, 47, "StandardFormEquation"],
Cell[1455967, 42535, 913, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1456917, 42562, 669, 18, 48, "StandardFormEquation"],
Cell[1457589, 42582, 828, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1458454, 42608, 798, 22, 50, "StandardFormEquation"],
Cell[1459255, 42632, 957, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1460249, 42662, 724, 20, 47, "StandardFormEquation"],
Cell[1460976, 42684, 851, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1461864, 42710, 712, 19, 47, "StandardFormEquation"],
Cell[1462579, 42731, 882, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1463498, 42758, 735, 20, 47, "StandardFormEquation"],
Cell[1464236, 42780, 907, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1465180, 42808, 737, 20, 27, "StandardFormEquation"],
Cell[1465920, 42830, 889, 21, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1466846, 42856, 809, 22, 47, "StandardFormEquation"],
Cell[1467658, 42880, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1468680, 42909, 880, 23, 47, "StandardFormEquation"],
Cell[1469563, 42934, 1090, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1470690, 42966, 694, 19, 47, "StandardFormEquation"],
Cell[1471387, 42987, 851, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1472275, 43013, 734, 20, 48, "StandardFormEquation"],
Cell[1473012, 43035, 893, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1473942, 43062, 694, 19, 47, "StandardFormEquation"],
Cell[1474639, 43083, 851, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1475527, 43109, 776, 21, 47, "StandardFormEquation"],
Cell[1476306, 43132, 903, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1477246, 43159, 997, 26, 47, "StandardFormEquation"],
Cell[1478246, 43187, 1194, 28, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1479477, 43220, 1308, 33, 59, "StandardFormEquation"],
Cell[1480788, 43255, 1416, 32, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1482253, 43293, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1482399, 43299, 784, 21, 47, "StandardFormEquation"],
Cell[1483186, 43322, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1484181, 43350, 675, 18, 47, "StandardFormEquation"],
Cell[1484859, 43370, 830, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1485726, 43395, 809, 22, 47, "StandardFormEquation"],
Cell[1486538, 43419, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1487584, 43450, 92, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[1487701, 43456, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1487846, 43462, 829, 24, 50, "StandardFormEquation"],
Cell[1488678, 43488, 912, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1489627, 43517, 616, 17, 50, "StandardFormEquation"],
Cell[1490246, 43536, 760, 20, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1491043, 43561, 565, 16, 46, "StandardFormEquation"],
Cell[1491611, 43579, 664, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1492312, 43602, 780, 22, 49, "StandardFormEquation"],
Cell[1493095, 43626, 874, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1494006, 43654, 709, 20, 49, "StandardFormEquation"],
Cell[1494718, 43676, 825, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1495580, 43703, 512, 15, 48, "StandardFormEquation"],
Cell[1496095, 43720, 585, 15, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1496717, 43740, 700, 20, 50, "StandardFormEquation"],
Cell[1497420, 43762, 813, 21, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1498270, 43788, 723, 20, 48, "StandardFormEquation"],
Cell[1498996, 43810, 871, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1499904, 43837, 759, 21, 50, "StandardFormEquation"],
Cell[1500666, 43860, 909, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1501612, 43888, 802, 23, 49, "StandardFormEquation"],
Cell[1502417, 43913, 941, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1503395, 43943, 480, 14, 29, "StandardFormEquation"],
Cell[1503878, 43959, 590, 16, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1504505, 43980, 866, 24, 50, "StandardFormEquation"],
Cell[1505374, 44006, 1043, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1506454, 44038, 582, 16, 49, "StandardFormEquation"],
Cell[1507039, 44056, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1507800, 44080, 582, 16, 49, "StandardFormEquation"],
Cell[1508385, 44098, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1509146, 44122, 707, 20, 47, "StandardFormEquation"],
Cell[1509856, 44144, 827, 22, 45, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1510732, 44172, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1510879, 44178, 916, 25, 50, "StandardFormEquation"],
Cell[1511798, 44205, 1103, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1512938, 44238, 727, 20, 50, "StandardFormEquation"],
Cell[1513668, 44260, 903, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1514608, 44289, 603, 17, 44, "StandardFormEquation"],
Cell[1515214, 44308, 702, 18, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1515953, 44331, 691, 19, 49, "StandardFormEquation"],
Cell[1516647, 44352, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1517536, 44379, 1004, 27, 49, "StandardFormEquation"],
Cell[1518543, 44408, 1200, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1519780, 44442, 856, 24, 50, "StandardFormEquation"],
Cell[1520639, 44468, 997, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1521673, 44499, 947, 26, 50, "StandardFormEquation"],
Cell[1522623, 44527, 1156, 30, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1523816, 44562, 911, 25, 50, "StandardFormEquation"],
Cell[1524730, 44589, 1105, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1525872, 44622, 727, 20, 50, "StandardFormEquation"],
Cell[1526602, 44644, 903, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1527542, 44673, 632, 18, 47, "StandardFormEquation"],
Cell[1528177, 44693, 729, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1528943, 44717, 898, 25, 48, "StandardFormEquation"],
Cell[1529844, 44744, 1067, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1530948, 44777, 624, 17, 47, "StandardFormEquation"],
Cell[1531575, 44796, 764, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1532376, 44820, 1142, 31, 49, "StandardFormEquation"],
Cell[1533521, 44853, 1349, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1534907, 44892, 1178, 32, 49, "StandardFormEquation"],
Cell[1536088, 44926, 1387, 35, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1537512, 44966, 1122, 31, 47, "StandardFormEquation"],
Cell[1538637, 44999, 1305, 34, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1539979, 45038, 852, 24, 47, "StandardFormEquation"],
Cell[1540834, 45064, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1541877, 45095, 888, 25, 49, "StandardFormEquation"],
Cell[1542768, 45122, 1044, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1543849, 45154, 888, 25, 49, "StandardFormEquation"],
Cell[1544740, 45181, 1044, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1545821, 45213, 770, 22, 50, "StandardFormEquation"],
Cell[1546594, 45237, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1547521, 45265, 929, 25, 50, "StandardFormEquation"],
Cell[1548453, 45292, 1100, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1549590, 45325, 1057, 28, 48, "StandardFormEquation"],
Cell[1550650, 45355, 1221, 31, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1551908, 45391, 626, 17, 47, "StandardFormEquation"],
Cell[1552537, 45410, 781, 20, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1553355, 45435, 585, 16, 47, "StandardFormEquation"],
Cell[1553943, 45453, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1554703, 45476, 582, 16, 49, "StandardFormEquation"],
Cell[1555288, 45494, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1556049, 45518, 582, 16, 49, "StandardFormEquation"],
Cell[1556634, 45536, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1557395, 45560, 691, 19, 49, "StandardFormEquation"],
Cell[1558089, 45581, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1558978, 45608, 1089, 29, 50, "StandardFormEquation"],
Cell[1560070, 45639, 1276, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1561383, 45676, 841, 22, 49, "StandardFormEquation"],
Cell[1562227, 45700, 999, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1563263, 45730, 899, 24, 50, "StandardFormEquation"],
Cell[1564165, 45756, 1100, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1565302, 45789, 839, 23, 47, "StandardFormEquation"],
Cell[1566144, 45814, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1567187, 45845, 1164, 30, 50, "StandardFormEquation"],
Cell[1568354, 45877, 1383, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1569774, 45916, 691, 19, 49, "StandardFormEquation"],
Cell[1570468, 45937, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1571357, 45964, 862, 24, 47, "StandardFormEquation"],
Cell[1572222, 45990, 1016, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1573275, 46021, 876, 23, 48, "StandardFormEquation"],
Cell[1574154, 46046, 1079, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1575270, 46078, 922, 25, 47, "StandardFormEquation"],
Cell[1576195, 46105, 1078, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1577310, 46137, 668, 18, 49, "StandardFormEquation"],
Cell[1577981, 46157, 827, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1578845, 46183, 691, 19, 49, "StandardFormEquation"],
Cell[1579539, 46204, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1580428, 46231, 956, 25, 49, "StandardFormEquation"],
Cell[1581387, 46258, 1133, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1582557, 46291, 904, 25, 47, "StandardFormEquation"],
Cell[1583464, 46318, 1092, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1584593, 46350, 940, 26, 49, "StandardFormEquation"],
Cell[1585536, 46378, 1130, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1586703, 46411, 973, 26, 65, "StandardFormEquation"],
Cell[1587679, 46439, 1173, 30, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1588889, 46474, 740, 20, 50, "StandardFormEquation"],
Cell[1589632, 46496, 918, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1590587, 46525, 706, 19, 49, "StandardFormEquation"],
Cell[1591296, 46546, 882, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1592215, 46574, 996, 27, 49, "StandardFormEquation"],
Cell[1593214, 46603, 1135, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1594386, 46637, 832, 23, 47, "StandardFormEquation"],
Cell[1595221, 46662, 971, 25, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1596229, 46692, 668, 18, 49, "StandardFormEquation"],
Cell[1596900, 46712, 827, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1597764, 46738, 942, 26, 50, "StandardFormEquation"],
Cell[1598709, 46766, 1100, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1599846, 46799, 862, 23, 49, "StandardFormEquation"],
Cell[1600711, 46824, 1067, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1601815, 46856, 902, 25, 50, "StandardFormEquation"],
Cell[1602720, 46883, 1028, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1603785, 46915, 709, 20, 49, "StandardFormEquation"],
Cell[1604497, 46937, 825, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1605359, 46964, 655, 18, 48, "StandardFormEquation"],
Cell[1606017, 46984, 769, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1606823, 47009, 843, 23, 50, "StandardFormEquation"],
Cell[1607669, 47034, 997, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1608703, 47065, 912, 24, 50, "StandardFormEquation"],
Cell[1609618, 47091, 1130, 29, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1610785, 47125, 511, 14, 27, "StandardFormEquation"],
Cell[1611299, 47141, 643, 17, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1611979, 47163, 795, 22, 49, "StandardFormEquation"],
Cell[1612777, 47187, 928, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1613742, 47216, 815, 22, 49, "StandardFormEquation"],
Cell[1614560, 47240, 1010, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1615607, 47271, 1032, 28, 50, "StandardFormEquation"],
Cell[1616642, 47301, 1251, 32, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1617930, 47338, 797, 22, 47, "StandardFormEquation"],
Cell[1618730, 47362, 934, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1619701, 47391, 797, 22, 47, "StandardFormEquation"],
Cell[1620501, 47415, 934, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1621472, 47444, 472, 13, 27, "StandardFormEquation"],
Cell[1621947, 47459, 591, 15, 28, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1622587, 47480, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1622733, 47486, 953, 26, 50, "StandardFormEquation"],
Cell[1623689, 47514, 1158, 29, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1624884, 47548, 829, 22, 50, "StandardFormEquation"],
Cell[1625716, 47572, 1028, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1626781, 47603, 772, 21, 50, "StandardFormEquation"],
Cell[1627556, 47626, 946, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1628539, 47655, 730, 20, 48, "StandardFormEquation"],
Cell[1629272, 47677, 902, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1630211, 47705, 768, 21, 50, "StandardFormEquation"],
Cell[1630982, 47728, 955, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1631974, 47758, 762, 21, 48, "StandardFormEquation"],
Cell[1632739, 47781, 906, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1633682, 47809, 798, 22, 50, "StandardFormEquation"],
Cell[1634483, 47833, 944, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1635464, 47862, 858, 23, 50, "StandardFormEquation"],
Cell[1636325, 47887, 1062, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1637424, 47919, 732, 20, 49, "StandardFormEquation"],
Cell[1638159, 47941, 904, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1639100, 47969, 760, 21, 49, "StandardFormEquation"],
Cell[1639863, 47992, 889, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1640789, 48019, 810, 22, 47, "StandardFormEquation"],
Cell[1641602, 48043, 954, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1642593, 48071, 784, 21, 47, "StandardFormEquation"],
Cell[1643380, 48094, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1644375, 48122, 1090, 28, 47, "StandardFormEquation"],
Cell[1645468, 48152, 1344, 33, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1646849, 48190, 735, 20, 47, "StandardFormEquation"],
Cell[1647587, 48212, 909, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1648533, 48240, 626, 17, 47, "StandardFormEquation"],
Cell[1649162, 48259, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1649980, 48284, 735, 20, 47, "StandardFormEquation"],
Cell[1650718, 48306, 909, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1651664, 48334, 862, 23, 47, "StandardFormEquation"],
Cell[1652529, 48359, 1072, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1653638, 48391, 753, 20, 47, "StandardFormEquation"],
Cell[1654394, 48413, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1655375, 48442, 585, 16, 47, "StandardFormEquation"],
Cell[1655963, 48460, 723, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1656723, 48483, 1037, 28, 47, "StandardFormEquation"],
Cell[1657763, 48513, 1263, 31, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1659063, 48549, 819, 22, 47, "StandardFormEquation"],
Cell[1659885, 48573, 995, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1660917, 48602, 809, 22, 47, "StandardFormEquation"],
Cell[1661729, 48626, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1662751, 48655, 700, 19, 47, "StandardFormEquation"],
Cell[1663454, 48676, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1664348, 48702, 693, 19, 44, "StandardFormEquation"],
Cell[1665044, 48723, 809, 20, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1665890, 48748, 809, 22, 47, "StandardFormEquation"],
Cell[1666702, 48772, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1667724, 48801, 732, 20, 48, "StandardFormEquation"],
Cell[1668459, 48823, 904, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1669400, 48851, 694, 19, 47, "StandardFormEquation"],
Cell[1670097, 48872, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1670985, 48898, 780, 21, 47, "StandardFormEquation"],
Cell[1671768, 48921, 954, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1672759, 48949, 947, 25, 48, "StandardFormEquation"],
Cell[1673709, 48976, 1162, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1674908, 49010, 710, 19, 47, "StandardFormEquation"],
Cell[1675621, 49031, 867, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1676525, 49057, 633, 17, 47, "StandardFormEquation"],
Cell[1677161, 49076, 773, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1677971, 49100, 626, 17, 47, "StandardFormEquation"],
Cell[1678600, 49119, 779, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1679416, 49144, 759, 20, 47, "StandardFormEquation"],
Cell[1680178, 49166, 948, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1681163, 49195, 865, 24, 47, "StandardFormEquation"],
Cell[1682031, 49221, 966, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1683034, 49250, 1214, 33, 48, "StandardFormEquation"],
Cell[1684251, 49285, 1425, 35, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1685713, 49325, 700, 19, 47, "StandardFormEquation"],
Cell[1686416, 49346, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1687310, 49372, 847, 23, 49, "StandardFormEquation"],
Cell[1688160, 49397, 1038, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1689235, 49428, 1105, 29, 49, "StandardFormEquation"],
Cell[1690343, 49459, 1289, 31, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1691669, 49495, 734, 20, 47, "StandardFormEquation"],
Cell[1692406, 49517, 861, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1693304, 49543, 829, 22, 47, "StandardFormEquation"],
Cell[1694136, 49567, 1005, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1695178, 49596, 753, 20, 47, "StandardFormEquation"],
Cell[1695934, 49618, 927, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1696898, 49646, 643, 18, 27, "StandardFormEquation"],
Cell[1697544, 49666, 778, 19, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1698359, 49690, 585, 16, 47, "StandardFormEquation"],
Cell[1698947, 49708, 723, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1699707, 49731, 694, 19, 47, "StandardFormEquation"],
Cell[1700404, 49752, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1701292, 49778, 700, 19, 47, "StandardFormEquation"],
Cell[1701995, 49799, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1702889, 49825, 796, 21, 47, "StandardFormEquation"],
Cell[1703688, 49848, 970, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1704695, 49876, 1132, 30, 49, "StandardFormEquation"],
Cell[1705830, 49908, 1337, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1707204, 49945, 558, 15, 27, "StandardFormEquation"],
Cell[1707765, 49962, 694, 17, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1708496, 49984, 795, 21, 49, "StandardFormEquation"],
Cell[1709294, 50007, 992, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1710323, 50037, 683, 19, 29, "StandardFormEquation"],
Cell[1711009, 50058, 835, 21, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1711881, 50084, 623, 17, 49, "StandardFormEquation"],
Cell[1712507, 50103, 776, 20, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1713320, 50128, 732, 20, 49, "StandardFormEquation"],
Cell[1714055, 50150, 904, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1714996, 50178, 738, 20, 49, "StandardFormEquation"],
Cell[1715737, 50200, 910, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1716684, 50228, 607, 17, 29, "StandardFormEquation"],
Cell[1717294, 50247, 743, 19, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1718074, 50271, 585, 16, 47, "StandardFormEquation"],
Cell[1718662, 50289, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1719422, 50312, 694, 19, 47, "StandardFormEquation"],
Cell[1720119, 50333, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1721007, 50359, 579, 16, 47, "StandardFormEquation"],
Cell[1721589, 50377, 717, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1722343, 50400, 748, 21, 47, "StandardFormEquation"],
Cell[1723094, 50423, 902, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1724033, 50450, 748, 21, 47, "StandardFormEquation"],
Cell[1724784, 50473, 902, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1725723, 50500, 795, 21, 49, "StandardFormEquation"],
Cell[1726521, 50523, 990, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1727548, 50553, 632, 17, 27, "StandardFormEquation"],
Cell[1728183, 50572, 783, 20, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1729003, 50597, 993, 27, 49, "StandardFormEquation"],
Cell[1729999, 50626, 1206, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1731242, 50661, 753, 20, 47, "StandardFormEquation"],
Cell[1731998, 50683, 927, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1732962, 50711, 795, 21, 49, "StandardFormEquation"],
Cell[1733760, 50734, 990, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1734787, 50764, 675, 18, 47, "StandardFormEquation"],
Cell[1735465, 50784, 830, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1736332, 50809, 822, 22, 49, "StandardFormEquation"],
Cell[1737157, 50833, 1011, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1738205, 50863, 947, 25, 47, "StandardFormEquation"],
Cell[1739155, 50890, 1108, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1740300, 50921, 1135, 30, 66, "StandardFormEquation"],
Cell[1741438, 50953, 1364, 34, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1742839, 50992, 792, 21, 47, "StandardFormEquation"],
Cell[1743634, 51015, 985, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1744656, 51045, 881, 24, 48, "StandardFormEquation"],
Cell[1745540, 51071, 1033, 26, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1746610, 51102, 869, 24, 47, "StandardFormEquation"],
Cell[1747482, 51128, 970, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1748489, 51157, 809, 22, 47, "StandardFormEquation"],
Cell[1749301, 51181, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1750323, 51210, 809, 22, 47, "StandardFormEquation"],
Cell[1751135, 51234, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1752157, 51263, 719, 19, 48, "StandardFormEquation"],
Cell[1752879, 51284, 876, 21, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1753792, 51310, 558, 15, 27, "StandardFormEquation"],
Cell[1754353, 51327, 694, 17, 28, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1755096, 51350, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1755242, 51356, 1115, 30, 47, "StandardFormEquation"],
Cell[1756360, 51388, 1343, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1757740, 51425, 1095, 28, 66, "StandardFormEquation"],
Cell[1758838, 51455, 1377, 33, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1760252, 51493, 1103, 30, 48, "StandardFormEquation"],
Cell[1761358, 51525, 1295, 32, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1762690, 51562, 1119, 30, 47, "StandardFormEquation"],
Cell[1763812, 51594, 1343, 32, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1765216, 51633, 92, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[1765333, 51639, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1765478, 51645, 709, 20, 49, "StandardFormEquation"],
Cell[1766190, 51667, 825, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1767052, 51694, 752, 21, 50, "StandardFormEquation"],
Cell[1767807, 51717, 910, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1768754, 51746, 758, 22, 50, "StandardFormEquation"],
Cell[1769515, 51770, 863, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1770415, 51798, 831, 23, 50, "StandardFormEquation"],
Cell[1771249, 51823, 957, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1772243, 51852, 614, 18, 50, "StandardFormEquation"],
Cell[1772860, 51872, 706, 18, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1773603, 51895, 911, 25, 50, "StandardFormEquation"],
Cell[1774517, 51922, 1060, 27, 48, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1775626, 51955, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1775773, 51961, 916, 25, 50, "StandardFormEquation"],
Cell[1776692, 51988, 1103, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1777832, 52021, 727, 20, 50, "StandardFormEquation"],
Cell[1778562, 52043, 903, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1779502, 52072, 776, 22, 50, "StandardFormEquation"],
Cell[1780281, 52096, 941, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1781259, 52126, 747, 21, 47, "StandardFormEquation"],
Cell[1782009, 52149, 863, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1782909, 52176, 616, 17, 50, "StandardFormEquation"],
Cell[1783528, 52195, 760, 20, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1784325, 52220, 691, 19, 49, "StandardFormEquation"],
Cell[1785019, 52241, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1785908, 52268, 864, 24, 50, "StandardFormEquation"],
Cell[1786775, 52294, 1048, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1787860, 52326, 900, 25, 50, "StandardFormEquation"],
Cell[1788763, 52353, 1099, 29, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1789899, 52387, 727, 20, 50, "StandardFormEquation"],
Cell[1790629, 52409, 903, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1791569, 52438, 632, 18, 47, "StandardFormEquation"],
Cell[1792204, 52458, 729, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1792970, 52482, 888, 25, 48, "StandardFormEquation"],
Cell[1793861, 52509, 1057, 28, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1794955, 52542, 924, 26, 50, "StandardFormEquation"],
Cell[1795882, 52570, 1095, 29, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1797014, 52604, 747, 21, 47, "StandardFormEquation"],
Cell[1797764, 52627, 863, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1798664, 52654, 691, 19, 49, "StandardFormEquation"],
Cell[1799358, 52675, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1800247, 52702, 888, 25, 49, "StandardFormEquation"],
Cell[1801138, 52729, 1044, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1802219, 52761, 924, 26, 50, "StandardFormEquation"],
Cell[1803146, 52789, 1095, 29, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1804278, 52823, 888, 25, 49, "StandardFormEquation"],
Cell[1805169, 52850, 1044, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1806250, 52882, 770, 22, 50, "StandardFormEquation"],
Cell[1807023, 52906, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1807950, 52934, 839, 23, 47, "StandardFormEquation"],
Cell[1808792, 52959, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1809835, 52990, 856, 23, 47, "StandardFormEquation"],
Cell[1810694, 53015, 1049, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1811780, 53046, 582, 16, 49, "StandardFormEquation"],
Cell[1812365, 53064, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1813126, 53088, 616, 17, 50, "StandardFormEquation"],
Cell[1813745, 53107, 760, 20, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1814542, 53132, 582, 16, 49, "StandardFormEquation"],
Cell[1815127, 53150, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1815888, 53174, 776, 22, 50, "StandardFormEquation"],
Cell[1816667, 53198, 941, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1817645, 53228, 691, 19, 49, "StandardFormEquation"],
Cell[1818339, 53249, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1819228, 53276, 691, 19, 49, "StandardFormEquation"],
Cell[1819922, 53297, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1820811, 53324, 1089, 29, 50, "StandardFormEquation"],
Cell[1821903, 53355, 1276, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1823216, 53392, 899, 24, 50, "StandardFormEquation"],
Cell[1824118, 53418, 1100, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1825255, 53451, 668, 18, 48, "StandardFormEquation"],
Cell[1825926, 53471, 826, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1826789, 53497, 1164, 30, 50, "StandardFormEquation"],
Cell[1827956, 53529, 1383, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1829376, 53568, 691, 19, 49, "StandardFormEquation"],
Cell[1830070, 53589, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1830959, 53616, 852, 24, 47, "StandardFormEquation"],
Cell[1831814, 53642, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1832857, 53673, 782, 21, 47, "StandardFormEquation"],
Cell[1833642, 53696, 934, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1834613, 53725, 582, 16, 49, "StandardFormEquation"],
Cell[1835198, 53743, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1835959, 53767, 875, 24, 49, "StandardFormEquation"],
Cell[1836837, 53793, 1057, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1837931, 53826, 912, 25, 47, "StandardFormEquation"],
Cell[1838846, 53853, 1068, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1839951, 53885, 740, 21, 50, "StandardFormEquation"],
Cell[1840694, 53908, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1841621, 53936, 668, 18, 49, "StandardFormEquation"],
Cell[1842292, 53956, 827, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1843156, 53982, 691, 19, 49, "StandardFormEquation"],
Cell[1843850, 54003, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1844739, 54030, 888, 25, 49, "StandardFormEquation"],
Cell[1845630, 54057, 1044, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1846711, 54089, 620, 17, 47, "StandardFormEquation"],
Cell[1847334, 54108, 760, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1848131, 54132, 668, 18, 49, "StandardFormEquation"],
Cell[1848802, 54152, 827, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1849666, 54178, 912, 25, 50, "StandardFormEquation"],
Cell[1850581, 54205, 1100, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1851718, 54238, 691, 19, 49, "StandardFormEquation"],
Cell[1852412, 54259, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1853301, 54286, 582, 16, 49, "StandardFormEquation"],
Cell[1853886, 54304, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1854647, 54328, 851, 23, 50, "StandardFormEquation"],
Cell[1855501, 54353, 1061, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1856599, 54386, 888, 25, 49, "StandardFormEquation"],
Cell[1857490, 54413, 1057, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1858584, 54446, 795, 22, 49, "StandardFormEquation"],
Cell[1859382, 54470, 928, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1860347, 54499, 740, 21, 50, "StandardFormEquation"],
Cell[1861090, 54522, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1862017, 54550, 691, 19, 49, "StandardFormEquation"],
Cell[1862711, 54571, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1863600, 54598, 1179, 31, 50, "StandardFormEquation"],
Cell[1864782, 54631, 1383, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1866202, 54670, 901, 24, 50, "StandardFormEquation"],
Cell[1867106, 54696, 1103, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1868246, 54729, 831, 23, 50, "StandardFormEquation"],
Cell[1869080, 54754, 979, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1870096, 54785, 994, 26, 50, "StandardFormEquation"],
Cell[1871093, 54813, 1188, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1872318, 54848, 1074, 28, 50, "StandardFormEquation"],
Cell[1873395, 54878, 1276, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1874708, 54915, 797, 22, 47, "StandardFormEquation"],
Cell[1875508, 54939, 934, 24, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1876479, 54968, 797, 22, 47, "StandardFormEquation"],
Cell[1877279, 54992, 934, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1878250, 55021, 912, 25, 47, "StandardFormEquation"],
Cell[1879165, 55048, 1068, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1880270, 55080, 716, 20, 48, "StandardFormEquation"],
Cell[1880989, 55102, 821, 21, 45, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1881859, 55129, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[1882005, 55135, 787, 21, 48, "StandardFormEquation"],
Cell[1882795, 55158, 963, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1883795, 55187, 911, 25, 48, "StandardFormEquation"],
Cell[1884709, 55214, 1093, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1885839, 55246, 896, 25, 50, "StandardFormEquation"],
Cell[1886738, 55273, 1076, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1887851, 55305, 725, 20, 48, "StandardFormEquation"],
Cell[1888579, 55327, 879, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1889495, 55354, 730, 20, 48, "StandardFormEquation"],
Cell[1890228, 55376, 902, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1891167, 55404, 768, 21, 50, "StandardFormEquation"],
Cell[1891938, 55427, 955, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1892930, 55457, 845, 23, 48, "StandardFormEquation"],
Cell[1893778, 55482, 1036, 26, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1894851, 55513, 883, 24, 50, "StandardFormEquation"],
Cell[1895737, 55539, 1089, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1896863, 55572, 837, 23, 47, "StandardFormEquation"],
Cell[1897703, 55597, 970, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1898710, 55626, 694, 19, 47, "StandardFormEquation"],
Cell[1899407, 55647, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1900295, 55673, 735, 20, 47, "StandardFormEquation"],
Cell[1901033, 55695, 909, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1901979, 55723, 784, 22, 48, "StandardFormEquation"],
Cell[1902766, 55747, 947, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1903750, 55776, 626, 17, 47, "StandardFormEquation"],
Cell[1904379, 55795, 781, 20, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1905197, 55820, 735, 20, 47, "StandardFormEquation"],
Cell[1905935, 55842, 909, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1906881, 55870, 626, 17, 47, "StandardFormEquation"],
Cell[1907510, 55889, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1908328, 55914, 771, 21, 48, "StandardFormEquation"],
Cell[1909102, 55937, 960, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1910099, 55967, 1037, 28, 47, "StandardFormEquation"],
Cell[1911139, 55997, 1263, 31, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1912439, 56033, 710, 19, 47, "StandardFormEquation"],
Cell[1913152, 56054, 867, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1914056, 56080, 845, 23, 48, "StandardFormEquation"],
Cell[1914904, 56105, 1036, 26, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1915977, 56136, 1188, 31, 65, "StandardFormEquation"],
Cell[1917168, 56169, 1436, 34, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1918641, 56208, 947, 25, 48, "StandardFormEquation"],
Cell[1919591, 56235, 1162, 29, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1920790, 56269, 787, 21, 47, "StandardFormEquation"],
Cell[1921580, 56292, 965, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1922582, 56321, 623, 17, 47, "StandardFormEquation"],
Cell[1923208, 56340, 763, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1924008, 56364, 626, 17, 47, "StandardFormEquation"],
Cell[1924637, 56383, 779, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1925453, 56408, 724, 20, 47, "StandardFormEquation"],
Cell[1926180, 56430, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1927068, 56456, 661, 18, 49, "StandardFormEquation"],
Cell[1927732, 56476, 803, 20, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1928572, 56501, 865, 24, 47, "StandardFormEquation"],
Cell[1929440, 56527, 966, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1930443, 56556, 819, 22, 47, "StandardFormEquation"],
Cell[1931265, 56580, 995, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1932297, 56609, 869, 24, 47, "StandardFormEquation"],
Cell[1933169, 56635, 970, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1934176, 56664, 862, 23, 47, "StandardFormEquation"],
Cell[1935041, 56689, 1055, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1936133, 56720, 911, 25, 48, "StandardFormEquation"],
Cell[1937047, 56747, 1093, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1938177, 56779, 809, 22, 47, "StandardFormEquation"],
Cell[1938989, 56803, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1940011, 56832, 883, 24, 50, "StandardFormEquation"],
Cell[1940897, 56858, 1089, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1942023, 56891, 809, 22, 47, "StandardFormEquation"],
Cell[1942835, 56915, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1943857, 56944, 643, 18, 27, "StandardFormEquation"],
Cell[1944503, 56964, 778, 19, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1945318, 56988, 585, 16, 47, "StandardFormEquation"],
Cell[1945906, 57006, 723, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1946666, 57029, 694, 19, 47, "StandardFormEquation"],
Cell[1947363, 57050, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1948251, 57076, 1188, 31, 65, "StandardFormEquation"],
Cell[1949442, 57109, 1436, 34, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1950915, 57148, 710, 19, 47, "StandardFormEquation"],
Cell[1951628, 57169, 867, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1952532, 57195, 1132, 30, 67, "StandardFormEquation"],
Cell[1953667, 57227, 1337, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1955041, 57264, 851, 22, 65, "StandardFormEquation"],
Cell[1955895, 57288, 1042, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1956974, 57318, 1356, 35, 83, "StandardFormEquation"],
Cell[1958333, 57355, 1501, 35, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1959871, 57395, 623, 17, 49, "StandardFormEquation"],
Cell[1960497, 57414, 776, 20, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1961310, 57439, 713, 19, 49, "StandardFormEquation"],
Cell[1962026, 57460, 883, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1962946, 57487, 694, 19, 47, "StandardFormEquation"],
Cell[1963643, 57508, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1964531, 57534, 579, 16, 47, "StandardFormEquation"],
Cell[1965113, 57552, 717, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1965867, 57575, 639, 18, 47, "StandardFormEquation"],
Cell[1966509, 57595, 774, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1967320, 57619, 748, 21, 47, "StandardFormEquation"],
Cell[1968071, 57642, 902, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1969010, 57669, 862, 23, 47, "StandardFormEquation"],
Cell[1969875, 57694, 1055, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1970967, 57725, 626, 17, 47, "StandardFormEquation"],
Cell[1971596, 57744, 779, 20, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1972412, 57769, 735, 20, 47, "StandardFormEquation"],
Cell[1973150, 57791, 907, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1974094, 57819, 993, 27, 49, "StandardFormEquation"],
Cell[1975090, 57848, 1206, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1976333, 57883, 1135, 30, 48, "StandardFormEquation"],
Cell[1977471, 57915, 1335, 33, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1978843, 57953, 1024, 27, 47, "StandardFormEquation"],
Cell[1979870, 57982, 1266, 32, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1981173, 58019, 753, 20, 47, "StandardFormEquation"],
Cell[1981929, 58041, 927, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1982893, 58069, 753, 20, 47, "StandardFormEquation"],
Cell[1983649, 58091, 927, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1984613, 58119, 851, 22, 47, "StandardFormEquation"],
Cell[1985467, 58143, 1059, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1986563, 58174, 713, 19, 49, "StandardFormEquation"],
Cell[1987279, 58195, 883, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1988199, 58222, 955, 26, 47, "StandardFormEquation"],
Cell[1989157, 58250, 1073, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1990267, 58281, 858, 24, 48, "StandardFormEquation"],
Cell[1991128, 58307, 1023, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1992188, 58337, 883, 24, 50, "StandardFormEquation"],
Cell[1993074, 58363, 1089, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1994200, 58396, 1386, 36, 101, "StandardFormEquation"],
Cell[1995589, 58434, 1433, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1997059, 58473, 923, 25, 47, "StandardFormEquation"],
Cell[1997985, 58500, 1073, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[1999095, 58531, 694, 19, 47, "StandardFormEquation"],
Cell[1999792, 58552, 851, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2000680, 58578, 809, 22, 47, "StandardFormEquation"],
Cell[2001492, 58602, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2002514, 58631, 585, 16, 47, "StandardFormEquation"],
Cell[2003102, 58649, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2003862, 58672, 694, 19, 47, "StandardFormEquation"],
Cell[2004559, 58693, 851, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2005447, 58719, 1092, 29, 48, "StandardFormEquation"],
Cell[2006542, 58750, 1273, 31, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2007852, 58786, 753, 20, 47, "StandardFormEquation"],
Cell[2008608, 58808, 927, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2009572, 58836, 1188, 31, 47, "StandardFormEquation"],
Cell[2010763, 58869, 1436, 34, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2012236, 58908, 685, 18, 47, "StandardFormEquation"],
Cell[2012924, 58928, 840, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2013801, 58953, 675, 18, 47, "StandardFormEquation"],
Cell[2014479, 58973, 830, 20, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2015358, 58999, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2015504, 59005, 675, 18, 47, "StandardFormEquation"],
Cell[2016182, 59025, 830, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2017049, 59050, 784, 21, 47, "StandardFormEquation"],
Cell[2017836, 59073, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2018831, 59101, 1110, 29, 47, "StandardFormEquation"],
Cell[2019944, 59132, 1339, 31, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2021320, 59168, 784, 21, 47, "StandardFormEquation"],
Cell[2022107, 59191, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2023102, 59219, 675, 18, 47, "StandardFormEquation"],
Cell[2023780, 59239, 830, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2024647, 59264, 1086, 29, 47, "StandardFormEquation"],
Cell[2025736, 59295, 1312, 31, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2027085, 59331, 809, 22, 47, "StandardFormEquation"],
Cell[2027897, 59355, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2028919, 59384, 1020, 27, 47, "StandardFormEquation"],
Cell[2029942, 59413, 1232, 29, 45, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2031235, 59449, 92, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[2031352, 59455, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2031497, 59461, 582, 16, 49, "StandardFormEquation"],
Cell[2032082, 59479, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2032843, 59503, 582, 16, 49, "StandardFormEquation"],
Cell[2033428, 59521, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2034189, 59545, 776, 22, 47, "StandardFormEquation"],
Cell[2034968, 59569, 913, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2035918, 59598, 469, 13, 29, "StandardFormEquation"],
Cell[2036390, 59613, 590, 16, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2037017, 59634, 742, 21, 47, "StandardFormEquation"],
Cell[2037762, 59657, 864, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2038663, 59685, 802, 23, 49, "StandardFormEquation"],
Cell[2039468, 59710, 954, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2040459, 59741, 616, 17, 50, "StandardFormEquation"],
Cell[2041078, 59760, 760, 20, 48, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2041887, 59786, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2042034, 59792, 701, 19, 49, "StandardFormEquation"],
Cell[2042738, 59813, 862, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2043637, 59840, 668, 18, 49, "StandardFormEquation"],
Cell[2044308, 59860, 827, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2045172, 59886, 912, 25, 50, "StandardFormEquation"],
Cell[2046087, 59913, 1100, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2047224, 59946, 691, 19, 49, "StandardFormEquation"],
Cell[2047918, 59967, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2048807, 59994, 832, 23, 47, "StandardFormEquation"],
Cell[2049642, 60019, 971, 25, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2050650, 60049, 684, 19, 48, "StandardFormEquation"],
Cell[2051337, 60070, 791, 19, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2052165, 60094, 782, 21, 47, "StandardFormEquation"],
Cell[2052950, 60117, 934, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2053921, 60146, 582, 16, 49, "StandardFormEquation"],
Cell[2054506, 60164, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2055267, 60188, 815, 22, 49, "StandardFormEquation"],
Cell[2056085, 60212, 1010, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2057132, 60243, 851, 23, 50, "StandardFormEquation"],
Cell[2057986, 60268, 1061, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2059084, 60301, 852, 24, 47, "StandardFormEquation"],
Cell[2059939, 60327, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2060982, 60358, 888, 25, 49, "StandardFormEquation"],
Cell[2061873, 60385, 1044, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2062954, 60417, 691, 19, 49, "StandardFormEquation"],
Cell[2063648, 60438, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2064537, 60465, 862, 24, 47, "StandardFormEquation"],
Cell[2065402, 60491, 1016, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2066455, 60522, 655, 18, 48, "StandardFormEquation"],
Cell[2067113, 60542, 769, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2067919, 60567, 508, 14, 47, "StandardFormEquation"],
Cell[2068430, 60583, 629, 16, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2069096, 60604, 1072, 29, 49, "StandardFormEquation"],
Cell[2070171, 60635, 1221, 31, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2071429, 60671, 522, 15, 27, "StandardFormEquation"],
Cell[2071954, 60688, 638, 16, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2072629, 60709, 740, 21, 50, "StandardFormEquation"],
Cell[2073372, 60732, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2074299, 60760, 691, 19, 49, "StandardFormEquation"],
Cell[2074993, 60781, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2075882, 60808, 691, 19, 49, "StandardFormEquation"],
Cell[2076576, 60829, 852, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2077465, 60856, 1179, 31, 50, "StandardFormEquation"],
Cell[2078647, 60889, 1383, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2080067, 60928, 901, 24, 50, "StandardFormEquation"],
Cell[2080971, 60954, 1103, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2082111, 60987, 994, 26, 50, "StandardFormEquation"],
Cell[2083108, 61015, 1173, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2084318, 61049, 1074, 28, 50, "StandardFormEquation"],
Cell[2085395, 61079, 1276, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2086708, 61116, 668, 18, 49, "StandardFormEquation"],
Cell[2087379, 61136, 826, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2088242, 61162, 852, 24, 47, "StandardFormEquation"],
Cell[2089097, 61188, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2090140, 61219, 543, 15, 47, "StandardFormEquation"],
Cell[2090686, 61236, 666, 17, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2091389, 61258, 782, 21, 47, "StandardFormEquation"],
Cell[2092174, 61281, 934, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2093145, 61310, 582, 16, 49, "StandardFormEquation"],
Cell[2093730, 61328, 724, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2094491, 61352, 875, 24, 49, "StandardFormEquation"],
Cell[2095369, 61378, 1057, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2096463, 61411, 625, 17, 29, "StandardFormEquation"],
Cell[2097091, 61430, 779, 20, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2097907, 61455, 1142, 31, 49, "StandardFormEquation"],
Cell[2099052, 61488, 1349, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2100438, 61527, 740, 21, 50, "StandardFormEquation"],
Cell[2101181, 61550, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2102108, 61578, 862, 23, 49, "StandardFormEquation"],
Cell[2102973, 61603, 1067, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2104077, 61635, 898, 24, 50, "StandardFormEquation"],
Cell[2104978, 61661, 1118, 29, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2106133, 61695, 940, 26, 49, "StandardFormEquation"],
Cell[2107076, 61723, 1143, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2108256, 61757, 973, 26, 65, "StandardFormEquation"],
Cell[2109232, 61785, 1173, 30, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2110442, 61820, 740, 20, 50, "StandardFormEquation"],
Cell[2111185, 61842, 918, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2112140, 61871, 1004, 27, 49, "StandardFormEquation"],
Cell[2113147, 61900, 1215, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2114399, 61935, 1178, 32, 67, "StandardFormEquation"],
Cell[2115580, 61969, 1400, 36, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2117017, 62010, 626, 17, 47, "StandardFormEquation"],
Cell[2117646, 62029, 779, 20, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2118462, 62054, 947, 26, 50, "StandardFormEquation"],
Cell[2119412, 62082, 1156, 30, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2120605, 62117, 585, 16, 47, "StandardFormEquation"],
Cell[2121193, 62135, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2121965, 62159, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2122111, 62165, 753, 20, 47, "StandardFormEquation"],
Cell[2122867, 62187, 927, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2123831, 62215, 862, 23, 47, "StandardFormEquation"],
Cell[2124696, 62240, 1055, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2125788, 62271, 847, 23, 49, "StandardFormEquation"],
Cell[2126638, 62296, 1038, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2127713, 62327, 687, 19, 47, "StandardFormEquation"],
Cell[2128403, 62348, 824, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2129264, 62373, 732, 20, 49, "StandardFormEquation"],
Cell[2129999, 62395, 904, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2130940, 62423, 802, 22, 47, "StandardFormEquation"],
Cell[2131745, 62447, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2132740, 62475, 847, 23, 49, "StandardFormEquation"],
Cell[2133590, 62500, 1038, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2134665, 62531, 710, 19, 47, "StandardFormEquation"],
Cell[2135378, 62552, 867, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2136282, 62578, 734, 20, 47, "StandardFormEquation"],
Cell[2137019, 62600, 861, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2137917, 62626, 724, 20, 47, "StandardFormEquation"],
Cell[2138644, 62648, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2139532, 62674, 633, 17, 47, "StandardFormEquation"],
Cell[2140168, 62693, 773, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2140978, 62717, 1016, 26, 47, "StandardFormEquation"],
Cell[2141997, 62745, 1249, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2143283, 62780, 724, 20, 47, "StandardFormEquation"],
Cell[2144010, 62802, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2144898, 62828, 626, 17, 47, "StandardFormEquation"],
Cell[2145527, 62847, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2146345, 62872, 626, 17, 47, "StandardFormEquation"],
Cell[2146974, 62891, 781, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2147792, 62916, 735, 20, 47, "StandardFormEquation"],
Cell[2148530, 62938, 909, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2149476, 62966, 585, 16, 47, "StandardFormEquation"],
Cell[2150064, 62984, 723, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2150824, 63007, 993, 27, 49, "StandardFormEquation"],
Cell[2151820, 63036, 1206, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2153063, 63071, 759, 20, 47, "StandardFormEquation"],
Cell[2153825, 63093, 950, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2154812, 63122, 809, 22, 47, "StandardFormEquation"],
Cell[2155624, 63146, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2156646, 63175, 1135, 30, 48, "StandardFormEquation"],
Cell[2157784, 63207, 1335, 33, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2159156, 63245, 833, 23, 47, "StandardFormEquation"],
Cell[2159992, 63270, 966, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2160995, 63299, 1024, 27, 47, "StandardFormEquation"],
Cell[2162022, 63328, 1268, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2163327, 63365, 623, 17, 47, "StandardFormEquation"],
Cell[2163953, 63384, 763, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2164753, 63408, 760, 21, 49, "StandardFormEquation"],
Cell[2165516, 63431, 902, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2166455, 63459, 787, 21, 47, "StandardFormEquation"],
Cell[2167245, 63482, 965, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2168247, 63511, 734, 20, 47, "StandardFormEquation"],
Cell[2168984, 63533, 861, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2169882, 63559, 724, 20, 47, "StandardFormEquation"],
Cell[2170609, 63581, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2171497, 63607, 798, 22, 50, "StandardFormEquation"],
Cell[2172298, 63631, 957, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2173292, 63661, 724, 20, 47, "StandardFormEquation"],
Cell[2174019, 63683, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2174907, 63709, 643, 18, 27, "StandardFormEquation"],
Cell[2175553, 63729, 778, 19, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2176368, 63753, 753, 20, 47, "StandardFormEquation"],
Cell[2177124, 63775, 927, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2178088, 63803, 694, 19, 47, "StandardFormEquation"],
Cell[2178785, 63824, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2179673, 63850, 694, 19, 47, "StandardFormEquation"],
Cell[2180370, 63871, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2181258, 63897, 809, 22, 47, "StandardFormEquation"],
Cell[2182070, 63921, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2183092, 63950, 819, 22, 47, "StandardFormEquation"],
Cell[2183914, 63974, 995, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2184946, 64003, 675, 18, 47, "StandardFormEquation"],
Cell[2185624, 64023, 830, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2186491, 64048, 1329, 34, 83, "StandardFormEquation"],
Cell[2187823, 64084, 1474, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2189334, 64123, 732, 20, 49, "StandardFormEquation"],
Cell[2190069, 64145, 904, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2191010, 64173, 822, 22, 49, "StandardFormEquation"],
Cell[2191835, 64197, 1011, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2192883, 64227, 753, 20, 47, "StandardFormEquation"],
Cell[2193639, 64249, 927, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2194603, 64277, 810, 22, 47, "StandardFormEquation"],
Cell[2195416, 64301, 954, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2196407, 64329, 810, 22, 47, "StandardFormEquation"],
Cell[2197220, 64353, 954, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2198211, 64381, 862, 23, 47, "StandardFormEquation"],
Cell[2199076, 64406, 1055, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2200168, 64437, 558, 15, 27, "StandardFormEquation"],
Cell[2200729, 64454, 694, 17, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2201460, 64476, 594, 16, 29, "StandardFormEquation"],
Cell[2202057, 64494, 743, 19, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2202837, 64518, 700, 19, 47, "StandardFormEquation"],
Cell[2203540, 64539, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2204434, 64565, 700, 19, 47, "StandardFormEquation"],
Cell[2205137, 64586, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2206031, 64612, 772, 21, 50, "StandardFormEquation"],
Cell[2206806, 64635, 946, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2207789, 64664, 700, 19, 47, "StandardFormEquation"],
Cell[2208492, 64685, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2209386, 64711, 700, 19, 47, "StandardFormEquation"],
Cell[2210089, 64732, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2210983, 64758, 784, 21, 47, "StandardFormEquation"],
Cell[2211770, 64781, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2212765, 64809, 794, 21, 47, "StandardFormEquation"],
Cell[2213562, 64832, 968, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2214567, 64860, 784, 21, 47, "StandardFormEquation"],
Cell[2215354, 64883, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2216361, 64912, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2216507, 64918, 1099, 30, 48, "StandardFormEquation"],
Cell[2217609, 64950, 1300, 33, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2218946, 64988, 1501, 39, 59, "StandardFormEquation"],
Cell[2220450, 65029, 1628, 39, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2222139, 65075, 92, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[2222256, 65081, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2222401, 65087, 831, 23, 48, "StandardFormEquation"],
Cell[2223235, 65112, 972, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2224244, 65142, 908, 25, 48, "StandardFormEquation"],
Cell[2225155, 65169, 1036, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2226228, 65201, 766, 22, 47, "StandardFormEquation"],
Cell[2226997, 65225, 903, 24, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2227937, 65254, 822, 23, 47, "StandardFormEquation"],
Cell[2228762, 65279, 961, 25, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2229760, 65309, 860, 24, 49, "StandardFormEquation"],
Cell[2230623, 65335, 1001, 26, 48, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2231673, 65367, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2231820, 65373, 902, 24, 48, "StandardFormEquation"],
Cell[2232725, 65399, 1110, 28, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2233872, 65432, 741, 20, 48, "StandardFormEquation"],
Cell[2234616, 65454, 872, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2235525, 65481, 921, 25, 66, "StandardFormEquation"],
Cell[2236449, 65508, 1079, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2237565, 65540, 1004, 27, 49, "StandardFormEquation"],
Cell[2238572, 65569, 1200, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2239809, 65603, 1094, 29, 49, "StandardFormEquation"],
Cell[2240906, 65634, 1322, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2242265, 65671, 744, 21, 48, "StandardFormEquation"],
Cell[2243012, 65694, 862, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2243911, 65721, 672, 18, 47, "StandardFormEquation"],
Cell[2244586, 65741, 831, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2245454, 65767, 929, 25, 50, "StandardFormEquation"],
Cell[2246386, 65794, 1100, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2247523, 65827, 975, 26, 66, "StandardFormEquation"],
Cell[2248501, 65855, 1178, 29, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2249716, 65889, 931, 25, 47, "StandardFormEquation"],
Cell[2250650, 65916, 1111, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2251798, 65948, 1020, 28, 47, "StandardFormEquation"],
Cell[2252821, 65978, 1195, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2254053, 66013, 1106, 30, 47, "StandardFormEquation"],
Cell[2255162, 66045, 1298, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2256497, 66082, 629, 17, 47, "StandardFormEquation"],
Cell[2257129, 66101, 769, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2257935, 66125, 655, 18, 48, "StandardFormEquation"],
Cell[2258593, 66145, 769, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2259399, 66170, 547, 15, 27, "StandardFormEquation"],
Cell[2259949, 66187, 685, 18, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2260671, 66210, 1057, 28, 48, "StandardFormEquation"],
Cell[2261731, 66240, 1221, 31, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2262989, 66276, 766, 22, 47, "StandardFormEquation"],
Cell[2263758, 66300, 903, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2264698, 66329, 1208, 33, 65, "StandardFormEquation"],
Cell[2265909, 66364, 1408, 36, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2267354, 66405, 852, 24, 47, "StandardFormEquation"],
Cell[2268209, 66431, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2269252, 66462, 852, 24, 47, "StandardFormEquation"],
Cell[2270107, 66488, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2271150, 66519, 734, 21, 48, "StandardFormEquation"],
Cell[2271887, 66542, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2272776, 66569, 935, 25, 48, "StandardFormEquation"],
Cell[2273714, 66596, 1123, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2274874, 66630, 597, 17, 47, "StandardFormEquation"],
Cell[2275474, 66649, 692, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2276203, 66672, 1057, 28, 48, "StandardFormEquation"],
Cell[2277263, 66702, 1221, 31, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2278521, 66738, 1147, 30, 48, "StandardFormEquation"],
Cell[2279671, 66770, 1328, 33, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2281036, 66808, 907, 24, 47, "StandardFormEquation"],
Cell[2281946, 66834, 1078, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2283061, 66866, 897, 24, 47, "StandardFormEquation"],
Cell[2283961, 66892, 1068, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2285066, 66924, 763, 21, 47, "StandardFormEquation"],
Cell[2285832, 66947, 913, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2286782, 66976, 1126, 30, 48, "StandardFormEquation"],
Cell[2287911, 67008, 1358, 35, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2289306, 67048, 730, 20, 47, "StandardFormEquation"],
Cell[2290039, 67070, 878, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2290954, 67098, 889, 24, 48, "StandardFormEquation"],
Cell[2291846, 67124, 1079, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2292962, 67156, 904, 25, 47, "StandardFormEquation"],
Cell[2293869, 67183, 1092, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2294998, 67215, 990, 27, 47, "StandardFormEquation"],
Cell[2295991, 67244, 1195, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2297223, 67278, 940, 26, 49, "StandardFormEquation"],
Cell[2298166, 67306, 1130, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2299333, 67339, 879, 24, 48, "StandardFormEquation"],
Cell[2300215, 67365, 1069, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2301321, 67397, 470, 13, 47, "StandardFormEquation"],
Cell[2301794, 67412, 589, 15, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2302420, 67432, 979, 27, 48, "StandardFormEquation"],
Cell[2303402, 67461, 1135, 30, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2304574, 67496, 917, 25, 47, "StandardFormEquation"],
Cell[2305494, 67523, 1043, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2306574, 67555, 1057, 28, 48, "StandardFormEquation"],
Cell[2307634, 67585, 1221, 31, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2308892, 67621, 622, 17, 48, "StandardFormEquation"],
Cell[2309517, 67640, 734, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2310288, 67664, 508, 14, 47, "StandardFormEquation"],
Cell[2310799, 67680, 629, 16, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2311465, 67701, 1126, 30, 48, "StandardFormEquation"],
Cell[2312594, 67733, 1358, 35, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2313989, 67773, 902, 24, 50, "StandardFormEquation"],
Cell[2314894, 67799, 1107, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2316038, 67832, 754, 21, 48, "StandardFormEquation"],
Cell[2316795, 67855, 872, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2317704, 67882, 902, 25, 50, "StandardFormEquation"],
Cell[2318609, 67909, 1028, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2319674, 67941, 709, 20, 49, "StandardFormEquation"],
Cell[2320386, 67963, 825, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2321248, 67990, 655, 18, 48, "StandardFormEquation"],
Cell[2321906, 68010, 769, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2322712, 68035, 843, 23, 50, "StandardFormEquation"],
Cell[2323558, 68060, 997, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2324592, 68091, 795, 22, 49, "StandardFormEquation"],
Cell[2325390, 68115, 928, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2326355, 68144, 925, 25, 50, "StandardFormEquation"],
Cell[2327283, 68171, 1130, 29, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2328450, 68205, 1032, 28, 50, "StandardFormEquation"],
Cell[2329485, 68235, 1251, 32, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2330773, 68272, 579, 16, 47, "StandardFormEquation"],
Cell[2331355, 68290, 717, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2332109, 68313, 950, 26, 49, "StandardFormEquation"],
Cell[2333062, 68341, 1108, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2334207, 68374, 950, 26, 49, "StandardFormEquation"],
Cell[2335160, 68402, 1108, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2336305, 68435, 661, 18, 47, "StandardFormEquation"],
Cell[2336969, 68455, 769, 19, 45, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2337787, 68480, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2337933, 68486, 956, 25, 47, "StandardFormEquation"],
Cell[2338892, 68513, 1157, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2340086, 68547, 838, 22, 47, "StandardFormEquation"],
Cell[2340927, 68571, 1014, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2341978, 68600, 762, 20, 47, "StandardFormEquation"],
Cell[2342743, 68622, 938, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2343718, 68650, 672, 18, 47, "StandardFormEquation"],
Cell[2344393, 68670, 831, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2345261, 68696, 805, 21, 47, "StandardFormEquation"],
Cell[2346069, 68719, 1023, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2347129, 68750, 735, 20, 47, "StandardFormEquation"],
Cell[2347867, 68772, 894, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2348798, 68799, 1279, 33, 47, "StandardFormEquation"],
Cell[2350080, 68834, 1535, 36, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2351652, 68875, 805, 21, 47, "StandardFormEquation"],
Cell[2352460, 68898, 1004, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2353501, 68928, 750, 20, 47, "StandardFormEquation"],
Cell[2354254, 68950, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2355200, 68977, 1279, 33, 47, "StandardFormEquation"],
Cell[2356482, 69012, 1535, 36, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2358054, 69053, 805, 21, 47, "StandardFormEquation"],
Cell[2358862, 69076, 1004, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2359903, 69106, 849, 22, 49, "StandardFormEquation"],
Cell[2360755, 69130, 1052, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2361844, 69161, 750, 20, 47, "StandardFormEquation"],
Cell[2362597, 69183, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2363543, 69210, 801, 22, 48, "StandardFormEquation"],
Cell[2364347, 69234, 962, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2365346, 69263, 762, 21, 48, "StandardFormEquation"],
Cell[2366111, 69286, 906, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2367054, 69314, 805, 21, 47, "StandardFormEquation"],
Cell[2367862, 69337, 1004, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2368903, 69367, 849, 22, 49, "StandardFormEquation"],
Cell[2369755, 69391, 1056, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2370848, 69422, 790, 21, 49, "StandardFormEquation"],
Cell[2371641, 69445, 970, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2372648, 69474, 820, 22, 47, "StandardFormEquation"],
Cell[2373471, 69498, 977, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2374485, 69528, 787, 21, 47, "StandardFormEquation"],
Cell[2375275, 69551, 942, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2376254, 69580, 707, 19, 47, "StandardFormEquation"],
Cell[2376964, 69601, 868, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2377869, 69628, 1105, 29, 47, "StandardFormEquation"],
Cell[2378977, 69659, 1337, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2380351, 69696, 787, 21, 47, "StandardFormEquation"],
Cell[2381141, 69719, 942, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2382120, 69748, 1157, 31, 77, "StandardFormEquation"],
Cell[2383280, 69781, 1360, 33, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2384677, 69819, 750, 20, 47, "StandardFormEquation"],
Cell[2385430, 69841, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2386376, 69868, 827, 23, 47, "StandardFormEquation"],
Cell[2387206, 69893, 960, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2388203, 69922, 761, 21, 47, "StandardFormEquation"],
Cell[2388967, 69945, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2389907, 69972, 724, 20, 47, "StandardFormEquation"],
Cell[2390634, 69994, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2391522, 70020, 611, 17, 27, "StandardFormEquation"],
Cell[2392136, 70039, 719, 18, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2392892, 70062, 750, 20, 47, "StandardFormEquation"],
Cell[2393645, 70084, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2394591, 70111, 623, 17, 48, "StandardFormEquation"],
Cell[2395217, 70130, 776, 20, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2396030, 70155, 732, 20, 48, "StandardFormEquation"],
Cell[2396765, 70177, 904, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2397706, 70205, 585, 16, 47, "StandardFormEquation"],
Cell[2398294, 70223, 723, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2399054, 70246, 694, 19, 47, "StandardFormEquation"],
Cell[2399751, 70267, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2400639, 70293, 886, 24, 47, "StandardFormEquation"],
Cell[2401528, 70319, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2402550, 70348, 854, 23, 50, "StandardFormEquation"],
Cell[2403407, 70373, 1015, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2404459, 70404, 787, 21, 47, "StandardFormEquation"],
Cell[2405249, 70427, 965, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2406251, 70456, 623, 17, 47, "StandardFormEquation"],
Cell[2406877, 70475, 763, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2407677, 70499, 744, 20, 47, "StandardFormEquation"],
Cell[2408424, 70521, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2409364, 70548, 712, 20, 47, "StandardFormEquation"],
Cell[2410079, 70570, 826, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2410942, 70596, 744, 20, 47, "StandardFormEquation"],
Cell[2411689, 70618, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2412629, 70645, 947, 25, 48, "StandardFormEquation"],
Cell[2413579, 70672, 1118, 28, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2414734, 70705, 707, 19, 47, "StandardFormEquation"],
Cell[2415444, 70726, 868, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2416349, 70753, 672, 18, 47, "StandardFormEquation"],
Cell[2417024, 70773, 831, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2417892, 70799, 1090, 28, 47, "StandardFormEquation"],
Cell[2418985, 70829, 1344, 33, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2420366, 70867, 1128, 30, 47, "StandardFormEquation"],
Cell[2421497, 70899, 1365, 35, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2422899, 70939, 787, 21, 47, "StandardFormEquation"],
Cell[2423689, 70962, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2424670, 70991, 629, 17, 47, "StandardFormEquation"],
Cell[2425302, 71010, 769, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2426108, 71034, 669, 18, 49, "StandardFormEquation"],
Cell[2426780, 71054, 830, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2427647, 71080, 829, 22, 65, "StandardFormEquation"],
Cell[2428479, 71104, 1005, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2429521, 71133, 732, 20, 48, "StandardFormEquation"],
Cell[2430256, 71155, 904, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2431197, 71183, 772, 21, 47, "StandardFormEquation"],
Cell[2431972, 71206, 943, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2432952, 71234, 859, 24, 47, "StandardFormEquation"],
Cell[2433814, 71260, 960, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2434811, 71289, 784, 21, 47, "StandardFormEquation"],
Cell[2435598, 71312, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2436544, 71339, 824, 22, 49, "StandardFormEquation"],
Cell[2437371, 71363, 970, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2438378, 71392, 585, 16, 47, "StandardFormEquation"],
Cell[2438966, 71410, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2439726, 71433, 871, 24, 50, "StandardFormEquation"],
Cell[2440600, 71459, 1002, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2441639, 71489, 1438, 36, 101, "StandardFormEquation"],
Cell[2443080, 71527, 1634, 38, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2444751, 71570, 1438, 36, 101, "StandardFormEquation"],
Cell[2446192, 71608, 1634, 38, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2447863, 71651, 820, 22, 47, "StandardFormEquation"],
Cell[2448686, 71675, 979, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2449702, 71705, 1279, 33, 65, "StandardFormEquation"],
Cell[2450984, 71740, 1535, 36, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2452556, 71781, 705, 19, 47, "StandardFormEquation"],
Cell[2453264, 71802, 830, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2454131, 71827, 833, 23, 48, "StandardFormEquation"],
Cell[2454967, 71852, 960, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2455964, 71881, 585, 16, 47, "StandardFormEquation"],
Cell[2456552, 71899, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2457312, 71922, 839, 23, 47, "StandardFormEquation"],
Cell[2458154, 71947, 987, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2459178, 71977, 712, 20, 47, "StandardFormEquation"],
Cell[2459893, 71999, 826, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2460756, 72025, 1090, 28, 47, "StandardFormEquation"],
Cell[2461849, 72055, 1344, 33, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2463230, 72093, 629, 17, 47, "StandardFormEquation"],
Cell[2463862, 72112, 769, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2464668, 72136, 739, 20, 47, "StandardFormEquation"],
Cell[2465410, 72158, 898, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2466345, 72185, 805, 22, 47, "StandardFormEquation"],
Cell[2467153, 72209, 978, 24, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2468168, 72238, 694, 19, 47, "StandardFormEquation"],
Cell[2468865, 72259, 851, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2469753, 72285, 1197, 32, 47, "StandardFormEquation"],
Cell[2470953, 72319, 1387, 34, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2472377, 72358, 1220, 32, 47, "StandardFormEquation"],
Cell[2473600, 72392, 1453, 35, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2475090, 72432, 881, 24, 48, "StandardFormEquation"],
Cell[2475974, 72458, 1033, 26, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2477044, 72489, 706, 19, 47, "StandardFormEquation"],
Cell[2477753, 72510, 863, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2478653, 72536, 809, 22, 47, "StandardFormEquation"],
Cell[2479465, 72560, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2480487, 72589, 784, 21, 47, "StandardFormEquation"],
Cell[2481274, 72612, 909, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2482220, 72639, 1127, 30, 61, "StandardFormEquation"],
Cell[2483350, 72671, 1360, 33, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2484747, 72709, 913, 25, 47, "StandardFormEquation"],
Cell[2485663, 72736, 1063, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2486763, 72767, 883, 24, 47, "StandardFormEquation"],
Cell[2487649, 72793, 1010, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2488696, 72822, 870, 23, 47, "StandardFormEquation"],
Cell[2489569, 72847, 1014, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2490620, 72876, 755, 20, 47, "StandardFormEquation"],
Cell[2491378, 72898, 880, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2492295, 72924, 793, 22, 47, "StandardFormEquation"],
Cell[2493091, 72948, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2494031, 72975, 793, 22, 47, "StandardFormEquation"],
Cell[2494827, 72999, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2495779, 73027, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2495925, 73033, 1013, 27, 47, "StandardFormEquation"],
Cell[2496941, 73062, 1210, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2498188, 73097, 744, 20, 47, "StandardFormEquation"],
Cell[2498935, 73119, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2499875, 73146, 700, 19, 47, "StandardFormEquation"],
Cell[2500578, 73167, 857, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2501472, 73193, 1334, 35, 59, "StandardFormEquation"],
Cell[2502809, 73230, 1414, 33, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2504260, 73268, 1120, 29, 47, "StandardFormEquation"],
Cell[2505383, 73299, 1300, 30, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2506744, 73336, 92, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[2506861, 73342, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2507006, 73348, 763, 21, 47, "StandardFormEquation"],
Cell[2507772, 73371, 913, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2508722, 73400, 578, 17, 48, "StandardFormEquation"],
Cell[2509303, 73419, 668, 17, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2510020, 73442, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2510167, 73448, 935, 25, 48, "StandardFormEquation"],
Cell[2511105, 73475, 1123, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2512265, 73509, 1026, 28, 48, "StandardFormEquation"],
Cell[2513294, 73539, 1240, 31, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2514571, 73575, 899, 24, 50, "StandardFormEquation"],
Cell[2515473, 73601, 1100, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2516610, 73634, 730, 20, 47, "StandardFormEquation"],
Cell[2517343, 73656, 878, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2518258, 73684, 971, 26, 48, "StandardFormEquation"],
Cell[2519232, 73712, 1133, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2520402, 73745, 899, 24, 50, "StandardFormEquation"],
Cell[2521304, 73771, 1100, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2522441, 73804, 638, 18, 48, "StandardFormEquation"],
Cell[2523082, 73824, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2523890, 73848, 816, 22, 47, "StandardFormEquation"],
Cell[2524709, 73872, 981, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2525727, 73902, 674, 19, 50, "StandardFormEquation"],
Cell[2526404, 73923, 809, 20, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2527250, 73948, 588, 17, 50, "StandardFormEquation"],
Cell[2527841, 73967, 706, 18, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2528584, 73990, 886, 24, 68, "StandardFormEquation"],
Cell[2529473, 74016, 1055, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2530565, 74048, 849, 23, 65, "StandardFormEquation"],
Cell[2531417, 74073, 1016, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2532470, 74104, 1018, 27, 66, "StandardFormEquation"],
Cell[2533491, 74133, 1206, 30, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2534734, 74168, 901, 24, 50, "StandardFormEquation"],
Cell[2535638, 74194, 1103, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2536778, 74227, 994, 26, 50, "StandardFormEquation"],
Cell[2537775, 74255, 1173, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2538985, 74289, 634, 18, 48, "StandardFormEquation"],
Cell[2539622, 74309, 767, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2540426, 74334, 839, 23, 47, "StandardFormEquation"],
Cell[2541268, 74359, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2542311, 74390, 607, 17, 44, "StandardFormEquation"],
Cell[2542921, 74409, 738, 19, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2543696, 74433, 668, 18, 48, "StandardFormEquation"],
Cell[2544367, 74453, 826, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2545230, 74479, 725, 20, 27, "StandardFormEquation"],
Cell[2545958, 74501, 869, 23, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2546864, 74529, 552, 16, 48, "StandardFormEquation"],
Cell[2547419, 74547, 668, 17, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2548124, 74569, 850, 23, 48, "StandardFormEquation"],
Cell[2548977, 74594, 1017, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2550031, 74625, 1129, 30, 66, "StandardFormEquation"],
Cell[2551163, 74657, 1349, 34, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2552549, 74696, 852, 24, 47, "StandardFormEquation"],
Cell[2553404, 74722, 1006, 26, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2554447, 74753, 888, 25, 48, "StandardFormEquation"],
Cell[2555338, 74780, 1057, 28, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2556432, 74813, 852, 24, 47, "StandardFormEquation"],
Cell[2557287, 74839, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2558330, 74870, 734, 21, 48, "StandardFormEquation"],
Cell[2559067, 74893, 852, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2559956, 74920, 935, 25, 48, "StandardFormEquation"],
Cell[2560894, 74947, 1123, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2562054, 74981, 597, 17, 47, "StandardFormEquation"],
Cell[2562654, 75000, 692, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2563383, 75023, 1057, 28, 48, "StandardFormEquation"],
Cell[2564443, 75053, 1221, 31, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2565701, 75089, 1147, 30, 48, "StandardFormEquation"],
Cell[2566851, 75121, 1328, 33, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2568216, 75159, 907, 24, 47, "StandardFormEquation"],
Cell[2569126, 75185, 1078, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2570241, 75217, 897, 24, 47, "StandardFormEquation"],
Cell[2571141, 75243, 1068, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2572246, 75275, 763, 21, 47, "StandardFormEquation"],
Cell[2573012, 75298, 913, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2573962, 75327, 1126, 30, 48, "StandardFormEquation"],
Cell[2575091, 75359, 1358, 35, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2576486, 75399, 730, 20, 47, "StandardFormEquation"],
Cell[2577219, 75421, 878, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2578134, 75449, 876, 23, 49, "StandardFormEquation"],
Cell[2579013, 75474, 1079, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2580129, 75506, 959, 26, 49, "StandardFormEquation"],
Cell[2581091, 75534, 1100, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2582228, 75567, 704, 20, 48, "StandardFormEquation"],
Cell[2582935, 75589, 852, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2583824, 75616, 704, 20, 48, "StandardFormEquation"],
Cell[2584531, 75638, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2585420, 75665, 638, 18, 48, "StandardFormEquation"],
Cell[2586061, 75685, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2586869, 75709, 674, 19, 50, "StandardFormEquation"],
Cell[2587546, 75730, 822, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2588405, 75756, 710, 20, 50, "StandardFormEquation"],
Cell[2589118, 75778, 860, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2590015, 75805, 674, 19, 50, "StandardFormEquation"],
Cell[2590692, 75826, 809, 20, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2591538, 75851, 883, 24, 48, "StandardFormEquation"],
Cell[2592424, 75877, 1024, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2593485, 75907, 1089, 29, 50, "StandardFormEquation"],
Cell[2594577, 75938, 1276, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2595890, 75975, 1179, 31, 50, "StandardFormEquation"],
Cell[2597072, 76008, 1383, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2598492, 76047, 1179, 31, 50, "StandardFormEquation"],
Cell[2599674, 76080, 1383, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2601094, 76119, 943, 26, 47, "StandardFormEquation"],
Cell[2602040, 76147, 1084, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2603161, 76180, 1007, 27, 47, "StandardFormEquation"],
Cell[2604171, 76209, 1150, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2605358, 76243, 795, 22, 49, "StandardFormEquation"],
Cell[2606156, 76267, 928, 24, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2607121, 76296, 971, 26, 48, "StandardFormEquation"],
Cell[2608095, 76324, 1133, 28, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2609265, 76357, 901, 24, 50, "StandardFormEquation"],
Cell[2610169, 76383, 1103, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2611309, 76416, 831, 23, 50, "StandardFormEquation"],
Cell[2612143, 76441, 979, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2613159, 76472, 994, 26, 50, "StandardFormEquation"],
Cell[2614156, 76500, 1188, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2615381, 76535, 1089, 29, 50, "StandardFormEquation"],
Cell[2616473, 76566, 1276, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2617786, 76603, 912, 25, 47, "StandardFormEquation"],
Cell[2618701, 76630, 1068, 27, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2619806, 76662, 950, 26, 49, "StandardFormEquation"],
Cell[2620759, 76690, 1108, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2621904, 76723, 950, 26, 49, "StandardFormEquation"],
Cell[2622857, 76751, 1108, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2624002, 76784, 831, 23, 48, "StandardFormEquation"],
Cell[2624836, 76809, 955, 24, 45, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2625840, 76839, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2625986, 76845, 792, 21, 47, "StandardFormEquation"],
Cell[2626781, 76868, 985, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2627803, 76898, 920, 24, 47, "StandardFormEquation"],
Cell[2628726, 76924, 1138, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2629901, 76957, 938, 25, 49, "StandardFormEquation"],
Cell[2630842, 76984, 1135, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2632014, 77018, 885, 23, 65, "StandardFormEquation"],
Cell[2632902, 77043, 1059, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2633998, 77074, 743, 20, 49, "StandardFormEquation"],
Cell[2634744, 77096, 883, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2635664, 77123, 744, 20, 47, "StandardFormEquation"],
Cell[2636411, 77145, 903, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2637351, 77172, 833, 23, 47, "StandardFormEquation"],
Cell[2638187, 77197, 966, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2639190, 77226, 672, 18, 47, "StandardFormEquation"],
Cell[2639865, 77246, 831, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2640733, 77272, 821, 22, 48, "StandardFormEquation"],
Cell[2641557, 77296, 978, 25, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2642572, 77326, 762, 20, 47, "StandardFormEquation"],
Cell[2643337, 77348, 938, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2644312, 77376, 820, 22, 47, "StandardFormEquation"],
Cell[2645135, 77400, 977, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2646149, 77430, 787, 21, 47, "StandardFormEquation"],
Cell[2646939, 77453, 942, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2647918, 77482, 863, 23, 50, "StandardFormEquation"],
Cell[2648784, 77507, 1041, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2649862, 77539, 787, 21, 47, "StandardFormEquation"],
Cell[2650652, 77562, 942, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2651631, 77591, 841, 23, 47, "StandardFormEquation"],
Cell[2652475, 77616, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2653497, 77645, 585, 16, 47, "StandardFormEquation"],
Cell[2654085, 77663, 723, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2654845, 77686, 886, 24, 47, "StandardFormEquation"],
Cell[2655734, 77712, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2656756, 77741, 854, 23, 50, "StandardFormEquation"],
Cell[2657613, 77766, 1015, 26, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2658665, 77797, 787, 21, 47, "StandardFormEquation"],
Cell[2659455, 77820, 965, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2660457, 77849, 623, 17, 47, "StandardFormEquation"],
Cell[2661083, 77868, 763, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2661883, 77892, 744, 20, 47, "StandardFormEquation"],
Cell[2662630, 77914, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2663570, 77941, 712, 20, 47, "StandardFormEquation"],
Cell[2664285, 77963, 826, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2665148, 77989, 744, 20, 47, "StandardFormEquation"],
Cell[2665895, 78011, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2666835, 78038, 947, 25, 48, "StandardFormEquation"],
Cell[2667785, 78065, 1118, 28, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2668940, 78098, 707, 19, 47, "StandardFormEquation"],
Cell[2669650, 78119, 868, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2670555, 78146, 672, 18, 47, "StandardFormEquation"],
Cell[2671230, 78166, 831, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2672098, 78192, 1090, 28, 47, "StandardFormEquation"],
Cell[2673191, 78222, 1344, 33, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2674572, 78260, 1128, 30, 47, "StandardFormEquation"],
Cell[2675703, 78292, 1365, 35, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2677105, 78332, 787, 21, 47, "StandardFormEquation"],
Cell[2677895, 78355, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2678876, 78384, 629, 17, 47, "StandardFormEquation"],
Cell[2679508, 78403, 769, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2680314, 78427, 669, 18, 49, "StandardFormEquation"],
Cell[2680986, 78447, 830, 21, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2681853, 78473, 914, 24, 78, "StandardFormEquation"],
Cell[2682770, 78499, 1122, 27, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2683929, 78531, 579, 16, 47, "StandardFormEquation"],
Cell[2684511, 78549, 717, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2685265, 78572, 615, 17, 49, "StandardFormEquation"],
Cell[2685883, 78591, 755, 19, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2686675, 78615, 701, 19, 49, "StandardFormEquation"],
Cell[2687379, 78636, 871, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2688287, 78663, 947, 25, 48, "StandardFormEquation"],
Cell[2689237, 78690, 1162, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2690436, 78724, 947, 25, 48, "StandardFormEquation"],
Cell[2691386, 78751, 1162, 29, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2692585, 78785, 729, 20, 47, "StandardFormEquation"],
Cell[2693317, 78807, 888, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2694242, 78834, 700, 19, 47, "StandardFormEquation"],
Cell[2694945, 78855, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2695839, 78881, 1037, 28, 47, "StandardFormEquation"],
Cell[2696879, 78911, 1263, 31, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2698179, 78947, 943, 25, 50, "StandardFormEquation"],
Cell[2699125, 78974, 1155, 29, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2700317, 79008, 980, 26, 47, "StandardFormEquation"],
Cell[2701300, 79036, 1096, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2702433, 79067, 885, 23, 47, "StandardFormEquation"],
Cell[2703321, 79092, 1059, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2704417, 79123, 743, 20, 49, "StandardFormEquation"],
Cell[2705163, 79145, 885, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2706085, 79172, 724, 20, 47, "StandardFormEquation"],
Cell[2706812, 79194, 851, 21, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2707700, 79220, 787, 21, 47, "StandardFormEquation"],
Cell[2708490, 79243, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2709471, 79272, 705, 19, 47, "StandardFormEquation"],
Cell[2710179, 79293, 830, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2711046, 79318, 1017, 27, 67, "StandardFormEquation"],
Cell[2712066, 79347, 1233, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2713336, 79382, 1067, 29, 67, "StandardFormEquation"],
Cell[2714406, 79413, 1253, 31, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2715696, 79449, 1067, 29, 67, "StandardFormEquation"],
Cell[2716766, 79480, 1253, 31, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2718056, 79516, 639, 18, 47, "StandardFormEquation"],
Cell[2718698, 79536, 774, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2719509, 79560, 753, 21, 47, "StandardFormEquation"],
Cell[2720265, 79583, 884, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2721186, 79611, 623, 17, 47, "StandardFormEquation"],
Cell[2721812, 79630, 763, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2722612, 79654, 772, 21, 49, "StandardFormEquation"],
Cell[2723387, 79677, 916, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2724340, 79705, 734, 20, 47, "StandardFormEquation"],
Cell[2725077, 79727, 861, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2725975, 79753, 724, 20, 47, "StandardFormEquation"],
Cell[2726702, 79775, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2727590, 79801, 1049, 28, 47, "StandardFormEquation"],
Cell[2728642, 79831, 1231, 29, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2729910, 79865, 1037, 28, 47, "StandardFormEquation"],
Cell[2730950, 79895, 1261, 31, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2732248, 79931, 748, 21, 47, "StandardFormEquation"],
Cell[2732999, 79954, 902, 22, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2733938, 79981, 678, 19, 47, "StandardFormEquation"],
Cell[2734619, 80002, 815, 20, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2735471, 80027, 809, 22, 47, "StandardFormEquation"],
Cell[2736283, 80051, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2737305, 80080, 809, 22, 47, "StandardFormEquation"],
Cell[2738117, 80104, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2739139, 80133, 980, 26, 47, "StandardFormEquation"],
Cell[2740122, 80161, 1096, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2741255, 80192, 1194, 32, 67, "StandardFormEquation"],
Cell[2742452, 80226, 1363, 33, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2743852, 80264, 1067, 29, 49, "StandardFormEquation"],
Cell[2744922, 80295, 1219, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2746178, 80330, 694, 19, 47, "StandardFormEquation"],
Cell[2746875, 80351, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2747763, 80377, 793, 22, 47, "StandardFormEquation"],
Cell[2748559, 80401, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2749499, 80428, 1014, 27, 47, "StandardFormEquation"],
Cell[2750516, 80457, 1194, 28, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2751759, 80491, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2751905, 80497, 1088, 29, 49, "StandardFormEquation"],
Cell[2752996, 80528, 1289, 32, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2754322, 80565, 1013, 27, 47, "StandardFormEquation"],
Cell[2755338, 80594, 1210, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2756585, 80629, 744, 20, 47, "StandardFormEquation"],
Cell[2757332, 80651, 903, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2758272, 80678, 814, 22, 47, "StandardFormEquation"],
Cell[2759089, 80702, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2760084, 80730, 1182, 31, 67, "StandardFormEquation"],
Cell[2761269, 80763, 1402, 34, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2762708, 80802, 1029, 28, 65, "StandardFormEquation"],
Cell[2763740, 80832, 1198, 29, 46, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2764999, 80868, 92, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[2765116, 80874, 120, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2765261, 80880, 817, 22, 47, "StandardFormEquation"],
Cell[2766081, 80904, 971, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2767089, 80934, 552, 16, 48, "StandardFormEquation"],
Cell[2767644, 80952, 668, 17, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2768349, 80974, 730, 20, 47, "StandardFormEquation"],
Cell[2769082, 80996, 878, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2769997, 81024, 443, 13, 48, "StandardFormEquation"],
Cell[2770443, 81039, 540, 14, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2771020, 81058, 717, 20, 44, "StandardFormEquation"],
Cell[2771740, 81080, 841, 22, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2772618, 81107, 764, 21, 48, "StandardFormEquation"],
Cell[2773385, 81130, 914, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2774336, 81159, 552, 16, 48, "StandardFormEquation"],
Cell[2774891, 81177, 668, 17, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2775596, 81199, 588, 17, 50, "StandardFormEquation"],
Cell[2776187, 81218, 706, 18, 48, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2776942, 81242, 122, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2777089, 81248, 691, 19, 48, "StandardFormEquation"],
Cell[2777783, 81269, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2778672, 81296, 943, 26, 47, "StandardFormEquation"],
Cell[2779618, 81324, 1084, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2780739, 81357, 977, 26, 47, "StandardFormEquation"],
Cell[2781719, 81385, 1202, 30, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2782958, 81420, 1163, 30, 65, "StandardFormEquation"],
Cell[2784124, 81452, 1414, 35, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2785575, 81492, 1088, 29, 66, "StandardFormEquation"],
Cell[2786666, 81523, 1250, 31, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2787953, 81559, 582, 16, 48, "StandardFormEquation"],
Cell[2788538, 81577, 724, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2789299, 81601, 1013, 27, 48, "StandardFormEquation"],
Cell[2790315, 81630, 1251, 32, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2791603, 81667, 1048, 27, 65, "StandardFormEquation"],
Cell[2792654, 81696, 1280, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2793971, 81733, 744, 21, 48, "StandardFormEquation"],
Cell[2794718, 81756, 862, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2795617, 81783, 807, 22, 44, "StandardFormEquation"],
Cell[2796427, 81807, 948, 24, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2797412, 81836, 704, 20, 48, "StandardFormEquation"],
Cell[2798119, 81858, 852, 22, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2799008, 81885, 942, 26, 50, "StandardFormEquation"],
Cell[2799953, 81913, 1100, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2801090, 81946, 795, 22, 48, "StandardFormEquation"],
Cell[2801888, 81970, 962, 24, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2802887, 81999, 888, 25, 48, "StandardFormEquation"],
Cell[2803778, 82026, 1044, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2804859, 82058, 816, 22, 65, "StandardFormEquation"],
Cell[2805678, 82082, 981, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2806696, 82112, 839, 23, 47, "StandardFormEquation"],
Cell[2807538, 82137, 1006, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2808581, 82168, 704, 20, 48, "StandardFormEquation"],
Cell[2809288, 82190, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2810177, 82217, 912, 25, 50, "StandardFormEquation"],
Cell[2811092, 82244, 1100, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2812229, 82277, 638, 18, 48, "StandardFormEquation"],
Cell[2812870, 82297, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2813678, 82321, 552, 16, 48, "StandardFormEquation"],
Cell[2814233, 82339, 668, 17, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2814938, 82361, 786, 22, 50, "StandardFormEquation"],
Cell[2815727, 82385, 960, 25, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2816724, 82415, 850, 23, 48, "StandardFormEquation"],
Cell[2817577, 82440, 1017, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2818631, 82471, 1041, 27, 47, "StandardFormEquation"],
Cell[2819675, 82500, 1274, 31, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2820986, 82536, 926, 24, 47, "StandardFormEquation"],
Cell[2821915, 82562, 1140, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2823092, 82595, 1093, 29, 65, "StandardFormEquation"],
Cell[2824188, 82626, 1298, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2825523, 82663, 902, 24, 48, "StandardFormEquation"],
Cell[2826428, 82689, 1108, 28, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2827573, 82722, 891, 24, 43, "StandardFormEquation"],
Cell[2828467, 82748, 1058, 27, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2829562, 82780, 700, 20, 50, "StandardFormEquation"],
Cell[2830265, 82802, 857, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2831159, 82830, 975, 26, 48, "StandardFormEquation"],
Cell[2832137, 82858, 1178, 29, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2833352, 82892, 1178, 32, 66, "StandardFormEquation"],
Cell[2834533, 82926, 1387, 35, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2835957, 82966, 979, 27, 48, "StandardFormEquation"],
Cell[2836939, 82995, 1135, 30, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2838111, 83030, 917, 25, 47, "StandardFormEquation"],
Cell[2839031, 83057, 1043, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2840111, 83089, 1057, 28, 48, "StandardFormEquation"],
Cell[2841171, 83119, 1221, 31, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2842429, 83155, 622, 17, 48, "StandardFormEquation"],
Cell[2843054, 83174, 734, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2843825, 83198, 508, 14, 47, "StandardFormEquation"],
Cell[2844336, 83214, 629, 16, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2845002, 83235, 1126, 30, 48, "StandardFormEquation"],
Cell[2846131, 83267, 1358, 35, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2847526, 83307, 741, 20, 49, "StandardFormEquation"],
Cell[2848270, 83329, 872, 22, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2849179, 83356, 843, 24, 50, "StandardFormEquation"],
Cell[2850025, 83382, 939, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2851001, 83411, 656, 19, 48, "StandardFormEquation"],
Cell[2851660, 83432, 740, 19, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2852437, 83456, 638, 18, 46, "StandardFormEquation"],
Cell[2853078, 83476, 748, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2853863, 83500, 790, 22, 50, "StandardFormEquation"],
Cell[2854656, 83524, 916, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2855609, 83552, 742, 21, 48, "StandardFormEquation"],
Cell[2856354, 83575, 843, 21, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2857234, 83601, 925, 25, 50, "StandardFormEquation"],
Cell[2858162, 83628, 1117, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2859316, 83661, 470, 13, 47, "StandardFormEquation"],
Cell[2859789, 83676, 589, 15, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2860415, 83696, 579, 16, 47, "StandardFormEquation"],
Cell[2860997, 83714, 717, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2861751, 83737, 615, 17, 47, "StandardFormEquation"],
Cell[2862369, 83756, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2863129, 83779, 704, 20, 48, "StandardFormEquation"],
Cell[2863836, 83801, 852, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2864725, 83828, 638, 18, 48, "StandardFormEquation"],
Cell[2865366, 83848, 771, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2866174, 83872, 740, 21, 50, "StandardFormEquation"],
Cell[2866917, 83895, 890, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2867844, 83923, 674, 19, 50, "StandardFormEquation"],
Cell[2868521, 83944, 809, 20, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2869367, 83969, 1109, 29, 68, "StandardFormEquation"],
Cell[2870479, 84000, 1298, 31, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2871814, 84036, 943, 26, 47, "StandardFormEquation"],
Cell[2872760, 84064, 1084, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2873881, 84097, 1007, 27, 47, "StandardFormEquation"],
Cell[2874891, 84126, 1150, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2876078, 84160, 742, 21, 48, "StandardFormEquation"],
Cell[2876823, 84183, 843, 21, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2877703, 84209, 931, 24, 49, "StandardFormEquation"],
Cell[2878637, 84235, 1106, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2879780, 84267, 846, 23, 50, "StandardFormEquation"],
Cell[2880629, 84292, 1018, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2881684, 84322, 778, 22, 50, "StandardFormEquation"],
Cell[2882465, 84346, 894, 23, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2883396, 84374, 980, 26, 50, "StandardFormEquation"],
Cell[2884379, 84402, 1144, 28, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2885560, 84435, 1019, 27, 50, "StandardFormEquation"],
Cell[2886582, 84464, 1191, 29, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2887810, 84498, 750, 21, 48, "StandardFormEquation"],
Cell[2888563, 84521, 909, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2889509, 84549, 879, 24, 48, "StandardFormEquation"],
Cell[2890391, 84575, 1069, 27, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2891497, 84607, 915, 25, 50, "StandardFormEquation"],
Cell[2892415, 84634, 1107, 28, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2893559, 84667, 964, 26, 50, "StandardFormEquation"],
Cell[2894526, 84695, 1162, 29, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2895725, 84729, 867, 24, 50, "StandardFormEquation"],
Cell[2896595, 84755, 1051, 27, 49, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2897695, 84788, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[2897841, 84794, 885, 23, 49, "StandardFormEquation"],
Cell[2898729, 84819, 1073, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2899839, 84851, 763, 20, 49, "StandardFormEquation"],
Cell[2900605, 84873, 937, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2901579, 84901, 976, 26, 47, "StandardFormEquation"],
Cell[2902558, 84929, 1132, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2903727, 84963, 879, 24, 49, "StandardFormEquation"],
Cell[2904609, 84989, 1036, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2905682, 85020, 671, 19, 27, "StandardFormEquation"],
Cell[2906356, 85041, 808, 20, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2907201, 85066, 753, 21, 43, "StandardFormEquation"],
Cell[2907957, 85089, 907, 22, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2908901, 85116, 840, 22, 47, "StandardFormEquation"],
Cell[2909744, 85140, 1060, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2910841, 85172, 747, 21, 48, "StandardFormEquation"],
Cell[2911591, 85195, 904, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2912532, 85223, 787, 21, 47, "StandardFormEquation"],
Cell[2913322, 85246, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2914303, 85275, 849, 22, 49, "StandardFormEquation"],
Cell[2915155, 85299, 1071, 27, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2916263, 85331, 711, 20, 29, "StandardFormEquation"],
Cell[2916977, 85353, 867, 22, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2917881, 85380, 780, 21, 47, "StandardFormEquation"],
Cell[2918664, 85403, 954, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2919655, 85431, 1131, 30, 65, "StandardFormEquation"],
Cell[2920789, 85463, 1321, 32, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2922147, 85500, 829, 22, 49, "StandardFormEquation"],
Cell[2922979, 85524, 1007, 26, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2924023, 85555, 863, 23, 50, "StandardFormEquation"],
Cell[2924889, 85580, 1043, 27, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2925969, 85612, 787, 21, 47, "StandardFormEquation"],
Cell[2926759, 85635, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2927740, 85664, 787, 21, 47, "StandardFormEquation"],
Cell[2928530, 85687, 944, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2929511, 85716, 705, 19, 47, "StandardFormEquation"],
Cell[2930219, 85737, 830, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2931086, 85762, 829, 22, 49, "StandardFormEquation"],
Cell[2931918, 85786, 992, 25, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2932947, 85816, 770, 21, 49, "StandardFormEquation"],
Cell[2933720, 85839, 910, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2934667, 85867, 694, 19, 47, "StandardFormEquation"],
Cell[2935364, 85888, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2936252, 85914, 896, 24, 47, "StandardFormEquation"],
Cell[2937151, 85940, 1070, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2938258, 85972, 896, 24, 47, "StandardFormEquation"],
Cell[2939157, 85998, 1070, 27, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2940264, 86030, 588, 16, 27, "StandardFormEquation"],
Cell[2940855, 86048, 694, 17, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2941586, 86070, 626, 17, 29, "StandardFormEquation"],
Cell[2942215, 86089, 745, 19, 29, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2942997, 86113, 732, 20, 47, "StandardFormEquation"],
Cell[2943732, 86135, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2944626, 86161, 732, 20, 47, "StandardFormEquation"],
Cell[2945361, 86183, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2946255, 86209, 804, 22, 50, "StandardFormEquation"],
Cell[2947062, 86233, 948, 24, 49, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2948047, 86262, 732, 20, 47, "StandardFormEquation"],
Cell[2948782, 86284, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2949676, 86310, 732, 20, 47, "StandardFormEquation"],
Cell[2950411, 86332, 857, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2951305, 86358, 814, 22, 47, "StandardFormEquation"],
Cell[2952122, 86382, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2953117, 86410, 839, 23, 47, "StandardFormEquation"],
Cell[2953959, 86435, 987, 25, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2954983, 86465, 712, 20, 47, "StandardFormEquation"],
Cell[2955698, 86487, 826, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2956561, 86513, 1090, 28, 47, "StandardFormEquation"],
Cell[2957654, 86543, 1344, 33, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2959035, 86581, 629, 17, 47, "StandardFormEquation"],
Cell[2959667, 86600, 769, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2960473, 86624, 816, 22, 62, "StandardFormEquation"],
Cell[2961292, 86648, 1022, 26, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2962351, 86679, 775, 21, 62, "StandardFormEquation"],
Cell[2963129, 86702, 962, 24, 44, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2964128, 86731, 639, 18, 47, "StandardFormEquation"],
Cell[2964770, 86751, 774, 19, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2965581, 86775, 579, 16, 47, "StandardFormEquation"],
Cell[2966163, 86793, 717, 18, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2966917, 86816, 748, 21, 47, "StandardFormEquation"],
Cell[2967668, 86839, 902, 22, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2968607, 86866, 665, 18, 47, "StandardFormEquation"],
Cell[2969275, 86886, 820, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2970132, 86911, 585, 16, 47, "StandardFormEquation"],
Cell[2970720, 86929, 723, 18, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2971480, 86952, 927, 25, 66, "StandardFormEquation"],
Cell[2972410, 86979, 1132, 28, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2973579, 87012, 890, 24, 47, "StandardFormEquation"],
Cell[2974472, 87038, 989, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2975498, 87067, 1314, 34, 81, "StandardFormEquation"],
Cell[2976815, 87103, 1412, 33, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2978264, 87141, 705, 19, 47, "StandardFormEquation"],
Cell[2978972, 87162, 830, 20, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2979839, 87187, 1046, 27, 67, "StandardFormEquation"],
Cell[2980888, 87216, 1240, 30, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2982165, 87251, 1451, 36, 119, "StandardFormEquation"],
Cell[2983619, 87289, 1609, 37, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2985265, 87331, 753, 21, 47, "StandardFormEquation"],
Cell[2986021, 87354, 884, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2986942, 87382, 623, 17, 47, "StandardFormEquation"],
Cell[2987568, 87401, 763, 19, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2988368, 87425, 772, 21, 49, "StandardFormEquation"],
Cell[2989143, 87448, 916, 23, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2990096, 87476, 734, 20, 47, "StandardFormEquation"],
Cell[2990833, 87498, 861, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2991731, 87524, 724, 20, 47, "StandardFormEquation"],
Cell[2992458, 87546, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2993346, 87572, 1121, 28, 99, "StandardFormEquation"],
Cell[2994470, 87602, 1419, 35, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2995926, 87642, 954, 25, 65, "StandardFormEquation"],
Cell[2996883, 87669, 1179, 29, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2998099, 87703, 772, 21, 47, "StandardFormEquation"],
Cell[2998874, 87726, 943, 23, 45, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[2999854, 87754, 927, 25, 66, "StandardFormEquation"],
Cell[3000784, 87781, 1132, 28, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3001953, 87814, 809, 22, 47, "StandardFormEquation"],
Cell[3002765, 87838, 985, 24, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3003787, 87867, 694, 19, 47, "StandardFormEquation"],
Cell[3004484, 87888, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3005372, 87914, 780, 21, 47, "StandardFormEquation"],
Cell[3006155, 87937, 954, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3007146, 87965, 824, 22, 47, "StandardFormEquation"],
Cell[3007973, 87989, 968, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3008978, 88017, 814, 22, 47, "StandardFormEquation"],
Cell[3009795, 88041, 958, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3010790, 88069, 694, 19, 47, "StandardFormEquation"],
Cell[3011487, 88090, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3012375, 88116, 694, 19, 47, "StandardFormEquation"],
Cell[3013072, 88137, 851, 21, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3013960, 88163, 905, 24, 65, "StandardFormEquation"],
Cell[3014868, 88189, 1098, 26, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3016003, 88220, 1409, 35, 117, "StandardFormEquation"],
Cell[3017415, 88257, 1605, 37, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3019057, 88299, 747, 21, 48, "StandardFormEquation"],
Cell[3019807, 88322, 904, 23, 47, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3020748, 88350, 1656, 41, 119, "StandardFormEquation"],
Cell[3022407, 88393, 1810, 42, 67, "TraditionalFormEquation"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3024266, 88441, 121, 2, 48, "Subsubsection"],

Cell[CellGroupData[{
Cell[3024412, 88447, 792, 22, 43, "StandardFormEquation"],
Cell[3025207, 88471, 948, 23, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3026192, 88499, 697, 19, 43, "StandardFormEquation"],
Cell[3026892, 88520, 822, 20, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3027751, 88545, 822, 22, 65, "StandardFormEquation"],
Cell[3028576, 88569, 964, 23, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3029577, 88597, 1224, 32, 75, "StandardFormEquation"],
Cell[3030804, 88631, 1452, 33, 28, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3032293, 88669, 1572, 39, 101, "StandardFormEquation"],
Cell[3033868, 88710, 1692, 38, 84, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3035597, 88753, 1367, 34, 115, "StandardFormEquation"],
Cell[3036967, 88789, 1495, 33, 46, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3038499, 88827, 1045, 27, 61, "StandardFormEquation"],
Cell[3039547, 88856, 1327, 33, 48, "TraditionalFormEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[3040911, 88894, 1139, 30, 63, "StandardFormEquation"],
Cell[3042053, 88926, 1366, 34, 48, "TraditionalFormEquation"]
}, Closed]]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

